@@ -1,11 +1,11 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -27,7 +27,6 @@
 This script creates the list of files to be included in
 the pyFormex source distribution.
 """
-from __future__ import print_function
 import os,re
 
 def prefixFiles(prefix,files):
@@ -98,36 +97,32 @@ def listTree(path,listdirs=False,topdown=True,sorted=True,excludedirs=[],exclude
     return filelist
 
 
-#NON_MANIFEST = [ f.strip('\n') for f in open('NONMANIFEST').readlines() ]
-
 
 # pyFormex documentation (installed in the pyformex tree)
 DOC_FILES = listTree(
     'pyformex/doc/html',
-    excludedirs=['.svn'],
-    ) + listTree(
-    'pyformex/doc',
-    excludedirs=['.svn','dutch','html'],
-    includefiles=[
-        'README',
-        'Description',
-        'COPYING',
-        'ReleaseNotes',
-        'p3.rst',
-        ],
     )
+# + listTree(
+#     'pyformex/doc',
+#     excludedirs=['dutch','html'],
+#     includefiles=[
+#         'README',
+#         'Description',
+#         'COPYING',
+#         'ReleaseNotes',
+#         ],
+#     )
 
 
 # pyFormex data files (installed in the pyformex tree)
 DATA_FILES = listTree(
     'pyformex/data',
-    excludedirs=['.svn','benchmark','ply'],
+    excludedirs=['benchmark','ply'],
     excludefiles=['.*\.pyc','.*~$','PTAPE.*'],
     includefiles=[
         'README',
-        'template.py',
         'benedict_6\.jpg',
-        'bifurcation\.off',
+        'bifurcation\.off.gz',
         'blippo\.pgf',
         'blippok\.ttf',
         'butterfly\.png',
@@ -135,26 +130,32 @@ DATA_FILES = listTree(
         'hesperia-nieve\.prop',
         'horse\.off',
         'horse\.pgf',
+        'image_not_loaded\.png',
+        'man\.off',
+        'man\.pgf',
         'mark_cross\.png',
         'materials\.db',
         'sections\.db',
         'splines\.pgf',
         'supershape\.txt',
         'teapot\.off',
+        'template.py',
         'world\.jpg',
         'xtk_xdat\.gui\.js',
         ],
-    ) + listTree(
+) + listTree(
+    'pyformex/scripts',
+) + listTree(
     'pyformex/glsl',
     includefiles=[
         '.*\.c',
-        ],
-    ) + listTree(
+    ],
+) + listTree(
     'pyformex/fonts',
     includefiles=[
         '.*\.png',
-        ],
-    )
+    ],
+)
 
 # scripts to install extra programs
 EXTRA_FILES = listTree(
@@ -162,7 +163,6 @@ EXTRA_FILES = listTree(
     includedirs=[
         'calpy',
         'dxfparser',
-###        'freetype-py',  now included in pyformex
         'gts',
         'postabq',
         'pygl2ps',
@@ -181,7 +181,6 @@ EXTRA_FILES = listTree(
         '.*\.py$',
         '.*\.1$',
         '.*\.pc$',
-#        'freetype-py-0.4.1.tar.gz',
         ],
     )
 
@@ -204,15 +203,15 @@ DIST_FILES = [
     'README',
     'COPYING',
     'Description',
-#    'Makefile',
+    'Makefile',
     'ReleaseNotes',
     'manifest.py',
-    'p3.rst',
     'setup.py',
     'setup.cfg',
     ] + \
     listTree('pyformex',
-             includedirs=['gui','menus','plugins','opengl','fe','appsdir','scripts'],
+             includedirs=['gui','menus','plugins','opengl',
+                          'fe','appsdir'],   # DO NOT ADD scripts HERE
              includefiles=['.*\.py$','pyformex(rc)?$','pyformex.conf$'],
              excludefiles=['core.py','curvetools.py','backports.py'],
              ) + \
