@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -26,26 +26,30 @@
 
 This module initializes the pyFormex global variables and
 defines a few essential functions.
-It is the very first thing that is executed when starting pyFormex.
-It is loaded even before main.
+It is the very first thing that is loaded when starting pyFormex.
 """
-from __future__ import absolute_import, division, print_function
 
-import os, sys
-import time, datetime
+import os
+import sys
+import time
+import datetime
 import logging
+import logging.config
 
 __prog__ = "pyformex"
-__version__ = "1.0.7"
+__version__ = "2.0"
 __revision__ = __version__
-Copyright = 'Copyright (C) 2004-2019 Benedict Verhegghe'
+__branch__ = "master"
+Copyright = 'Copyright (C) 2004-2020 Benedict Verhegghe'
 Url = 'http://pyformex.org'
-Description = "pyFormex is a tool for generating, manipulating and transforming large geometrical models of 3D structures by sequences of mathematical transformations."
+Description = ("pyFormex is a tool for generating, manipulating and "
+               "transforming large geometrical models of 3D structures "
+               "by sequences of mathematical transformations.")
 
 
 def Version():
     """Return a string with the pyFormex name and version"""
-    return 'pyFormex %s' % __version__
+    return f"pyFormex {__version__}"
 
 
 def fullVersion():
@@ -53,7 +57,7 @@ def fullVersion():
     if __revision__ == __version__:
         return Version()
     else:
-        return "%s (%s) DEVELOPMENT VERSION" % (Version(), __revision__)
+        return f"{Version()} ({__revision__}) DEVELOPMENT VERSION"
 
 
 # set start date/time
@@ -69,19 +73,18 @@ started = False
 PY2 = sys.hexversion < 0x03000000
 PY3 = not PY2
 
+if PY2:
+    raise RuntimeError("This version of pyFormex does not support Python2.x. "
+                       "Please use Python3 instead, or use an older pyFormex "
+                       "version (<= 1.0.7)")
+
+
 # intended Python version
-# We only support 3.4+
-minimal_version = 0x03040000
+# We only support 3.6+
+minimal_version = 0x03060000
 target_version = 0x03070000
 future_version = 0x03080000
 
-if PY2:
-    # No more support for pre 2.7
-    # 2.7 support will end on Jan 1, 2020
-    minimal_version = 0x02070000
-    target_version = 0x02070000
-    future_version = 0x03000000
-
 
 def major(v):
     """Return the major component of version"""
@@ -95,7 +98,7 @@ def minor(v):
 
 def human_version(v):
     """Return the human readable string for version"""
-    return "%s.%s" % (major(v), minor(v))
+    return f"{major(v)}.{minor(v)}"
 
 
 if sys.hexversion < minimal_version:
@@ -119,29 +122,6 @@ if sys.hexversion & 0xFFFF0000 > target_version:
 ##  contact the developers at http://pyformex.org.                   ##
 #######################################################################
 """ % (human_version(sys.hexversion), human_version(minimal_version))
-    #print(startup_warnings)
-
-if PY2:
-    if datetime.date.today() >= datetime.date(2020, 1, 1):
-        startup_warnings += """
-#######################################################################
-##  Your are running pyFormex with Python version %s, but pyFormex  ##
-##  support for Python 2.x has ended as of Jan 1, 2020.              ##
-##  Consider running pyFormex on Python 3.6 or higher, so you can    ##
-##  enjoy continued support and updates.                             ##
-#######################################################################
-""" % (human_version(sys.hexversion),)
-
-# Compatibility between Python2 and Python3
-# We keep these in separate modules, because the ones for 2k might
-# not compile in 3k and vice-versa.
-
-if PY2:
-    from pyformex.compat_2k import *
-    startup_messages += py2_warning
-if PY3:
-    from pyformex.compat_3k import *
-    startup_messages += py3_warning
 
 #### Detect install type ########
 
@@ -170,16 +150,43 @@ if os.path.exists(os.path.join(parentdir, '.git')):
     installtype = 'G'
 
 ########## start the logger ####################
+LOGGING = {
+    'version': 1,
+    'disable_existing_loggers': False,
+    'formatters': {
+        'default': {
+            'format': "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
+        },
+        'short': {
+            'format': "%(asctime)s %(message)s",
+        },
+        'detail': {
+            'format': "%(asctime)s::%(levelname)s::%(name)s::"
+            "%(filename)s::%(lineno)d::%(message)s",
+        },
+    },
+    'handlers': {
+        'console': {
+            'class': 'logging.StreamHandler',
+            'formatter': 'detail',
+        },
+        'memory': {
+            'class': 'logging.handlers.MemoryHandler',
+            'capacity': 100,
+            'formatter': 'default',
+        },
+    },
+    'loggers': {
+        'pyformex': {
+            'level': 'INFO',
+            'handlers': ['memory'],
+        }
+    },
+}
 
-logging.basicConfig(
-    filename='pyformex.log',
-    filemode='a',
-    format='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
-    level=logging.INFO
-)
-#logger = logging.getLogger('pyformex')
-logger = logging
-logger.info("%s start on Python%s" % (fullVersion(), 2 if PY2 else 3))
+logging.config.dictConfig(LOGGING)
+logger = logging.getLogger('pyformex')
+logger.info(f"{fullVersion()} start on Python{human_version(sys.hexversion)}")
 
 ########## acceleration libraries ##############
 
@@ -194,7 +201,7 @@ if installtype in 'SG':
         """Run command"""
         import subprocess
         P = subprocess.Popen(
-            cmd, stdout=subprocess.PIPE, shell=True, universal_newlines=True
+            str(cmd), stdout=subprocess.PIPE, shell=True, universal_newlines=True
         )
         out, err = P.communicate()
         return P.returncode, out, err
@@ -203,12 +210,13 @@ if installtype in 'SG':
     source_clean = os.path.join(pyformexdir, 'source_clean')
     if os.path.exists(source_clean):
         try:
-            run_cmd(str(source_clean))
-        except:
-            print(
-                "Error while executing %s, ignore error and continue" %
-                source_clean
-            )
+            import importlib
+            suffix = importlib.machinery.EXTENSION_SUFFIXES[0]
+            cmd = "%s --keep_modules '*%s'" % (source_clean, suffix)
+            run_cmd(cmd)
+        except Exception:
+            print(f"Error while executing {source_clean}\n"
+                  "Ignore error and continue")
 
     # Running from source tree: make sure the compiled libraries are up-to-date
     libdir = os.path.join(pyformexdir, 'lib')
@@ -231,13 +239,11 @@ if installtype in 'SG':
 
     msg = checkLibraries()
     if msg:
-        # Try rebyuilding
+        print(msg)
         print("Rebuilding pyFormex libraries, please wait")
-        if PY2:
-            target = 'lib'
-        else:
-            target = 'lib3'
+        target = 'lib3'
         cmd = "cd %s/..; make %s" % (pyformexdir, target)
+        print(f"Running command: {cmd}")
         os.system(cmd)
         msg = checkLibraries()
 
@@ -263,18 +269,19 @@ You should probably exit pyFormex, fix the problem first and then restart pyForm
             print("Could not set revision")
 
     def set_branch():
+        global __branch__
         cmd = 'cd %s && git symbolic-ref -q HEAD' % pyformexdir
         sta, out, err = run_cmd(cmd)
         if sta == 0:
-            branch = out.split('\n')[0].split('/')[-1]
+            __branch__ = out.split('\n')[0].split('/')[-1]
         else:
             print("Could not set branch name")
 
     set_revision()
     set_branch()
 
-logger.info("This is %s" % fullVersion())
-logger.info("Installation type %s at %s" % (installtype, pyformexdir))
+logger.info(f"This is {fullVersion()}")
+logger.info(f"Installation type {installtype} at {pyformexdir}")
 
 ################ pyFormex global variables and functions ###############
 
@@ -284,7 +291,6 @@ interactive = False
 app = None  # the Qapplication
 GUI = None  # the GUI QMainWindow
 canvas = None  # the OpenGL Drawing widget controlled by the running script
-#board = None      # the message board
 console = None  # alternate Python console
 
 # initialize some global variables used for communication between modules
@@ -347,17 +353,16 @@ class DebugLevels(object):
     """
     ALL = -1
     NONE = 0
-    INFO, WARNING, OPTION, CONFIG, DETECT, MEM, SCRIPT, GUI, MENU, DRAW, \
-          CANVAS, OPENGL, LIB, MOUSE, APPS, IMAGE, MISC, ABQ, WIDGET, \
-          PROJECT, WEBGL, MULTI, LEGACY, PLUGIN, UNICODE, FONT, \
-          PGF, VTK, DOCTEST = \
-          [2 ** i for i in range(29)]
+    (INFO, WARNING, OPTION, CONFIG, DETECT, MEM, SCRIPT, GUI, MENU, DRAW,
+     CANVAS, OPENGL, LIB, MOUSE, APPS, IMAGE, MISC, ABQ, WIDGET, PROJECT,
+     WEBGL, MULTI, LEGACY, PLUGIN, UNICODE, FONT, PGF, VTK, DOCTEST,
+     ) = [2 ** i for i in range(29)]
 
 
 try:
     # Python2 stores the local variable 'i'
     delattr(DebugLevels, 'i')
-except:
+except Exception:
     # Python3 seems not to store it
     pass
 
@@ -374,7 +379,7 @@ def debugLevel(sl):
     for l in sl:
         try:
             lev |= getattr(DEBUG, l.upper())
-        except:
+        except Exception:
             pass
     return lev
 
@@ -388,15 +393,20 @@ def debug(s, level=DEBUG.ALL):
     """Print a debug message"""
     try:  # to make sure that debug() can be used before options are set
         if options.debuglevel & level:
-            raise
-        pass
-    except:
-        print("DEBUG(%s): %s" % (level, s))
+            raise exception
+    except Exception:
+        print(f"DEBUG({level}): {s}")
 
 
 def debugt(s, level):
     """Print a debug message with timer"""
-    debug("%s: %s" % (time.time(), s))
+    debug(f"{time.time()}: {s}")
+
+
+def verbose(verbose, *args, **kargs):
+    """Print a message if the verbosity is high enough"""
+    if options.verbose >= verbose:
+        print(*args, **kargs)
 
 
 def run(args=[]):
@@ -408,49 +418,25 @@ def run(args=[]):
 ## Load selected Path class
 ###########################
 
-#print(sys.argv[1])
-
 if len(sys.argv) > 1 and sys.argv[1].endswith('pyformex'):
     from pyformex.options import parseOptions
     if not parseOptions(sys.argv[2:]):
         sys.exit(1)
 
 if options.pathlib:
-
-    if PY2:
-        try:
-            #print("Importing Path from python-pathlib2")
-            from pathlib2 import Path
-        except:
-            raise RuntimeError(
-                """
-        ##############################
-        ## Missing pathlib!
-        ## Please install python-pathlib2, if you want to use pathlib.
-        ## Or use the Python3 version: pathlib is part of its standard library.
-        ## pyFormex can however also run without the pathlib option.
-        ##############################
-        """
-            )
-
-    if PY3:
-        #print("Importing Path from Python3.pathlib")
-        from pathlib import Path
-
+    from pathlib import Path
 else:
-    #print("Importing Path from pyformex.path")
     from pyformex.path import Path
 
 # Placeholder for excutable, if pyformex: filled in by startup.py
 executable = Path(sys.executable)
-#print(executable)
 
 ############################################################################
 ###  Load default configuration
 ### (pyFormex does not work if not loaded)
 ##########################################
 
-from pyformex.config import Config
+from pyformex.config import Config  # noqa: E402
 
 # Create a config instance
 cfg = Config()
