@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -28,58 +28,16 @@ This module defines a specialized array class for representing adjacency
 of items of a single type. This is e.g. used in mesh models, to store
 the adjacent elements.
 """
-from __future__ import absolute_import, division, print_function
 
 import numpy as np
 
 from pyformex import arraytools as at
-from pyformex.varray import Varray
 
-############### Utility functions ##############
-
-# :DEV
-# THESE FUNCTIONS SHOULD NOT BE USED!! THEY WILL BE REMOVED
+############### Private functions ##############
 
 
-def _sortAdjacency(adj):
-    """Sort an adjacency table.
-
-    An adjacency table is an integer array where each row lists the numbers
-    of the items that are connected to the item with number equal to the row
-    index. Rows are padded with -1 value to create rows of equal length.
-
-    This function sorts the rows of the adjacency table in ascending order
-    and removes all columns containing only -1 values.
-
-    Paramaters:
-
-    - `adj`: an 2-D integer array with values >=0 or -1
-
-    Returns: an integer array with shape (adj.shape[0],maxc), with
-    maxc <= adj.shape[1], where the rows are sorted in ascending order
-    and where columns with only -1 values are removed.
-
-    Example:
-
-      >>> a = np.array([[ 0,  2,  1, -1],
-      ...               [-1,  3,  1, -1],
-      ...               [ 3, -1,  0,  1],
-      ...               [-1, -1, -1, -1]])
-      >>> _sortAdjacency(a)
-      array([[ 0,  1,  2],
-             [-1,  1,  3],
-             [ 0,  1,  3],
-             [-1, -1, -1]])
-
-    """
-    if adj.shape[1] > 0:
-        adj.sort(axis=-1)      # sort rows
-        maxc = adj.max(axis=0)  # find maximum per column
-        adj = adj[:, maxc>=0]   # retain columns with non-negative maximum
-    return adj
-
-
-def _reduceAdjacency(adj):
+# Not to be used outside this module
+def _reduce_adjacency(adj, remove_self=True, remove_dup=True):
     """Reduce an adjacency table.
 
     An adjacency table is an integer array where each row lists the numbers
@@ -89,46 +47,66 @@ def _reduceAdjacency(adj):
     A reduced adjacency table is one where each row:
 
     - does not contain the row index itself,
-    - does not contain duplicates,
+    - does not contain duplicate entries (other than -1),
     - is sorted in ascending order,
 
     and that has at least one row without -1 value.
 
-    Paramaters:
+    Paramaters
+    ----------
+    adj: int :term:`array_like`
+        A 2-dim integer array with values >=0 or -1
+    remove_self: bool
+        If True (default), row entries equal to the row index are removed
+        (i.e. elements are not considered to be adjacent to themselves).
+    remove_dup: bool
+        If True (default), duplicate (non-negative) entries on a row are
+        removed (i.e. adjacency does not count the number of connections).
 
-    - `adj`: an 2-D integer array with value >=0 or -1
-
-    Returns: an integer array with shape (adj.shape[0],maxc), with
-    maxc <= adj.shape[1], where row `i` retains the unique non-negative
-    numbers of the original array except the value `i`, and is possibly
-    padded with -1 values.
-
-    Example:
-
-      >>> a = np.array([[ 0,  0,  0,  1,  2,  5],
-      ...               [-1,  0,  1, -1,  1,  3],
-      ...               [-1, -1,  0, -1, -1,  2],
-      ...               [-1, -1,  1, -1, -1,  3],
-      ...               [-1, -1, -1, -1, -1, -1],
-      ...               [-1, -1,  0, -1, -1,  5]])
-      >>> _reduceAdjacency(a)
-      array([[ 1,  2,  5],
-             [-1,  0,  3],
-             [-1, -1,  0],
-             [-1, -1,  1],
-             [-1, -1, -1],
-             [-1, -1,  0]])
+    Returns
+    -------
+    int array
+        An integer array with shape (adj.shape[0],maxc) with
+        maxc <= adj.shape[1], where row `i` retains the unique non-negative
+        numbers of the original array except the value `i`, and is possibly
+        padded with -1 values.
 
+    Examples
+    --------
+    >>> a = np.array([[ 0,  0,  0,  1,  2,  5],
+    ...               [-1,  0,  1, -1,  1,  3],
+    ...               [-1, -1,  0, -1, -1,  2],
+    ...               [-1, -1,  1, -1, -1,  3],
+    ...               [-1, -1, -1, -1, -1, -1],
+    ...               [-1, -1,  0, -1, -1,  5]])
+    >>> _reduce_adjacency(a)
+    array([[ 1,  2,  5],
+           [-1,  0,  3],
+           [-1, -1,  0],
+           [-1, -1,  1],
+           [-1, -1, -1],
+           [-1, -1,  0]])
+    >>> _reduce_adjacency(Adjacency(a))
+    Adjacency([[ 1,  2,  5],
+               [-1,  0,  3],
+               [-1, -1,  0],
+               [-1, -1,  1],
+               [-1, -1, -1],
+               [-1, -1,  0]])
     """
-    adj = at.checkArray(adj, ndim=2)
+    adj = at.checkArray(adj, ndim=2, subok=True)
     n = adj.shape[0]
     if n > 0:
-        adj[adj == np.arange(n).reshape(n, -1)] = -1  # remove the item i
-        adj.sort(axis=1)
-        adj[np.where(adj[:, :-1] == adj[:, 1:])] = -1  # remove duplicate items
-        adj.sort(axis=1)
+        if remove_self:
+            # remove the item i from row i
+            adj[adj == np.arange(n).reshape(n, -1)] = -1
+        adj.sort(axis=1)        # sort the rows
+        if remove_dup:
+            # remove duplicate items
+            adj[np.where(adj[:, :-1] == adj[:, 1:])] = -1
+            adj.sort(axis=1)
         maxc = adj.max(axis=0)  # find maximum per column
-        adj = adj[:, maxc>=0]   # retain columns with non-negative maximum
+        adj = adj[:, maxc>=0]   # remove columns with only negative values
     return adj
 
 
@@ -190,7 +168,7 @@ class Adjacency(np.ndarray):
 
     Parameters
     ----------
-    data: int :term:
+    data: int :term:`array_like`
         Data to initialize the Connectivity. The data should be 2-dim with
         shape ``(nelems,ncon)``, where ``nelems`` is the number of elements and
         ``ncon`` is the maximum number of connections per element.
@@ -231,7 +209,8 @@ class Adjacency(np.ndarray):
     >>> Adjacency([[]])
     Adjacency([], shape=(1, 0))
     """
-    def __new__(clas, data=[], dtyp=None, copy=False, normalize=True, allow_self=False, bidirectional=False, check_max=True):
+    def __new__(clas, data=[], dtyp=None, copy=False, normalize=True,
+                allow_self=False, bidirectional=False, check_max=True):
         """Create a new Adjacency table."""
 
         # Turn the data into an array, and copy if requested
@@ -247,16 +226,17 @@ class Adjacency(np.ndarray):
         if ar.size > 0:
             maxval = ar.max()
             if check_max and maxval > ar.shape[0]-1:
-                raise ValueError("Too large element number (%s) for number of rows(%s)" % (maxval, ar.shape[0]))
+                raise ValueError(f"Too large element number ({maxval})"
+                                 f" for number of rows({ar.shape[0]})")
         else:
             maxval = -1
 
+        if normalize:
+            ar = _reduce_adjacency(ar)
+
         # Transform 'subarr' from an ndarray to our new subclass.
         ar = ar.view(clas)
 
-        if normalize:
-            ar = _reduceAdjacency(ar).view(clas)
-
         return ar
 
 
@@ -275,7 +255,8 @@ class Adjacency(np.ndarray):
         return self.shape[1]
 
 
-    ### normalize ###
+    ### normalization ###
+
 
     def sortRows(self):
         """Sort an adjacency table.
@@ -291,6 +272,10 @@ class Adjacency(np.ndarray):
             values. The number of rows is the same as the input, the number
             of columns may be lower.
 
+        See Also
+        --------
+        normalize: also removes self and duplicate entries
+
         Examples
         --------
         >>> a = Adjacency([[ 0,  2,  1, -1],
@@ -312,12 +297,7 @@ class Adjacency(np.ndarray):
                    [ 0,  1,  3],
                    [-1, -1, -1]])
         """
-        if self.shape[1] > 0:
-            self.sort(axis=-1)      # sort rows
-            maxc = self.max(axis=0)  # find maximum per column
-            return self[:, maxc>=0]   # retain columns with non-negative maximum
-        else:
-            return self
+        return _reduce_adjacency(self, remove_self=False, remove_dup=False)
 
 
     def normalize(self):
@@ -334,7 +314,7 @@ class Adjacency(np.ndarray):
         By default, an Adjacency gets normalized when it is constructed.
         Performing operations on an Adjacency may however leave it in
         a non-normalized state. Calling this method will normalize it again.
-        This can obviously also be obtained by creating a new Adjacency
+        Obviously this can also be obtained by creating a new Adjacency
         with self as data.
 
         Returns
@@ -355,6 +335,13 @@ class Adjacency(np.ndarray):
         ...                [-1, -1, -1, -1, -1, -1],
         ...                [-1, -1,  0, -1, -1,  5]],normalize=False)
         >>> a.normalize()
+        Adjacency([[ 1,  2,  5],
+                   [-1,  0,  3],
+                   [-1, -1,  0],
+                   [-1, -1,  1],
+                   [-1, -1, -1],
+                   [-1, -1,  0]])
+        >>> Adjacency(a)
         Adjacency([[ 1,  2,  5],
                    [-1,  0,  3],
                    [-1, -1,  0],
@@ -362,11 +349,12 @@ class Adjacency(np.ndarray):
                    [-1, -1, -1],
                    [-1, -1,  0]])
         """
-        return Adjacency(self).sortRows()
+        return _reduce_adjacency(self)
 
 
     ### operations ###
 
+
     def pairs(self):
         """Return all pairs of adjacent element.
 
@@ -384,7 +372,8 @@ class Adjacency(np.ndarray):
                [1, 2]])
 
         """
-        p = [[[i, j] for j in k if j >= 0] for i, k in enumerate(self[:-1]) if max(k) >= 0]
+        p = [[[i, j] for j in k if j >= 0]
+             for i, k in enumerate(self[:-1]) if max(k) >= 0]
         p = np.row_stack(p)
         return p[p[:, 1] > p[:, 0]]
 
@@ -439,6 +428,7 @@ class Adjacency(np.ndarray):
 
     ### frontal methods ###
 
+
     def frontGenerator(self, startat=0, frontinc=1, partinc=1):
         """Generator function returning the frontal elements.
 
