@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -21,30 +21,42 @@
 ##  You should have received a copy of the GNU General Public License
 ##  along with this program.  If not, see http://www.gnu.org/licenses/.
 ##
-"""pyFormex apps initialization.
+"""pyFormex application loading.
 
-This module contains the functions to detect and load the pyFormex
-applications.
+This module contains the functions used to detect and load the pyFormex
+applications. pyFormex applications ('apps') are loaded as a Python
+module. They contain a dedicated function 'run' that is executed when
+the application is started. The application stays in memory, unless it
+is explicitely unloaded.
+
+This module contains functions to find, handle, list and (un)load
+applications and manage application directories.
 """
-from __future__ import absolute_import, division, print_function
 
-import os, sys
+import os
+import sys
+from importlib import reload
 
 import pyformex as pf
-if pf.PY3:
-    from importlib import reload
 from pyformex import utils
 from pyformex import Path
 
 
-# Guess the appdir from the name
-# This works for dirs having a matching cfg['NAMEdir'] entry
-#
-guessDir = lambda n, s: Path(s) if s else pf.cfg['%sdir' % n.lower()]
-
-# global variable used of tracing application load errors
+# global variable used for tracing application load errors
 _traceback = ''
 
+
+def guessDir(n, s):
+    """ Guess the appdir from the name
+
+    n: app name
+    s: app path
+
+    This works for dirs having a matching cfg['NAMEdir'] entry
+    """
+    return Path(s) if s else pf.cfg['%sdir' % n.lower()]
+
+
 class AppDir(object):
     """Application directory
 
@@ -69,7 +81,6 @@ class AppDir(object):
             self.name = self.pkg.capitalize()
         else:
             self.name = name
-        #print("DEBUG: %s %s" % (self.pkg,self.name))
         pf.debug("Created %s" % self, pf.DEBUG.APPS)
 
     def __repr__(self):
@@ -79,15 +90,21 @@ class AppDir(object):
 def setAppDirs():
     """Set the configured application directories"""
     # If this is a reset, first remove sys.path components
-    try:
+    if hasattr(pf, 'appdirs'):
         for p in pf.appdirs:
             if p.added:
-                sys.path.remove(str(p.path.parent))
+                parent = str(p.path.parent)
+                if parent in sys.path:
+                    sys.path.remove(parent)
         print('SYSPATH IS NOW:', sys.path)
-    except:
-        pass
 
-    pf.appdirs = [AppDir(i[1], i[0]) for i in pf.cfg['appdirs']]
+    pf.appdirs = []
+    for p in pf.cfg['appdirs']:
+        try:
+            pf.appdirs.append(AppDir(p[1], p[0]))
+        except:
+            # Silently skip invalid paths
+            pf.debug(f"Invalid appdir path: {p}", pf.DEBUG.CONFIG)
     for p in pf.appdirs:
         pf.debug(str(p), pf.DEBUG.CONFIG)
 
@@ -103,7 +120,10 @@ def checkAppdir(d):
     """
     d = Path(d)
     if not d.exists():
-        os.makedirs(str(d))
+        try:
+            os.makedirs(str(d))
+        except Exception:
+            pass
 
     initfile = d / '__init__.py'
     if not initfile.exists():
@@ -117,7 +137,7 @@ directory as a pyFormex application path.
 \"\"\"
 # End
 """)
-        except:
+        except Exception:
             pass
     if initfile.exists():
         return d
@@ -146,7 +166,7 @@ def load(appname, refresh=False, strict=False):
     if not appname:
         raise RuntimeError("No appname specified!")
     pf.debug("Loading %s with refresh=%s" % (appname, refresh), pf.DEBUG.APPS)
-    print("Loading application %s " % appname)
+    pf.logger.info("Loading application %s " % appname)
     try:
         _traceback = ''
         __import__(appname)
@@ -157,7 +177,7 @@ def load(appname, refresh=False, strict=False):
             if not hasattr(app, 'run') or not callable(app.run):
                 return None
         return app
-    except:
+    except Exception:
         import traceback
         _traceback = traceback.format_exc()
         return None
@@ -175,7 +195,7 @@ def findAppSource(app):
     """
     from types import ModuleType
     if isinstance(app, (str, ModuleType)):
-        path = pf.findModuleSource(app)
+        path = utils.findModuleSource(app)
         if path:
             return Path(path)
         else:
@@ -192,13 +212,8 @@ def unload(appname):
         refcnt = sys.getrefcount(app)
         if refcnt == 4:
             pf.debug("Unloading %s" % name, pf.DEBUG.APPS)
-            ## k = globals().keys()
-            ## k.sort()
-            ## print k
             del globals()[appname]
             del sys.modules[name]
-            ## refcnt = sys.getrefcount(app)
-            ## print refcnt
             del app
         else:
             print("Can not unload %s" % name)
@@ -206,23 +221,45 @@ def unload(appname):
         print("Module %s is not loaded" % name)
 
 
-def listLoaded():
-    return sorted([m for m in sys.modules if m.startswith('apps.')])
+def listLoaded(appsdir='appsdir'):
+    """List the currently loaded apps
+
+    Parameters
+    ----------
+    appsdir: str
+        The base name of a directory registered as an application
+        directory.
+
+    Returns
+    -------
+    list of str
+        A list with the currently loaded applications from the specified
+        application directory.
+
+    """
+    return sorted([m for m in sys.modules if m.startswith(f"{appsdir}.")])
 
 
 def detect(appdir):
     """Detect the apps present in the specified appdir.
 
-    Parameters:
+    Parameters
+    ----------
+    appdir: :term:`path_like`
+        Path to an appdir (i.e. a directory containing a file '__init__.py').
 
-    - `appdir`: path to an appdir (i.e. a directory containing a file
-      '__init__.py'
+    Returns
+    -------
+    list of str
+        A list with all the pyFormex apps in the specified appdir.
+        If a file '.apps.dir' exists in the appdir, the returned list is the
+        contents of that file. Otherwise the list contains all '.py' files
+        in the directory, without the '.py' extension and sorted.
 
-    Return a list with all the pyFormex apps in that appdir.
-
-    If a file '.apps.dir' exists in the appdir, the returned list is the
-    contents of that file. Otherwise the list contains all '.py' files
-    in the directory, without the '.py' extension and sorted.
+    Examples
+    --------
+    >>> detect(pf.cfg.appsdir)
+    ['FeEx', 'Hesperia', 'RunAll']
     """
     pf.debug("Detect apps in %s" % appdir, pf.DEBUG.APPS)
     # Detect, but do not load!!!!
@@ -237,12 +274,12 @@ def detect(appdir):
     else:
         pf.debug("Detect apps: scan %s" % appdir, pf.DEBUG.APPS)
 
-        files = appdir.listTree(listdirs=False, excludedirs=['.*'], includefiles=[r'.*\.py$'])
+        files = appdir.listTree(
+            listdirs=False, excludedirs=['.*'], includefiles=[r'.*[.]py$'])
         apps = [f.stem for f in files if f.stem[0] not in '._']
         apps = sorted(apps)
         pf.debug("%s" % apps, pf.DEBUG.APPS)
         return apps
 
 
-
 # End
