@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -27,10 +27,8 @@
 This module defines a general class for adding extra attributes to
 other objects without cluttering the name space.
 """
-from __future__ import absolute_import, division, print_function
 
 from pyformex.mydict import Dict
-from pyformex import utils
 
 
 class Attributes(Dict):
@@ -75,15 +73,15 @@ class Attributes(Dict):
     --------
     >>> A = Attributes()
     >>> A
-    Dict({})
+    Attributes({})
     >>> A(color='red',alpha=0.7,ontop=True)
     >>> A
-    Dict({'color': 'red', 'alpha': 0.7, 'ontop': True})
+    Attributes({'color': 'red', 'alpha': 0.7, 'ontop': True})
     >>> A['alpha'] = 0.8
     >>> A.color = 'blue'
     >>> A.ontop = None       # remove 'ontop'
     >>> A
-    Dict({'color': 'blue', 'alpha': 0.8})
+    Attributes({'color': 'blue', 'alpha': 0.8})
     >>> A = Attributes({'alpha': 0.8, 'color': 'blue'})
     >>> A.ontop is None
     True
@@ -92,25 +90,25 @@ class Attributes(Dict):
 
     >>> B = Attributes(default_factory=A, color='green')
     >>> B
-    Dict({'color': 'green'})
+    Attributes({'color': 'green'})
     >>> B.color, B.alpha      # alpha found in A
     ('green', 0.8)
     >>> A.clear()
     >>> A
-    Dict({})
+    Attributes({})
     >>> A['alpha'], A.alpha, A('alpha')     # all mechanisms still working
     (None, None, None)
     >>> B['alpha'], B.alpha, B('alpha')
     (None, None, None)
     >>> B(color=None,alpha=1.0)            # remove and change in 1 operation
     >>> B
-    Dict({'alpha': 1.0})
+    Attributes({'alpha': 1.0})
     >>> B.update(color=None)     # update can be used to enter None values.
     >>> B
-    Dict({'alpha': 1.0, 'color': None})
+    Attributes({'alpha': 1.0, 'color': None})
     >>> B['alpha'] = None
     >>> B
-    Dict({'color': None})
+    Attributes({'color': None})
     """
 
     def __init__(self, default_factory=Dict.returnNone, *args, **kargs):
