@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -31,13 +31,13 @@ are described by refering to the node numbers.
 In a mesh model, points common to adjacent elements are unique, and
 adjacency of elements can easily be detected from common node numbers.
 """
-from __future__ import absolute_import, division, print_function
 
 from itertools import combinations
 import numpy as np
 
 from pyformex import utils
 from pyformex import arraytools as at
+from pyformex.varray import Varray
 from pyformex.adjacency import Adjacency
 
 
@@ -82,7 +82,7 @@ class Connectivity(np.ndarray):
 
     Parameters
     ----------
-    data: int :term:
+    data: int :term:`array_like`
         Data to initialize the Connectivity. The data should be 2-dim with
         shape ``(nelems,nplex)``, where ``nelems`` is the number of elements and
         ``nplex`` is the plexitude of the elements.
@@ -145,7 +145,7 @@ class Connectivity(np.ndarray):
         if eltype is None:
             try:
                 eltype = data.eltype
-            except:
+            except Exception:
                 eltype = None
 
         # Turn the data into an array, and copy if requested
@@ -198,7 +198,7 @@ class Connectivity(np.ndarray):
         # Get the pickled ndarray state (as a list, so we can change it)
         object_state = list(np.ndarray.__reduce__(self))
         # Define our own state with the extra attributes we added
-        subclass_state = (self.eltype, None)
+        subclass_state = (str(self.eltype), None)
         # Store both in place of the original ndarray state
         object_state[2] = (object_state[2], subclass_state)
         return tuple(object_state)
@@ -212,13 +212,13 @@ class Connectivity(np.ndarray):
             nd_state, own_state = state
             np.ndarray.__setstate__(self, nd_state)
             self.eltype, self.inv = own_state
-        except:
+        except Exception:
             try:
                 # try to read legacy pickle format, which did not save
                 # the element type (rev < 2360)
                 np.ndarray.__setstate__(self, state)
                 print("WARNING: Connectivity was restored without element type!")
-            except:
+            except Exception:
                 print("I could not unpickle the Connectivity,"
                       " neither in old nor new format")
                 raise
@@ -317,6 +317,7 @@ class Connectivity(np.ndarray):
 
     ############### Detecting degenerates and duplicates ##############
 
+
     def testDegenerate(self):
         """Flag the degenerate elements (rows).
 
@@ -583,12 +584,13 @@ class Connectivity(np.ndarray):
         elif order == 'reverse':
             order = np.arange(self.nelems()-1, -1, -1)
         elif order == 'random':
-            order = random.permutation(self.nelems())
+            order = np.random.permutation(self.nelems())
         else:
             order = np.asarray(order)
-            if not (order.dtype.kind == 'i' and
-                    (np.sort(order) == np.arange(order.size)).all()):
-                raise ValueError("order should be a permutation of range(%s)" % self.nelems())
+            if not (order.dtype.kind == 'i'
+                    and (np.sort(order) == np.arange(order.size)).all()):
+                raise ValueError(
+                    f"order should be a permutation of range({self.nelems()})")
         return order
 
 
@@ -650,7 +652,7 @@ class Connectivity(np.ndarray):
         return elems, nodes
 
 
-    def inverse(self, expand=True):
+    def inverse(self, expand=None):
         """Return the inverse index of a Connectivity table.
 
         Returns
@@ -661,7 +663,7 @@ class Connectivity(np.ndarray):
 
         Examples
         --------
-        >>> Connectivity([[0,1,2],[0,1,4],[0,4,2]]).inverse()
+        >>> Connectivity([[0,1,2],[0,1,4],[0,4,2]]).inverse(expand=True)
         array([[ 0,  1,  2],
                [-1,  0,  1],
                [-1,  0,  2],
@@ -669,17 +671,21 @@ class Connectivity(np.ndarray):
                [-1,  1,  2]])
         >>> Connectivity([[0,1,2],[0,1,4],[0,4,2]]).inverse(expand=False)
         Varray([[0, 1, 2], [0, 1], [0, 2], [], [1, 2]])
+        >>> Connectivity().inverse()
+        Varray([])
         """
-        if not expand:
-            # we should not store the inverse
-            return at.inverseIndex(self, expand=expand)
+        if expand is None:
+            utils.warn("warn_Connectivity_inverse", uplevel=1)
+            expand = False
+
         if self.inv is None or self.flags.writeable:
-            if self.size > 0:
-                self.inv = at.inverseIndex(self, expand=expand)
-            else:
-                self.inv = Connectivity()
+            self.inv = Varray(self).inverse()
             self.flags.writeable = False
-        return self.inv
+
+        if expand:
+            return self.inv.toArray()
+        else:
+            return self.inv
 
 
     def nParents(self):
@@ -697,8 +703,7 @@ class Connectivity(np.ndarray):
         >>> Connectivity([[0,1,2],[0,1,4],[0,4,2]]).nParents()
         array([3, 2, 2, 0, 2])
         """
-        r = self.inverse()
-        return (r>=0).sum(axis=1)
+        return self.inverse(expand=False).lengths
 
 
     def connectedTo(self, nodes, return_ncon=False):
@@ -706,7 +711,7 @@ class Connectivity(np.ndarray):
 
         Parameters
         ----------
-        nodes: int or int :term:
+        nodes: int or int :term:`array_like`
             One or more node numbers to check for connections in the table.
         return_ncon: bool, optional
             If True, also return the number of connections for each element.
@@ -731,7 +736,7 @@ class Connectivity(np.ndarray):
         """
         nodes = at.checkArray1D(nodes, kind='i')
         nodes = np.intersect1d(nodes, self)  # remove unconnected nodes
-        inv = self.inverse()
+        inv = self.inverse(expand=True)
         ad = inv[nodes]
         ad = ad[ad>=0]
         # We now have a list of all individual attachements to any of the nodes,
@@ -850,11 +855,13 @@ class Connectivity(np.ndarray):
             # We already computed it
             return adj
 
-
-        inv = self.inverse()
+        inv = self.inverse(expand=True)
         if kind == 'e':
             if mask is not None:
                 mask = at.complement(mask, inv.shape[0])
+                # BEWARE! Need to make a copy here to avoid
+                # destroying the stored full inv
+                #inv = inv.copy()
                 inv[mask] = -1
             if self.size <= 4000000:
                 # do in one step
@@ -939,7 +946,7 @@ class Connectivity(np.ndarray):
         nels = els.shape[0]
         if nels <= 0:
             return np.array([], dtype=at.Int)
-        inv = self.inverse()
+        inv = self.inverse(expand=True)
         # print(inv)
         if mask is not None:
             mask = at.complement(mask, inv.shape[0])
@@ -957,10 +964,10 @@ class Connectivity(np.ndarray):
 
     ### frontal methods ###
 
-    # TODO: This is still much slower that Adjacency.frontwalk
-    #   Maybe we should just remove this (or else implement in C)
 
     def frontGenerator(self, startat=0, frontinc=1, partinc=1):
+        # TODO: This is still much slower that Adjacency.frontwalk
+        #   Maybe we should just remove this (or else implement in C)
         """Generator function returning the frontal elements.
 
         This is a generator function and is normally not used directly,
@@ -1007,22 +1014,22 @@ class Connectivity(np.ndarray):
         p = -np.ones((self.nelems()), dtype=at.Int)
 
         # Compute inverse once, then lock array
-        self.inv = self.inverse()
+        self.inverse(expand=True)
 
         # Remember current elements front
         elems = np.clip(np.asarray(startat), 0, self.nelems())
         prop = 0
         while elems.size > 0:
             # Store prop value for current elems
-            #at.printar("Elems ",elems)
+            # at.printar("Elems ",elems)
             p[elems] = prop
             yield p
 
             prop += frontinc
 
             # Determine adjacent elements
-            #nodes = np.unique(np.asarray(self[elems]))
-            #elems = self.connectedTo(nodes)
+            # nodes = np.unique(np.asarray(self[elems]))
+            # elems = self.connectedTo(nodes)
             elems = np.unique(self.adjacentElements(elems))
             while elems[0] < 0:  # There should only be one -1
                 elems = elems[1:]
@@ -1126,14 +1133,15 @@ class Connectivity(np.ndarray):
         return front
 
 
-######### Creating intermediate levels ###################
+    ##### Creating intermediate levels ###################
+
 
     def selectNodes(self, selector):
         """Return a :class:`Connectivity` containing subsets of the nodes.
 
         Parameters
         ----------
-        selector: int :term:
+        selector: int :term:`array_like`
             An object that can be converted to a 1-dim or 2-dim
             int array. Examples are a tuple of local node numbers, or a list
             of such tuples all having the same length.
@@ -1183,7 +1191,7 @@ class Connectivity(np.ndarray):
 
         Parameters
         ----------
-        selector: int :term:
+        selector: int :term:`array_like`
             An object that can be converted to a 1-dim or 2-dim
             int array. Examples are a tuple of local node numbers, or a list
             of such tuples all having the same length.
@@ -1261,9 +1269,9 @@ class Connectivity(np.ndarray):
         return hi, lo
 
 
-    # TODO: This is currently far from general!!!
-    # should probably be moved to Mesh/TriSurface if needed there
     def combine(self, lo):
+        # TODO: This is currently far from general!!!
+        # should probably be moved to Mesh/TriSurface if needed there
         """Combine two hierarchical Connectivity levels to a single one.
 
         self and lo are two hierarchical Connectivity tables, representing
@@ -1299,7 +1307,8 @@ class Connectivity(np.ndarray):
         elems = lo[self]
         elems1 = np.roll(elems, -1, axis=1)
         for i in range(elems.shape[1]):
-            flags = (elems[:, i, 1] != elems1[:, i, 0]) * (elems[:, i, 1] != elems1[:, i, 1])
+            flags = (elems[:, i, 1] != elems1[:, i, 0]) * (
+                elems[:, i, 1] != elems1[:, i, 1])
             elems[flags, i] = np.roll(elems[flags, i], 1, axis=1)
         return Connectivity(elems[:, :, 0])
 
@@ -1335,9 +1344,9 @@ class Connectivity(np.ndarray):
         return lo[ind]
 
 
-    # BV: UNTESTED !
-    def reorderNodes(schemes, reverse=False):
-        """_Convert Connectivity to/from foreign node numbering schemes.
+    def reorderNodes(self, schemes, reverse=False):
+        # TODO: THIS IS UNTESTED! DO NOT USE!
+        """_Convert Elems to/from foreign node numbering schemes.
 
         The order in which the element's nodes are numbered internally in
         pyFormex may be different than the numbering scheme used in external
@@ -1350,23 +1359,21 @@ class Connectivity(np.ndarray):
         schemes: dict
             A dict having pyFormex element names as keys and
             the matching nodal permutation arrays as values. The length of
-            the array should match the plexitude of the Connectivity.
+            the array should match the plexitude of the Elems.
         reverse: bool
             If True, the conversion is from external to internal.
-            In this case, the Connectivity's eltype is interpreted as the
+            In this case, the Elems eltype is interpreted as the
             pyFormex target element type (and should be set beforehand).
 
         Returns
         -------
         Connectivity
-            If the Connectivity has an element type and `scheme` has a key
-            matching the element's name, a Connectivity with the renumbered
-            elements is returned.
+            If `schemes` has a key matching the element's name, a Connectivity
+            with the renumbered elements is returned.
 
             - If `reverse` is False (default), the renumbering is done according
-              to the permutation given by the `scheme` value matching the
-              element name and the returned Connectivity will have no element
-              type.
+              to the permutation given by the `schemes` value matching the
+              element name and a Connectivity without eltype is returned.
 
             - If `reverse` is True, the permutation scheme is reversed prior
               to using it. The target element type is retained in the returned
@@ -1377,11 +1384,11 @@ class Connectivity(np.ndarray):
 
         """
         if self.eltype is not None:
-            eltype = ElementType(self.eltype)
+            eltype = self.elName()
             key = eltype.name()
-            if key in scheme:
+            if key in schemes:
                 print('key = %s' % key)
-                trl = scheme[key]
+                trl = schemes[key]
                 print('trl = %s' % trl)
                 elems = self[trl]
                 if not reverse:
@@ -1396,7 +1403,7 @@ class Connectivity(np.ndarray):
 
         Parameters
         ----------
-        elist: int :term:
+        elist: int :term:`array_like`
             List of element numbers. If not specified,
             all elements are considered.
 
@@ -1421,7 +1428,7 @@ class Connectivity(np.ndarray):
         else:
             elems = self[elist]
         m, u = at.multiplicity(elems.ravel())
-        return u[m==len(elems)]
+        return np.asarray(u[m==len(elems)])
 
 
     def replic(self, n, inc):
@@ -1534,7 +1541,9 @@ class Connectivity(np.ndarray):
         [array([[0, 1],
            [1, 1]]), array([[3, 1]]), array([[2, 1]])]
         """
-        elems = self[:,[0, -1]]    # this allows for plexitudes > 2
+        elems = self[:, [0, -1]]    # this allows for plexitudes > 2
+        # Make sure we own the data and can write to it
+        elems = np.require(elems, requirements=['O', 'W'])
         elnrs = np.arange(elems.shape[0])  # original element numbers
         if disconnect == 'branch':
             disconnect = np.where(elems.nParents() > 2)[0]
@@ -1581,7 +1590,7 @@ class Connectivity(np.ndarray):
                 rev = w[-1][0] > 0  # check if the target node is the first or last
 
             indi = ind[:ie]  # get the relevant part
-            indi[:,0] = elnrs[indi[:, 0]]  # translate element numbers
+            indi[:, 0] = elnrs[indi[:, 0]]  # translate element numbers
             chains.append(indi.copy())
             todo = (elems!=-1).any(axis=1)
             elems = elems[todo]
@@ -1595,16 +1604,16 @@ class Connectivity(np.ndarray):
             return chains
 
         conn = []
-        for i,c in enumerate(chains):
-            if c[:,1].sum() < 0:
-                c[:,1] = - c[:,1]
+        for i, c in enumerate(chains):
+            if c[:, 1].sum() < 0:
+                c[:, 1] = - c[:, 1]
                 chains[i] = c = c[::-1]
-            e = c[:,0]
-            d = c[:,1] == -1
+            e = c[:, 0]
+            d = c[:, 1] == -1
             els = self[e]
-            els[d] = els[d,::-1]
+            els[d] = els[d, ::-1]
             conn.append(els)
-        return chains,conn
+        return chains, conn
 
 
     def chained(self, disconnect=None):
@@ -1717,7 +1726,8 @@ class Connectivity(np.ndarray):
                 else:
                     raise TypeError
         except TypeError:
-            raise TypeError('Connectivity.connect(): first argument should be a list of Connectivities')
+            raise TypeError("Connectivity.connect(): first argument "
+                            "should be a list of Connectivities")
 
         if not nodid:
             nodid = [0 for i in range(m)]
@@ -1744,6 +1754,7 @@ def _elem_adj(inv, els, check):
     adj = inv[els].reshape((els.shape[0], -1))
     return Adjacency(adj, check_max=check)
 
+
 def _elem_adj_multi(inv, els, nproc=-1):
     from pyformex import multi
     datablocks = at.splitar(els, nproc)
@@ -1753,13 +1764,15 @@ def _elem_adj_multi(inv, els, nproc=-1):
     return multi.multitask(tasks, nproc=nproc)
 
 
-
 ######################################
 # Deprecated
 
-@utils.deprecated_by("connectivity.connectedLineElems","Connectivity.chained")
-def connectedLineElems(elems, *args,**kargs):
-    return elems.chained()
+
+@utils.deprecated("depr_connectedLineElems")
+def connectedLineElems(elems, *args, **kargs):
+    raise NotImplementedError(
+        "connectedLineElems has been removed. "
+        "You should use Connectivity.chained or Connectivity.chain instead.")
 
 
 # End
