@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -37,15 +37,19 @@ specialisation of the :class:`~connectivity.Connectivity` using an
 ElementType instance as the eltype. The Elems class is one of the basic
 data holders in the :class:`Mesh` model.
 """
-from __future__ import absolute_import, division, print_function
+
+#flake8: noqa
 
 import re
+from collections import OrderedDict
+
 import numpy as np
 
 from pyformex import arraytools as at
 from pyformex.coords import Coords
 from pyformex.connectivity import Connectivity
-from collections import OrderedDict
+from pyformex import simple
+from pyformex import utils
 
 
 class ElementType(object):
@@ -54,7 +58,7 @@ class ElementType(object):
     ElementType instances store all data that define a particular geometrical
     entity type and that can not be derived from the plexitude.
     The class is mostly a storage of provided (and sanitized) data.
-    All succesfully created elements are stored in the class-owned
+    All successfully created elements are stored in the class-owned
     :attr:`register`, from where they can be looked up by their name.
 
 
@@ -102,7 +106,7 @@ class ElementType(object):
         If the element contains faces of different plexitudes, they
         should be specified with the highest plexitude and degenerate
         elements should be used for the lower plexitude faces.
-    *kargs: keyword arguments
+    **kargs: keyword arguments
         Other keyword arguments are stored in the ElementType as is.
         These can also be set after initialization by direct assignment
         to the instance's attribute. Below are some predefined values
@@ -336,7 +340,6 @@ class ElementType(object):
         Line3.degenerate[Point] = [(((0, 2), ), (0, ))]
 
 
-
     Attributes
     ----------
     register: dict
@@ -371,15 +374,33 @@ class ElementType(object):
     # - getAlignedCoords(): return coords between 0 ad 1 and aligned on 0 in all
     #   directions
 
-    def __init__(self,name, doc, ndim, vertices, edges=None, faces=None, **kargs):
+
+    def __new__(clas, *args, **kargs):
+        """Create a new ElementType instance"""
+        # This is here to make sure that all 'ElementType' instances have a
+        # _name, even when they are created by unpickling (which does
+        # not call __init__). This helps in solving some problems with
+        # reading back old pickles, which stored the full ElementType
+        # with all its data. Newer versions now only store the
+        # name of the ElementType.
+        # TODO: We should probably convert the ElementType instances
+        # to singleton classes. That would have avoided these problems,
+        # as classes are always pickled by name.
+        instance = super().__new__(clas)
+        instance._name = "no_name"
+        return instance
+
+
+    def __init__(self, name, doc, ndim, vertices, edges=None, faces=None,
+                 **kargs):
         name = name.capitalize()
-        if name in ElementType.register:
+        if name.lower() in ElementType.register:
             raise ValueError("Element type %s already exists" % name)
 
         self._name = name
         self.doc = str(doc)
         if ndim in range(4):
-           self.ndim = int(ndim)
+            self.ndim = int(ndim)
         else:
             raise ValueError("ndim should be in range(4)")
         self.vertices = Coords(vertices)
@@ -392,7 +413,6 @@ class ElementType(object):
         # sanitize these valid options
         for a in ['drawgl2edges', 'drawgl2faces']:
             if a in kargs:
-                #print(kargs[a])
                 D[a] = self._sanitize(kargs[a])
                 del kargs[a]
         # reject these obsolete options
@@ -405,17 +425,17 @@ class ElementType(object):
 
         # register the element
         ElementType.register[name.lower()] = self
-        #print(self)
 
-    # TODO: remove this: just specify an Elems ?
-    def _sanitize(self,ent):
+
+    def _sanitize(self, ent):
+        # TODO: remove this: just specify an Elems ?
         # input is Elems or Connectivity or (table,eltype)
         # output is Elems
         if isinstance(ent, Elems):
             return ent
         elif isinstance(ent, Connectivity):
             if hasattr(ent, 'eltype'):
-                return Elems(ent,ent.eltype)
+                return Elems(ent, ent.eltype)
             else:
                 raise ValueError("Connectivity should have an element type")
         else:
@@ -508,19 +528,19 @@ class ElementType(object):
         return self.getEntities(3)
 
     def getElement(self):
-        """Return the element connectivity: the entity od level self.ndim"""
+        """Return the element connectivity: the entity of level self.ndim"""
         return self.getEntities(self.ndim)
 
     def getDrawFaces(self, quadratic=False):
         """Return the local connectivity for drawing the element's faces"""
         if not hasattr(self, 'drawgl2faces'):
-            self.drawgl2faces = self.getFaces()#.reduceDegenerate()
+            self.drawgl2faces = self.getFaces()  # .reduceDegenerate()
         return self.drawgl2faces
 
     def getDrawEdges(self, quadratic=False):
         """Return the local connectivity for drawing the element's edges"""
         if not hasattr(self, 'drawgl2edges'):
-            self.drawgl2edges = self.getEdges()#.reduceDegenerate()
+            self.drawgl2edges = self.getEdges()  # .reduceDegenerate()
         return self.drawgl2edges
 
     def toMesh(self):
@@ -652,7 +672,7 @@ class ElementType(object):
         if isinstance(eltype, ElementType):
             return eltype
 
-        if isinstance(eltype,str):
+        if isinstance(eltype, str):
             eltype = eltype.lower()
             if eltype in ElementType.register:
                 return ElementType.register[eltype]
@@ -747,17 +767,17 @@ class Elems(Connectivity):
     """
     def __new__(self, data, eltype):
         """Create a new Elems"""
-        if not isinstance(data,Connectivity):
+        if not isinstance(data, Connectivity):
             data = Connectivity(data=data, eltype=eltype)
         try:
-            eltype = ElementType.get(eltype,data.nplex())
+            eltype = ElementType.get(eltype, data.nplex())
         except Exception:
             raise ValueError("Not a valid eltype: %s" % eltype)
         if not isinstance(eltype, ElementType):
             raise ValueError("Not a valid eltype: %s" % eltype)
         if eltype.nplex() != data.nplex():
             raise ValueError("Data plexitude (%s) != eltype plexitude (%s)" %
-                             (data.nplex(),eltype.nplex()))
+                             (data.nplex(), eltype.nplex()))
         data.eltype = eltype
         return data.view(self)
 
@@ -765,10 +785,27 @@ class Elems(Connectivity):
     def __repr__(self):
         """String representation of an Elems"""
         res = np.ndarray.__repr__(self)
-        res = res.replace(')', ", eltype=%s)" % self.eltype._name)
+        res = re.sub("[)]$", f", eltype={self.eltype._name})", res)
         return res
 
 
+    def __setstate__(self, state):
+        """Allow an Elems to be properly unpickled"""
+        # An Elems is pickled like a Connectivity, with the
+        # ElementType's name as eltype.
+        # After unpickling, the eltype should be converted
+        # to an ElementType.
+        Connectivity.__setstate__(self, state)
+        if isinstance(self.eltype, str):
+            self.eltype = ElementType.get(self.eltype)
+        else:
+            # This is a FIX for old pickles that stored full ElementType data
+            name = self.eltype.__dict__.get('_name', None)
+            if name == 'no_name':
+                name = None
+            self.eltype = ElementType.get(name, self.shape[1])
+
+
     def levelSelector(self, level):
         """Return a selector for lower level entities.
 
@@ -785,7 +822,7 @@ class Elems(Connectivity):
             ``(self.nelems*selector.nelems,selector.nplex)``.
         """
         sel = self.eltype.getEntities(level)
-        return Elems(sel,sel.eltype)
+        return Elems(sel, sel.eltype)
 
 
     def selectNodes(self, selector):
@@ -823,7 +860,7 @@ class Elems(Connectivity):
             selector = self.levelSelector(selector)
         else:
             selector = Connectivity(selector)
-        lo = Connectivity.selectNodes(self,selector)
+        lo = Connectivity.selectNodes(self, selector)
         clas = Elems if lo.eltype is not None else Connectivity
         return clas(lo, eltype=lo.eltype)
 
@@ -893,7 +930,7 @@ class Elems(Connectivity):
             selector = self.levelSelector(selector)
         else:
             selector = Connectivity(selector)
-        hi, lo = Connectivity.insertLevel(self,selector)
+        hi, lo = Connectivity.insertLevel(self, selector)
         lo.eltype = selector.eltype
         return hi, lo
 
@@ -1015,7 +1052,7 @@ class Elems(Connectivity):
                 try:
                     w = (e[:, cond[:, 0]] == e[:, cond[:, 1]]).all(axis=1)
                     sel = np.where(w)[0]
-                except:
+                except Exception:
                     raise ValueError(
                         "Invalid data in %s.degenerate:\n%s = %s" % (
                             self.eltype, totype, (conditions, selector)))
@@ -1087,10 +1124,10 @@ class Elems(Connectivity):
         """
         try:
             eltype, reorder = self.eltype.extruded[degree]
-        except:
+        except Exception:
             try:
                 eltype = self.eltype.name()
-            except:
+            except Exception:
                 eltype = None
             raise ValueError("I don't know how to extrude an Elems"
                              "of eltype '%s' in degree %s" % (eltype, degree))
@@ -1102,6 +1139,70 @@ class Elems(Connectivity):
         return Elems(elems, eltype=eltype)
 
 
+    def getFreeEntities(self, level=-1, return_indices=False):
+        """Return the free entities of the specified level.
+
+        Parameters
+        ----------
+        level: int
+            The :term:`level` of the entities to return. If negative,
+            it is a value relative to the level of the caller. If non-negative,
+            it specifies the absolute level.
+        return_indices: bool
+            If True, also returns an index array (nentities,2) for inverse
+            lookup of the higher entity (column 0) and its local
+            lower entity number (column 1).
+
+        Returns
+        -------
+        :class:`~elements.Elems`
+            A connectivity table with the free entities of the
+            specified level. Free entities are entities
+            that are only connected to a single element.
+
+        See Also
+        --------
+        :meth:`Mesh.getFreeEntities`: return the free entities of a Mesh
+        :meth:`Mesh.getBorder`: return the border entities of a Mesh
+
+        Examples
+        --------
+        >>> elems = Elems([[0, 1, 3], [3, 2, 0]], eltype='tri3')
+        >>> elems.getFreeEntities(1)
+        Elems([[0, 1],
+               [1, 3],
+               [3, 2],
+               [2, 0]], eltype=Line2)
+        >>> elems.getFreeEntities(1,True)[1]
+        array([[0, 0],
+               [0, 1],
+               [1, 0],
+               [1, 1]])
+
+        """
+        hi, lo = self.insertLevel(level)
+        if hi.size == 0:
+            if return_indices:
+                return Connectivity(), []
+            else:
+                return Connectivity()
+
+        hiinv = hi.inverse(expand=True)
+        ncon = (hiinv>=0).sum(axis=1)
+        isbrd = (ncon<=1)   # < 1 should not occur
+        brd = lo[isbrd]
+        if not return_indices:
+            return brd
+
+        # also return indices where the border elements come from
+        binv = hiinv[isbrd]
+        enr = binv[binv >= 0]  # element number
+        a = hi[enr]
+        b = np.arange(lo.shape[0])[isbrd].reshape(-1, 1)
+        fnr = np.where(a==b)[1]   # local border part number
+        return brd, np.column_stack([enr, fnr])
+
+
 #######################################################################
 # The collection of default pyFormex elements
 #############################################
@@ -1195,10 +1296,10 @@ Tri6.drawgl2edges = Tri6.edges.selectNodes(Line3.drawgl2faces)
 Quad4 = ElementType(
     'quad4', "A 4-node quadrilateral",
     ndim = 2,
-    vertices = [(0.0,  0.0, 0.0),
-                (1.0,  0.0, 0.0),
-                (1.0,  1.0, 0.0),
-                (0.0,  1.0, 0.0),
+    vertices = [(0.0, 0.0, 0.0),
+                (1.0, 0.0, 0.0),
+                (1.0, 1.0, 0.0),
+                (0.0, 1.0, 0.0),
     ],
     edges = Elems([(0, 1), (1, 2), (2, 3), (3, 0)], Line2),
     drawgl2faces = Elems([(0, 1, 3), (1, 2, 3)], Tri3),
@@ -1209,8 +1310,8 @@ Quad6 = ElementType(
     ndim = 2,
     vertices = Coords.concatenate([
         Quad4.vertices,
-        [(0.5,  0.0, 0.0),
-         (0.5,  1.0, 0.0),
+        [(0.5, 0.0, 0.0),
+         (0.5, 1.0, 0.0),
         ]]),
     edges = Elems([(0, 4, 1), (1, 1, 2), (2, 5, 3), (3, 3, 0)], Line3),
     reversed = (3, 2, 1, 0, 5, 4),
@@ -1228,15 +1329,16 @@ Quad8 = ElementType(
     ndim = 2,
     vertices = Coords.concatenate([
         Quad4.vertices,
-        [(0.5,  0.0, 0.0),
-         (1.0,  0.5, 0.0),
-         (0.5,  1.0, 0.0),
-         (0.0,  0.5, 0.0),
+        [(0.5, 0.0, 0.0),
+         (1.0, 0.5, 0.0),
+         (0.5, 1.0, 0.0),
+         (0.0, 0.5, 0.0),
         ]]),
     edges = Elems([(0, 4, 1), (1, 5, 2), (2, 6, 3), (3, 7, 0)], Line3),
     reversed = (3, 2, 1, 0, 6, 5, 4, 7),
-    # drawfaces = [('tri3', [(0, 4, 7), (1, 5, 4), (2, 6, 5), (3, 7, 6)]), ('quad4', [(4, 5, 6, 7)], )],
-    #drawfaces2 = [('quad8', [(0, 1, 2, 3, 4, 5, 6, 7)], )],
+    # drawfaces = [('tri3', [(0, 4, 7), (1, 5, 4), (2, 6, 5), (3, 7, 6)]),
+    #              ('quad4', [(4, 5, 6, 7)], )],
+    # drawfaces2 = [('quad8', [(0, 1, 2, 3, 4, 5, 6, 7)], )],
     drawgl2faces = Elems([(0, 4, 7), (1, 5, 4), (2, 6, 5), (3, 7, 6),
                           (4, 5, 6), (4, 6, 7)], Tri3),
 )
@@ -1247,7 +1349,7 @@ Quad9 = ElementType(
     ndim = 2,
     vertices = Coords.concatenate([
         Quad8.vertices,
-        [(0.5,  0.5, 0.0),
+        [(0.5, 0.5, 0.0),
         ]]),
     edges = Quad8.edges,
     reversed = (3, 2, 1, 0, 6, 5, 4, 7, 8),
@@ -1263,14 +1365,14 @@ Quad12 = ElementType(
     ndim = 2,
     vertices = Coords.concatenate([
         Quad4.vertices,
-        [(e3,  0.0, 0.0),
+        [(  e3,  0.0, 0.0),
          (2*e3,  0.0, 0.0),
-         (1.0,   e3, 0.0),
-         (1.0, 2*e3, 0.0),
+         (1.0,    e3, 0.0),
+         (1.0,  2*e3, 0.0),
          (2*e3,  1.0, 0.0),
-         (e3,  1.0, 0.0),
-         (0.0, 2*e3, 0.0),
-         (0.0,   e3, 0.0),
+         (  e3,  1.0, 0.0),
+         ( 0.0, 2*e3, 0.0),
+         ( 0.0,   e3, 0.0),
         ]]),
     edges = Elems([(0, 4, 5, 1), (1, 6, 7, 2), (2, 8, 9, 3), (3, 10, 11, 0)],
                   Line4),
@@ -1317,12 +1419,11 @@ Tet10 = ElementType(
         ]]),
     edges = Elems([(0, 4, 1), (1, 7, 2), (2, 5, 0), (0, 6, 3), (1, 9, 3),
                    (2, 8, 3)], Line3),
-    faces = Elems(np.array([(0, 2, 1, 5, 7, 4), (0, 1, 3, 4, 9, 6),
-                            (0, 3, 2, 6, 8, 5), (1, 2, 3, 7, 8, 9)])[:, [
-                                (0, 3, 5), (3, 1, 4), (4, 2, 5),
-                                (3, 4, 5)]].reshape(-1, 3), Tri3),
+    faces = Elems([(0, 2, 1, 5, 7, 4), (0, 1, 3, 4, 9, 6),
+                   (0, 3, 2, 6, 8, 5), (1, 2, 3, 7, 8, 9)], Tri6),
     reversed = (0, 1, 3, 2, 4, 6, 5, 9, 8, 7),
 )
+Tet10.drawgl2faces = Tet10.faces.selectNodes(Tri6.drawgl2faces)
 Tet10.drawgl2edges = Tet10.edges.selectNodes(Line3.drawgl2faces)
 
 Tet14 = ElementType(
@@ -1336,12 +1437,11 @@ Tet14 = ElementType(
          (e3, e3, e3),
         ]]),
     edges = Tet10.edges,
-    faces = Elems(
-        np.array([(0, 2, 1, 5, 7, 4, 10), (0, 1, 3, 4, 9, 6, 11),
-                  (0, 3, 2, 6, 8, 5, 12), (1, 2, 3, 2, 7, 8, 13)])[:, [
-                      (0, 3, 6), (3, 1, 6), (1, 4, 6), (4, 2, 6), (2, 5, 6),
-                      (5, 0, 6)]].reshape(-1, 3), Tri3),
+    faces = Tet10.faces,  # We do not have a Tri7 yet!
+    # faces = Elems([(0, 2, 1, 5, 7, 4, 10), (0, 1, 3, 4, 9, 6, 11),
+    #                (0, 3, 2, 6, 8, 5, 12), (1, 2, 3, 2, 7, 8, 13)]), Tri7)
     reversed = (0, 1, 3, 2, 4, 6, 5, 9, 8, 7, 12, 11, 10, 13),
+    drawgl2faces = Tet10.drawgl2faces,
     drawgl2edges = Tet10.drawgl2edges,
 )
 
@@ -1352,10 +1452,11 @@ Tet15 = ElementType(
         Tet14.vertices,
         [(0.25, 0.25, 0.25),
         ]]),
-    edges = Tet10.edges,
+    edges = Tet14.edges,
     faces = Tet14.faces,
     reversed = (0, 1, 3, 2, 4, 6, 5, 9, 8, 7, 12, 11, 10, 13, 14),
-    drawgl2edges = Tet10.drawgl2edges,
+    drawgl2faces = Tet14.drawgl2faces,
+    drawgl2edges = Tet14.drawgl2edges,
 )
 
 ###############
@@ -1463,13 +1564,12 @@ Hex20.drawgl2faces = Hex20.faces.selectNodes(Quad8.drawgl2faces)
 # THIS ELEMENT USES A REGULAR NODE NUMBERING!!
 # WE MIGHT SWITCH OTHER ELEMENTS TO THIS REGULAR SCHEME TOO
 # AND ADD THE RENUMBERING TO THE FE OUTPUT MODULES
-from pyformex.simple import regularGrid
 Hex27 = ElementType(
     'hex27', "A 27-node hexahedron",
     ndim = 3,
     # !! Add swapaxes=False to silence warning
-    vertices = regularGrid([0., 0., 0.], [1., 1., 1.], [2, 2, 2],
-                           swapaxes=False).reshape(-1, 3),
+    vertices = simple.regularGrid([0., 0., 0.], [1., 1., 1.], [2, 2, 2],
+                                  swapaxes=False).reshape(-1, 3),
     edges = Elems([(0, 1, 2), (6, 7, 8), (18, 19, 20), (24, 25, 26),
                   (0, 3, 6), (2, 5, 8), (18, 21, 24), (20, 23, 26),
                    (0, 9, 18), (2, 11, 20), (6, 15, 24), (8, 17, 26)], Line3),
@@ -1767,7 +1867,7 @@ Quad8.extruded = {
     2: (Hex20, [0, 1, 2, 3, 16, 17, 18, 19, 4, 5, 6, 7,
                 20, 21, 22, 23, 8, 9, 10, 11])}
 # BV: If Quad9 would be numbered consecutively, extrusion would be as easy as
-#Quad9.extruded = { 2: (Hex27, [] }
+# Quad9.extruded = { 2: (Hex27, [] }
 Quad9.extruded = {2: (Hex27, [0, 4, 1, 7, 8, 5, 3, 6, 2,
                               9, 13, 10, 16, 17, 14, 12, 15, 11,
                               18, 22, 19, 25, 26, 23, 21, 24, 20, ])}
@@ -1812,7 +1912,6 @@ Wedge6.degenerate = {
 }
 
 
-from pyformex import utils
 @utils.deprecated_by("elementType","ElementType.get")
 def elementType(*args,**kargs):
     return ElementType.get(*args,**kargs)
