@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -31,7 +31,6 @@ Make sure you have version 1.5-a8 or higher.
 
 See example BeamFreq for a version that does not require calix.
 """
-from __future__ import absolute_import, division, print_function
 
 
 _status = 'checked'
@@ -40,12 +39,11 @@ _topics = ['FEA', 'curve', 'drawing']
 _techniques = ['external', 'viewport']
 
 from pyformex.gui.draw import *
-from pyformex.plugins.curve import *
-from pyformex import simple
+from pyformex.plugins.curve import NaturalSpline
 
-def check_calix(version='1.5-a8'):
+def check_calix(version='>= 1.5-a8'):
     """Check that we have the required calix version"""
-    ok = utils.checkVersion('calix', version, True) >= 0
+    ok = utils.External.check('calix', version)
     if not ok:
         showText("""..
 
@@ -168,7 +166,7 @@ stop
 
         if verbose:
             # show calix output
-            showText(P.out)
+            showText(P.stdout)
             showFile('temp.res')
             showFile('test.out')
 
