@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -29,7 +29,6 @@ topics = ['geometry','curve']
 techniques = ['connect','color','solve']
 
 """
-from __future__ import absolute_import, division, print_function
 
 
 _status = 'checked'
@@ -50,10 +49,7 @@ def build_matrix(atoms, vars):
     A matrix is returned where each row contains the values of atoms evaluated
     for one set of the variables.
     """
-    if pf.PY3:
-        keys = list(vars)
-    else:
-        keys = vars.keys()
+    keys = list(vars)
     nval = len(vars[keys[0]])
     aa = zeros((nval, len(atoms)), Float)
     for k, a in enumerate(atoms):
