@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -25,7 +25,6 @@
 
 Perform boolean operations on surfaces
 """
-from __future__ import absolute_import, division, print_function
 
 _status = 'checked'
 _level = 'normal'
@@ -37,44 +36,30 @@ from pyformex.simple import cylinder
 from pyformex.trisurface import fillBorder
 
 
-def splitAlongPath(path, mesh, atol=0.0):
-    '''
-    Given split mesh into opposite regions along a closed path matching coords of mesh
-    '''
-    cpath= Mesh(mesh.coords, mesh.getEdges()).matchCentroids(path)
-    mask=complement(cpath, mesh.getEdges().shape[0])
-    p=mesh.maskedEdgeFrontWalk(mask=mask, frontinc=0)
-    msplit=mesh.setProp(p)
-    return msplit
-
-
 def drawResults(**res):
-
-    op = res['op'][0]
+    op = res['op'].split()[0]
     verbose = res['verbose']
-    split = res['split']
-    path = None
-    if op in '+-*':
-        I = F.boolean(G, op, verbose=verbose)
-        if split:
-            path = F.intersection(G, verbose=verbose)
-            I = splitAlongPath(path.toMesh(), I.fuse(atol=0).compact())  # with atol = 0 removes repeted nodes which may results after boolean operation
+    scale = res['scale 2']
+    rot = res['rot 2']
+    trl = res['trl 2']
+    # Compute result of operation
+    G = F.scale(scale).rotate(rot, 0).trl(0, trl).setProp(1)
+
+    if op == 'I':
+        R = F.intersection(G, verbose=verbose)
     else:
-        I = F.intersection(G, verbose=verbose)
+        R = F.gts_set(G, op, prop=[2,2,1,1], verbose=verbose)
     clear()
-    draw(I)
+    draw(R)
 
-    if op in '+-*':
-        return
-
-    else:
+    if op == 'I':
         if ack('Create a surface inside the curve ?'):
-            I = I.toMesh()
-            e = I.elems.chained()
-            I = Mesh(I.coords, I.elems.chained()[0])
+            R = R.toMesh()
+            e = R.elems.chained()
+            R = Mesh(R.coords, R.elems.chained()[0])
             clear()
-            draw(I, color=red, linewidth=3)
-            S = fillBorder(I, method='planar')
+            draw(R, color=red, linewidth=3)
+            S = fillBorder(R, method='planar')
             draw(S)
 
 
@@ -102,7 +87,8 @@ def run():
     smooth()
     view('iso')
     F = cylinder(L=8., D=2., nt=36, nl=20, diag='u').centered()
-    F = TriSurface(F).setProp(3).close(method='planar').fixNormals().fuse().compact()
+    F = TriSurface(F).close(method='planar').fixNormals().fuse().compact()
+    F = F.setProp(2)
     G = F.rotate(90., 0).trl(0, 1.).setProp(1)
     export({'F': F, 'G': G})
     draw([F, G])
@@ -110,20 +96,20 @@ def run():
     _items =\
         [_I('op', text='Operation', choices=[
             '+ (Union)',
-            '- (Difference)',
-            '* Intersection',
-            'Intersection Curve',
+            '* (Intersection)',
+            '- (Difference 1-2)',
+            '2- (Difference 2-1)',
+            '^ (Symmetric difference)',
+            'I (Intersection curve)',
             ]),
-          _I('split', False, text='Split along intersection'),
-          _I('verbose', False, text='Show stats'),
+         _I('verbose', False, text='Verbose'),
+         _I('scale 2', 1.0),
+         _I('rot 2', 90.),
+         _I('trl 2', 1.),
         ]
-    _enablers = [('op', '+ (Union)', 'split'),
-        ('op', '- (Difference)', 'split'),
-        ('op', '* Intersection', 'split'), ]
 
     dialog = Dialog(
         items=_items,
-        enablers=_enablers,
         actions=[('Close', close), ('Show', show)],
         default='Show')
 
