@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -42,7 +42,6 @@ During the display of the first half of the set of texts,
 the previous text is removed after each new one is shown.
 During the second half, all texts remain on the canvas.
 """
-from __future__ import absolute_import, division, print_function
 
 
 _status = 'checked'
@@ -55,7 +54,9 @@ from pyformex.opengl.textext import *
 
 def run():
     n = 40
-    T = ['Python', 'NumPy', 'OpenGL', 'QT4', 'pyFormex']
+    T = ['Python', 'NumPy', 'OpenGL',
+         'Qt4' if pf.gui.bindings in ['pyside', 'pyqt4'] else 'Qt5',
+         'PIL', 'pyFormex']
     fonts = utils.listMonoFonts()
 
     ftmin, ftmax = 12, 48
