@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -31,7 +31,6 @@ installed.
 The pyFormex source repository contains a directory pyformex/extra/pyftgl
 containing a Makefile to install the libraries.
 """
-from __future__ import absolute_import, division, print_function
 
 
 _status = 'checked'
@@ -49,13 +48,12 @@ class FontOutline(object):
 
     """
     def __init__(self, filename, size):
-        """Initialize a FontTexture"""
-        #Geometry.__init__(self)
-        print("Creating FontTexture(%s) in size %s" % (filename, size))
+        """Initialize a FontOutline"""
+        print("Creating FontOutline(%s) in size %s" % (filename, size))
         face = ft.Face(str(filename))
         face.set_char_size(int(size*64))
-        if not face.is_fixed_width:
-            raise RuntimeError("Font is not monospace")
+        # if not face.is_fixed_width:
+        #     raise RuntimeError("Font is not monospace")
         self.face = face
 
     def outline(self, c):
@@ -74,7 +72,8 @@ def pointsToContour(points, tags):
         if elem:
             elem.append(i)
             if len(elem) > 4:
-                raise ValueError("Too many points (%s) in stroke %s" % (len(elem), len(elems)))
+                raise ValueError(
+                    f"Too many points ({len(elem)}) in stroke {len(elems)}")
             elems.append(elem)
 
     for i, t in enumerate(tags):
@@ -99,15 +98,12 @@ def outlineToCurve(outline):
     return out
 
 
-def drawChar(c):
+def drawChar(font, c):
     clear()
     CO = font.outline(c)
     O = outlineToCurve(CO)
     C = O[0]
-    print("nparts: %s" % C.nparts)
-    print(C.stroke((C.nparts)-1))
-    draw(O, clear=True)
-    #draw(C.approx())
+    draw(O.approx(chordal=0.001), clear=True)
     X = Coords(CO.points)
     draw(X)
     drawNumbers(X)
@@ -115,7 +111,7 @@ def drawChar(c):
 
 def callback(item):
     c = item.value()
-    drawChar(c)
+    drawChar(font, c)
 
 def setFont(default):
     global font
@@ -123,7 +119,7 @@ def setFont(default):
 
 
 def run():
-    fonts = utils.listMonoFonts()
+    fonts = utils.listMonoFonts() + [ pf.cfg['datadir'] / 'blippok.ttf' ]
     default = utils.defaultMonoFont()
     setFont(default)
 
@@ -137,7 +133,7 @@ def run():
     default = res['font']
     setFont(default)
     c = res['char']
-    drawChar(c)
+    drawChar(font, c)
 
 
 if __name__ == '__draw__':
