@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -26,7 +26,6 @@
 Saves the contour of an object as shown in the viewport.
 
 """
-from __future__ import absolute_import, division, print_function
 
 
 _status = 'checked'
@@ -35,8 +34,9 @@ _topics = ['geometry', 'rendering']
 _techniques = ['outline', 'contour']
 
 from pyformex.gui.draw import *
-
 import pyformex as pf
+from pyformex.candy import Horse
+
 
 def outlineBox(F, axis, dmin, dmax):
     """Construct an outlinebox from an outline curve
@@ -58,7 +58,7 @@ def run():
     resetAll()
     smooth()
     clear()
-    S = TriSurface.read(getcfg('datadir') / 'horse.off')
+    S = Horse()
     perspective(False)
     SA = draw(S)
     setDrawOptions(view='cur', bbox=None)
