@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -29,7 +29,6 @@ of the cube are drawn as triangles or as quadrilaterals, and what color
 scheme is to be used: no color (black), a single color, a single color per
 face, or a color gradient over the faces.
 """
-from __future__ import absolute_import, division, print_function
 
 
 _status = 'checked'
@@ -66,15 +65,15 @@ def cube_tri(color=None):
 
 def cube_quad(color=None):
     """Create a cube with quadrilaterals."""
-    v = Hex8.vertices
-    f = Hex8.faces
-    faces = Formex(v[f], eltype=f.eltype)
+    coords = Hex8.vertices
+    elems = Hex8.faces
+    faces = Mesh(coords,elems)
     if color == 'Single':
         color = 'red'
     elif color == 'Face':
         color = [4, 1, 5, 2, 6, 3]
     elif color == 'Full':
-        color = array([7, 6, 4, 5, 3, 2, 0, 1])[f]
+        color = array([7, 6, 4, 5, 3, 2, 0, 1])[elems]
     faces.attrib(color=color)
     return faces
 
