@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -39,7 +39,6 @@ The application shows two viewports. In the left viewport element per
 element interpolation is shown. The right viewport shows the result of the
 nodal averaging.
 """
-from __future__ import absolute_import, division, print_function
 
 
 _status = 'checked'
@@ -59,7 +58,7 @@ def run():
     from pyformex.plugins import calpy_itf
     try:
         Q = calpy_itf.QuadInterpolator
-    except:
+    except Exception:
         print("NO CALPY: I'm out of here!")
         return
 
@@ -68,7 +67,7 @@ def run():
     # size of the grid
     nx, ny = 4, 3
     # plexitude
-    nplex = 8
+    nplex = 4
     clear()
     flatwire()
     M = Formex('4:0123').replicm((nx, ny)).toMesh().convert('quad%s'%nplex, fuse=True)
