@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -25,8 +25,6 @@
 """FeAbq
 
 """
-from __future__ import absolute_import, division, print_function
-
 
 _status = 'checked'
 _level = 'advanced'
@@ -35,7 +33,7 @@ _techniques = ['persistence', 'dialog', 'color']
 
 from pyformex.gui.draw import *
 
-from pyformex.plugins.fe import mergedModel
+from pyformex.plugins.fe import FEModel
 from pyformex.plugins.properties import PropertyDB, ElemSection, Eset
 from pyformex.plugins.fe_abq import Step, Output, Result, AbqData
 
@@ -120,8 +118,8 @@ def run():
         parts = [p.convert('quad8') for p in parts]
 
     # Create the finite element model
-    # A model contains a single set of nodes and one or more sets of elements
-    M = mergedModel(parts)
+    # A model contains multiple Meshes with a single merged set of nodes
+    M = FEModel(parts)
     #drawFEModel(M)
     #return
 
