@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -29,7 +29,6 @@ steel plate, how to add material properties, boundary conditions and loads,
 and how to export the resulting model as an input file for Abaqus(tm) or
 Calculix.
 """
-from __future__ import absolute_import, division, print_function
 
 _status = 'checked'
 _level = 'advanced'
@@ -38,7 +37,7 @@ _techniques = ['properties', 'export', 'extrude']
 
 from pyformex.gui.draw import *
 
-from pyformex.plugins.fe import *
+from pyformex.plugins.fe import FEModel
 from pyformex.plugins.properties import *
 from pyformex.plugins.fe_abq import Step, Output, Result, AbqData
 from pyformex.plugins import ccxdat
@@ -80,7 +79,7 @@ def run():
 
     # User input
     res = askItems(store=pf.PF['FePlast_diag'], items=[
-        _I('geometry', choices=['Rectangle', 'Square with hole'], text='Plate geometry'),
+        _I('geometry', choices=['Plain rectangle', 'Rectangle with hole'], text='Plate geometry'),
         _I('material', choices=['Elastic', 'Plastic'], text='Material model'),
         _I('eltype', choices=['quad4', 'quad8', 'hex8', 'hex20'], text='Element type'),
         _I('interpolation', choices=['Linear', 'Quadratic'], text='Degree of interpolation'),
@@ -95,10 +94,10 @@ def run():
 
 
     # Create geometry
-    if res['geometry'] == 'Rectangle':
+    if res['geometry'] == 'Plain rectangle':
         plate = rectangle(L2, B2, nl, nb)
     else:
-        plate = rectangleWithHole(L2, B2, r, nl, nb, e0=e0)
+        plate = rectangleWithHole(L2, B2, r, (nl,e0), nb)
 
 
     if res['eltype'].startswith('hex'):
@@ -112,10 +111,10 @@ def run():
     setDrawOptions({'bbox': 'last', 'marksize': 8})
 
     # Assemble the FEmodel (this may renumber the nodes!)
-    FEM = Model(meshes=[plate])
+    FEM = FEModel(meshes=[plate])
 
     # Create an empty property database
-    P = PropertyDB()
+    PDB = PropertyDB()
 
     # Define the material data: here we use an elasto-plastic model
     # for the steel
@@ -159,7 +158,8 @@ def run():
     # Give the elements their properties: this is simple here because
     # all elements have the same properties. The element type is
     # for an Abaqus plain stress quadrilateral element with 4 nodes.
-    P.elemProp(name='Plate', eltype='CPS4', section=ElemSection(section=steel_plate, material=steel))
+    PDB.elemProp(name='Plate', eltype='CPS4',
+                 section=ElemSection(section=steel_plate, material=steel))
 
     # Set the boundary conditions
     # The xz and yz planes should be defined as symmetry planes.
@@ -175,12 +175,12 @@ def run():
 
     # Define the boundary conditions
     # For Abaqus, we could define it like follows
-    #P.nodeProp(tag='init',set=nyz,name='YZ_plane',bound='XSYMM')
-    #P.nodeProp(tag='init',set=nxz,name='XZ_plane',bound='YSYMM')
+    #PDB.nodeProp(tag='init',set=nyz,name='YZ_plane',bound='XSYMM')
+    #PDB.nodeProp(tag='init',set=nxz,name='XZ_plane',bound='YSYMM')
     # But as Calculix does not have the XSYMM/YSYMM possibilities
     # we define the conditions explicitely
-    P.nodeProp(tag='init', set=nyz, name='YZ_plane', bound=[1, 0, 0, 0, 0, 0])
-    P.nodeProp(tag='init', set=nxz, name='XZ_plane', bound=[0, 1, 0, 0, 0, 0])
+    PDB.nodeProp(tag='init', set=nyz, name='YZ_plane', bound=[1, 0, 0, 0, 0, 0])
+    PDB.nodeProp(tag='init', set=nxz, name='XZ_plane', bound=[0, 1, 0, 0, 0, 0])
 
     # The plate is loaded by a uniform tensile stress in the x-direction
     # First we detect the border
@@ -192,7 +192,10 @@ def run():
     # The loaded border elements
     loaded = where(loaded)[0]
     draw(BRD.select(loaded), color=blue, linewidth=4)
-    sortedelems = sortElemsByLoadedFace(ind[loaded])
+    # sort the load elements by the local loaded edge number
+    lind = ind[loaded]
+    samefacerows = collectRowsByColumnValue(ind[loaded], 1)
+    sortedelems = dict((k,ind[loaded][samefacerows[k],0]) for k in samefacerows)
     # Define the load
     # Apply 4 load steps:
     # 1: small load (10 MPa)
@@ -204,10 +207,12 @@ def run():
     for face in sortedelems:
         abqface = face+1  # BEWARE: Abaqus numbers start with 1
         for step, load in zip(steps, loads):
-            P.elemProp(tag=step, set=sortedelems[face], name='Loaded-%s'%face, dload=ElemLoad('P%s'%(abqface), -load))
+            PDB.elemProp(
+                tag=step, set=sortedelems[face], name='Loaded-%s'%face,
+                dload=ElemLoad('P%s'%(abqface), -load))
 
     # Print the property database
-    P.print()
+    PDB.print()
 
     # Create requests for output to the .fil file.
     # - the displacements in all nodes
@@ -232,16 +237,22 @@ def run():
     # The tags refer to the property database
     simsteps = [Step('STATIC', time=[1., 1., 0.01, 1.], tags=[step]) for step in steps]
 
-    data = AbqData(FEM, prop=P, steps=simsteps, res=result, initial=['init'])
+    data = AbqData(FEM, prop=PDB, steps=simsteps, res=result, initial=['init'])
 
+    if not checkWorkdir():
+        raise RuntimeError("Can not write to current workdir")
     fn = askNewFilename(pf.cfg['workdir'] / 'feplast1.inp', filter='inp')
 
     if fn:
         cmd = None
         if res['run']:
             cmd = {'CalculiX': 'ccx', 'Abaqus': 'abaqus'}[res['format']]
-            if not utils.hasExternal(res['format'].lower()):
-                ans = pf.warning("I did not find the command '%s' on your system.\nIf you continue, I can prepare the model and write the input file,but not run the simulation" % cmd, actions=['Cancel', 'Continue'])
+            if not utils.External.has(res['format'].lower()):
+                ans = pf.warning(
+                    "I did not find the command '%s' on your system.\n"
+                    "If you continue, I can prepare the model and write "
+                    "the input file,but not run the simulation" % cmd,
+                    actions=['Cancel', 'Continue'])
                 if ans == 'Continue':
                     cmd = None
                 else:
@@ -257,7 +268,7 @@ def run():
             elif cmd == 'abaqus':
                 cmd == "abaqus job=%s" % job
             P = utils.command("ccx -i %s" % job)
-            print(P.out)
+            print(P.stdout)
 
             if ack('Create the result database?'):
                 DB = ccxdat.createResultDB(FEM)
