@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -26,10 +26,9 @@
 This example demonstrates the use of FontForge library to render text. To be
 able to run it, you need to have the FontForge library and its Python bindings
 installed. On Debian GNU/Linux you can achieve this by installing the package
-'python-fontforge'.
+'python3-fontforge'.
 
 """
-from __future__ import absolute_import, division, print_function
 
 _status = 'checked'
 _level = 'advanced'
@@ -195,7 +194,7 @@ try:
                 try:
                     #from voronoi import voronoi
                     surface = delaunay(border.coords)
-                except:
+                except Exception:
                     #print(sys.path)
                     warning("DELAUNAY fill is not available")
                     surface = []
@@ -249,7 +248,7 @@ try:
         global fonts
 
         if not fonts:
-            fonts =  [f for f in my_fonts if f.exists()] + utils.listAllFonts()
+            fonts =  [f for f in my_fonts if f.exists()] + utils.listFonts()
 
         print("There are %s fonts" % len(fonts))
         print("There are %s monospaced fonts" % len(utils.listMonoFonts()))
@@ -262,7 +261,7 @@ try:
             )
         try:
             data.update(pf.PF['_FontForge_data_'])
-        except:
+        except Exception:
             pass
         print("Number of available fonts: %s" % len(fonts))
         if not data['fontname']:
@@ -281,7 +280,6 @@ try:
         if res['fill'] == 'None':
             del res['fill']
 
-
         show(**res)
 
 
@@ -290,13 +288,13 @@ except ImportError:
 
     def run():
 
-        warning("""\
-I could not import Python%s bindings for fontforge.
-If you want to run this example, first make sure
-that you have fontforge and the proper Python
-bindings, and then try again.""" % ('3' if pf.PY3 else ''))
+        warning("I could not import fontforge. "
+                "To run this example, first make sure that you have "
+                "fontforge and the proper Python bindings. "
+                "E.g.: on Debian/Ubuntu, install 'python3-fontforge'."
+                )
 
-except:
+except Exception:
     raise
 
 
