@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -39,7 +39,6 @@ Then, the original and the transformed structure are first shown
 superimposed, in black and red respectively. Transparency is set on.
 After the pause, the original structure is removed, and transparency is set off.
 """
-from __future__ import absolute_import, division, print_function
 
 _status = 'checked'
 _level = 'normal'
@@ -61,7 +60,7 @@ def run():
     res = askItems([
         _I('geometry', '3D', itemtype='radio', choices=['1D', '2D', '3D']),
         _I('transformation', '3D', itemtype='radio', choices=['1D', '2D', '3D']),
-        _I('Show trf points', False),
+        _I('Show trf points', True),
         ])
     if not res:
         return
@@ -87,12 +86,9 @@ def run():
         tol = 0.01
         d = x1.distanceFromPoint(x1[0])
         w = where((d > 0.5+tol) * (d < 1.0 - tol))[0]
-        # avoid error messages during projection
-        errh = seterr(all='ignore')
         x1[w] = x1.projectOnSphere(0.5)[w]
         w = where(d > 1.+tol)[0]
         x1[w] = x1.projectOnSphere(1.)[w]
-        seterr(**errh)
 
     clear()
     if sdim == 1:
@@ -120,11 +116,12 @@ def run():
 
     if res['Show trf points']:
         print('This is the set of nodes in natural coordinates')
-        draw(x0, color=blue, nolights=True)
+        draw(x0, color=blue, nolights=True, marksize=5)
+        drawNumbers(x0, color=blue)
+        pause()
         print('This is the set of nodes in cartesian coordinates')
-        draw(x1, color=red, nolights=True)
-        drawNumbers(x1, color=red)
-        drawNumbers(x1)
+        draw(x1, color=yellow, nolights=True, marksize=10)
+        drawNumbers(x1, color=yellow)
         pause()
 
     G=F.isopar(eltype.name(), x1.points(), x0.points())
