@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -25,7 +25,6 @@
 
 Find the intersection points of polylines
 """
-from __future__ import absolute_import, division, print_function
 
 
 _status = 'checked'
@@ -55,7 +54,6 @@ def intersection(F1, F2):
 
     from pyformex import geomtools as gt
 
-    errh = seterr(divide='ignore', invalid='ignore')  # ignore division errors
     q1 = F1[:, 0]
     m1 = F1[:, 1]-F1[:, 0]
     q2 = F2[:, 0]
@@ -65,7 +63,6 @@ def intersection(F1, F2):
     t1, t2 = gt.intersectLineWithLine(q1, m1, q2, m2, mode='all', times=True)
     X1 = pointsAtLines(q1[:, newaxis], m1[:, newaxis], t1)
     X2 = pointsAtLines(q2, m2, t2)
-    seterr(**errh)  # reactivate division errors
 
     # Keep intersecting segments
     inside = (t1>=0.0)*(t1<=1.0)*(t2>=0.0)*(t2<=1.0)
