@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -23,9 +23,8 @@
 ##
 """Pattern
 
-This example shows the predefined geometries from simple.Pattern.
+This example shows the predefined geometries from simple.shape.
 """
-from __future__ import absolute_import, division, print_function
 
 
 _status = 'checked'
@@ -46,9 +45,9 @@ def run():
     linewidth(3)
     FA = None
     setDrawOptions({'bbox': None})
-    for n, p in simple.Pattern.items():
-        print("%s = %s" % (n, p))
-        FB = draw(Formex(p), bbox=None, color='red')
+    for n in simple.Pattern:
+        print("%s = %s" % (n, simple.Pattern[n]))
+        FB = draw(simple.shape(n), bbox=None, color='red')
         if FA:
             undraw(FA)
         FA = FB
