@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -27,7 +27,6 @@
 Computing geometrical properties of plane sections.
 
 """
-from __future__ import absolute_import, division, print_function
 
 
 _status = 'checked'
@@ -42,7 +41,7 @@ from pyformex.mydict import CDict
 
 
 def showaxes(C, angle, size, color):
-    H = Formex(simple.Pattern['plus']).scale(0.6*size).rot(angle/DEG).trl(C)
+    H = simple.shape('plus').scale(0.6*size).rot(angle/DEG).trl(C)
     draw(H, color=color)
 
 
