@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -30,7 +30,6 @@ surface and the animation of the results.
 A model of a horse is repeatedly cut by a plane and the cut-off parts
 are rotated and translated.
 """
-from __future__ import absolute_import, division, print_function
 
 
 _status = 'checked'
@@ -71,18 +70,17 @@ def run():
     t = -0.3
     bb[0] = (1.0-t)*bb[0] + t*bb[1]
     draw(S, bbox=bb, view='front')
-    return
+    #return
 
     try:
         P, n, t = askSlices(S.bbox())
-    except:
+    except Exception:
         return
 
-    a = t/len(P)
+    a = t / len(P)
 
     F = S.toFormex()
     G = []
-    old = seterr(all='ignore')
     setDrawOptions({'bbox': None})
 
     clear()
@@ -93,18 +91,15 @@ def run():
             F1.setProp(i)
         G = [g.rot(a, around=p) for g in G]
         G.append(F1)
-        #clear()
         B = draw([F, G])
         if A:
             undraw(A)
         A = B
 
-    seterr(**old)
-
     x = pf.canvas.width()//2
     y = pf.canvas.height() - 40
     T = drawText("No animals got hurt during the making of this movie!", (x, y), size=18, gravity='C')
-    for i in range(10):
+    for i in range(8):
         sleep(0.3)
         undecorate(T)
         sleep(0.3)
