@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -24,7 +24,6 @@
 """Double Layer Flat Space Truss Roof
 
 """
-from __future__ import absolute_import, division, print_function
 
 _status = 'checked'
 _level = 'advanced'
@@ -42,13 +41,17 @@ def run():
         ############################
         # Load the needed calpy modules
         from pyformex.plugins import calpy_itf
+        print("Loading calpy")
         import calpy
         calpy.options.optimize = False
+        print("Loading calpy.fe_util")
         from calpy import fe_util
+        print("Loading calpy.truss3d")
         from calpy import truss3d
 
         ############################
-    except:
+    except Exception:
+        pf.warning("Calpy could not be loaded")
         return
 
     if not checkWorkdir():
@@ -170,7 +173,12 @@ def run():
 
     # Running calpy analysis
     print("Performing analysis: this may take some time")
-    outfile = pf.cfg['workdir'] / Path(__file__).with_suffix('.out')
+    if checkWorkdir():
+        indir = pf.cfg['workdir']
+    else:
+        tmpdir = utils.TempDir()
+        indir = tmpdir.path
+    outfile = indir / Path(__file__).with_suffix('.out')
     print("Output is written to file '%s'" % outfile.resolve())
     stdout_saved = sys.stdout
     try:
@@ -180,6 +188,8 @@ def run():
             print("# Script name: %s" % pf.scriptName)
             displ, frc = truss3d.static(M.coords, bcon, mats, matnod, loads, Echo=True)
             print("# Analysis finished on %s" % time.ctime())
+    except:
+        return
     finally:
         sys.stdout = stdout_saved
 
@@ -190,7 +200,7 @@ def run():
 
     if pf.options.gui:
 
-        from pyformex.plugins.postproc import niceNumber, frameScale
+        from pyformex.plugins.postproc import frameScale
         from pyformex.gui.colorscale import ColorScale
         from pyformex.opengl.decors import ColorLegend
 
@@ -282,7 +292,9 @@ def run():
         optimscale = getOptimscale()
         options = ['None', 'Output File', 'Member forces', 'Deformation', 'Animated deformation']
         functions = [None, showOutput, showForces, showDeformation, showAnimatedDeformation]
-        while True:
+        cnt = 0
+        while True and cnt < 1000:
+            cnt += 1
             ans = ask("Which results do you want to see?", options)
             ind = options.index(ans)
             if ind <= 0:
