@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -48,8 +48,6 @@ consisting of quadrilaterals). The number of elements along the
 splines can be chosen. The number of elements across the splines is
 currently unused.
 """
-from __future__ import absolute_import, division, print_function
-from pyformex import zip
 
 _status = 'checked'
 _level = 'advanced'
@@ -245,7 +243,7 @@ def readSplines():
     fn = getcfg('datadir') / 'splines.pgf'
     obj = readGeomFile(fn)
     T = obj.values()
-    print("Number of curve: %s" % len(T))
+    print("Number of curves: %s" % len(T))
     print("Curve lengths: %s" % [len(Si.coords) for Si in T])
     return T
 
