@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -29,7 +29,6 @@ trisurface.intersectSurfaceWithLines as a method to render a 2D image
 onto a 3D surface.
 
 """
-from __future__ import absolute_import, division, print_function
 
 _status = 'checked'
 _level = 'normal'
@@ -132,7 +131,7 @@ def run():
     try:
         ratioYX = float(hpic)/wpic
         mH = mH.scale(ratioYX, 1)  # Keep original aspect ratio
-    except:
+    except Exception:
         pass
 
     mH0 = mH.scale(scale).translate(trl)
