@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -25,7 +25,6 @@
 
 Example for testing the low level drawing functions
 """
-from __future__ import absolute_import, division, print_function
 
 
 _status = 'checked'
@@ -63,7 +62,7 @@ def select_geom(geom, nplex, eltype):
     """Construct the geometry"""
     try:
         nplex = int(eltype[-1])
-    except:
+    except Exception:
         if not nplex in Points.keys():
             nplex = max([i for i in plexitude if i in Points.keys()])
         eltype = None
