@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -32,7 +32,6 @@ and transparency, and exports an equivalent WebGL model in the current
 working directory. Point your WebGL capable browser to the created
 'scene1.html' file to view the WebGL model.
 """
-from __future__ import absolute_import, division, print_function
 
 
 _status = 'checked'
@@ -134,6 +133,13 @@ def run():
     # export to WebGL
     camera = pf.canvas.camera
     print("Camera focus: %s; eye: %s" % (camera.focus, camera.eye))
+    if not checkWorkdir():
+        # Use the user's home as a last resort for a writable directory.
+        # If you use a TempDir here, make sure to export the directory
+        # to the globals, otherwise the tempdir gets destroyed at the
+        # end of this script, and the showHTML below might crash your
+        # browser
+        chdir(Path.home())
     pwdir()
     fn = exportWebGL('Scene1',
                      title='Two spheres and a cone',
