@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -24,7 +24,6 @@
 """X-shaped truss analysis
 
 """
-from __future__ import absolute_import, division, print_function
 
 
 _status = 'checked'
@@ -49,11 +48,11 @@ from calpy.truss3d import *
 
 
 def run():
-    if not checkWorkdir():
-        error("No writable path: I can not execute the simulation.\nCopy the script to a writable path and try running from there.")
-        return
+    # if not checkWorkdir():
+    #     error("No writable path: I can not execute the simulation.\nCopy the script to a writable path and try running from there.")
+    #     return
 
-    ###########################
+    # ###########################
 
     reset()
     clear()
@@ -134,9 +133,17 @@ def run():
 
     # Running calpy analysis
     print("Performing analysis: this may take some time")
-    # Note: __file__ is same as pf.scriptname
-    # and adding an absolute path will ignore the leading parts
-    outfile = pf.cfg['workdir'] / Path(__file__).with_suffix('.out')
+    if checkWorkdir():
+        wrkdir = pf.cfg['workdir']
+        print(f"Using workdir {wrkdir}")
+    else:
+        tmpdir = utils.TempDir()
+        wrkdir = tmpdir.path
+        print(f"Created tempdir {wrkdir}")
+    pwdir()
+    # USe a filename with same name as script
+    outfile = (wrkdir / Path(__file__).name).with_suffix('.out')
+    print(f"outfile is {outfile}")
     print("Output is written to file '%s'" % outfile.resolve())
     stdout_saved = sys.stdout
     try:
@@ -146,6 +153,8 @@ def run():
             print("# Script name: %s" % pf.scriptName)
             displ, frc = static(coords, bcon, mats, matnod, loads, Echo=True)
             print("# Analysis finished on %s" % time.ctime())
+    except:
+        return
     finally:
         sys.stdout = stdout_saved
 
