@@ -1,11 +1,11 @@
 /* */
 //
-//  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+//  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 //  pyFormex is a tool for generating, manipulating and transforming 3D
 //  geometrical models by sequences of mathematical operations.
 //  Home page: http://pyformex.org
 //  Project page:  http://savannah.nongnu.org/projects/pyformex/
-//  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+//  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 //  Distributed under the GNU General Public License version 3 or later.
 //
 //  This program is free software: you can redistribute it and/or modify
@@ -119,14 +119,14 @@ char* str(int64_t k) {
 }
 
 void do_element() {
-  printf("D.Element(%ld,",data.i[j++]);
+  printf("D.Element(%d,",(int)data.i[j++]);
   printf("'%s',[",str(j++));
-  while (j < jend) printf("%ld,",data.i[j++]);
+  while (j < jend) printf("%d,",(int)data.i[j++]);
   printf("])\n");
 }
 
 void do_node() {
-  printf("D.Node(%ld,[",data.i[j++]);
+  printf("D.Node(%d,[",(int)data.i[j++]);
   int64_t j3 = j+3;
   if (j3 > jend) j3 = jend;
   while (j < j3) printf("%e,",data.d[j++]);
@@ -139,7 +139,7 @@ void do_node() {
 
 void do_dofs() {
   printf("D.Dofs([");
-  while (j < jend) printf("%ld,",data.i[j++]);
+  while (j < jend) printf("%d,",(int)data.i[j++]);
   printf("])\n");
 }
 
@@ -156,7 +156,7 @@ void do_abqver() {
   /* BEWARE ! Do not call str() multiple times in the same printf instruction */
   printf("D.Date('%s',",strn(j,2)); j += 2;
   printf("'%s')\n",str(j++));
-  printf("D.Size(nelems=%ld,nnodes=%ld,length=%f)\n",data.i[j],data.i[j+1],data.d[j+2]);
+  printf("D.Size(nelems=%d,nnodes=%d,length=%f)\n",(int)data.i[j],(int)data.i[j+1],data.d[j+2]);
 }
 
 void do_heading() {
@@ -165,30 +165,30 @@ void do_heading() {
 
 void do_nodeset() {
   printf("D.Nodeset('%s',[",stripn(j++,1,1));
-  while (j<jend) printf("%ld,",data.i[j++]);
+  while (j<jend) printf("%d,",(int)data.i[j++]);
   printf("])\n");
 }
 
 void add_nodeset() {
   printf("D.NodesetAdd([");
-  while (j<jend) printf("%ld,",data.i[j++]);
+  while (j<jend) printf("%d,",(int)data.i[j++]);
   printf("])\n");
 }
 
 void do_elemset() {
   printf("D.Elemset('%s',[",stripn(j++,1,1));
-  while (j<jend) printf("%ld,",data.i[j++]);
+  while (j<jend) printf("%d,",(int)data.i[j++]);
   printf("])\n");
 }
 
 void add_elemset() {
   printf("D.ElemsetAdd([");
-  while (j<jend) printf("%ld,",data.i[j++]);
+  while (j<jend) printf("%d,",(int)data.i[j++]);
   printf("])\n");
 }
 
 void do_label() {
-  printf("D.Label(tag='%ld',value='",data.i[j++]);
+  printf("D.Label(tag='%d',value='",(int)data.i[j++]);
   printf("%s",strn(j,jend-j));
   printf("')\n");
 }
@@ -226,22 +226,22 @@ void do_elemheader() {
   int64_t * ip = data.i + j;
   int loc = ip[3];
   printf("D.ElemHeader(loc='%s',",output_location[loc]);
-  printf("i=%ld,",ip[0]);
+  printf("i=%d,",(int)ip[0]);
   if (loc==0)
-    printf("gp=%ld,",ip[1]);
+    printf("gp=%d,",(int)ip[1]);
   else if (loc==2)
-    printf("np=%ld,",ip[1]);
+    printf("np=%d,",(int)ip[1]);
   else if (ip[1]!=0)
-    printf("ip=%ld,",ip[1]);
+    printf("ip=%d,",(int)ip[1]);
   if (ip[2]!=0)
-    printf("sp=%ld,",ip[2]);
+    printf("sp=%d,",(int)ip[2]);
   if (loc==3)
     printf("rb='%s',",stripn(j+4,1,1));
-  printf("ndi=%ld,",ip[5]);
-  printf("nshr=%ld,",ip[6]);
-  printf("nsfc=%ld,",ip[8]);
+  printf("ndi=%d,",(int)ip[5]);
+  printf("nshr=%d,",(int)ip[6]);
+  printf("nsfc=%d,",(int)ip[8]);
   if (explicit)
-    printf("ndir=%ld,",ip[7]);
+      printf("ndir=%d,",(int)ip[7]);
   printf(")\n");
 }
 
@@ -252,7 +252,7 @@ void do_elemout(char* text) {
 }
 
 void do_nodeout(char* text) {
-  printf("D.NodeOutput('%s',%ld,[",text,data.i[j++]);
+  printf("D.NodeOutput('%s',%d,[",text,(int)data.i[j++]);
   while (j < jend) printf("%e,",data.d[j++]);
   printf("])\n");
 }
