@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -27,28 +27,19 @@ This module defines a generic Geometry superclass which adds all the
 possibilities of coordinate transformations offered by the
 Coords class to the derived classes.
 """
-from __future__ import absolute_import, division, print_function
+from collections import OrderedDict
+from abc import ABC, abstractmethod
 
 import numpy as np
 
-import pyformex as pf
-
-from abc import ABCMeta, abstractmethod
-if pf.PY2:
-     abstractbaseclass = object
-if pf.PY3:
-     from abc import ABC
-     abstractbaseclass = ABC
-
 from pyformex import utils
-from pyformex.coords import Coords, Int
-from pyformex.attributes import Attributes
-from collections import OrderedDict
-from pyformex.olist import List
 import pyformex.arraytools as at
+from pyformex.coords import Coords
+from pyformex.attributes import Attributes
+from pyformex.olist import List
 
 
-class Geometry(abstractbaseclass):
+class Geometry(ABC):
     """A generic geometry class allowing manipulation of large coordinate sets.
 
     The Geometry class is a generic parent class for all geometry classes.
@@ -203,7 +194,7 @@ class Geometry(abstractbaseclass):
         exists when at least one Field has been defined. See :meth:`addField`.
 
     """
-    #_attributes_ = [ 'xyz', 'x', 'y', 'z', 'xy', 'xz', 'yz' ]
+    # _attributes_ = [ 'xyz', 'x', 'y', 'z', 'xy', 'xz', 'yz' ]
 
 
     def __init__(self):
@@ -219,9 +210,6 @@ class Geometry(abstractbaseclass):
     #
     ##########################################################################
 
-    if pf.PY2:
-         __metaclass__ = ABCMeta
-
 
     def _set_coords_inplace(self, coords):
         """Replace the current coords with new ones.
@@ -266,11 +254,12 @@ class Geometry(abstractbaseclass):
         """
         funcname = func.__name__
         print(func.__code__.co_firstlineno)
+
         @property
         def newf(self, *args, **kargs):
             """Call the Coords %s method on the coords attribute"""
             return getattr(self.coords, funcname)
-        #newf.__name__ = func.__name__
+        # newf.__name__ = func.__name__
         newf.fget.__doc__ ="""NEWDOC"""
         print(newf.fget.__code__.co_firstlineno)  # = func.__code__.co_firstlineno
         return newf
@@ -287,21 +276,27 @@ class Geometry(abstractbaseclass):
     @xyz.setter
     def xyz(self, value):
         self.coords.xyz = value
+
     @x.setter
     def x(self, value):
         self.coords.x = value
+
     @y.setter
     def y(self, value):
         self.coords.y = value
+
     @z.setter
     def z(self, value):
         self.coords.z = value
+
     @xy.setter
     def xy(self, value):
         self.coords.xy = value
+
     @yz.setter
     def yz(self, value):
         self.coords.yz = value
+
     @xz.setter
     def xz(self, value):
         self.coords.xz = value
@@ -363,67 +358,84 @@ class Geometry(abstractbaseclass):
         This is a decorator function.
         """
         coords_func = getattr(Coords, func.__name__)
+
         def newf(self, *args, **kargs):
-            """Call the Coords %s method on the coords attribute"""
             return coords_func(self.coords, *args, **kargs)
         newf.__name__ = func.__name__
-        newf.__doc__ ="""Call :meth:`~coords.Coords.%s` method on the ``coords`` attribute of the Geometry object.
-
-        See :meth:`coords.Coords.%s` for details.
-""" % (func.__name__, func.__name__)
+        newf.__doc__ = (
+            f"Call Coords.{func.__name__} method "
+            "on the Geometry object's coords.\n\n"
+            f"See :meth:`coords.Coords.{func.__name__}` for details.")
         return newf
 
     @_coords_method
     def points(self):
         pass
+
     @_coords_method
     def bbox(self):
         pass
+
     @_coords_method
     def center(self):
         pass
+
     @_coords_method
     def bboxPoint(self, *args, **kargs):
         pass
+
     @_coords_method
     def centroid(self):
         pass
+
     @_coords_method
     def sizes(self):
         pass
+
     @_coords_method
     def dsize(self):
         pass
+
     @_coords_method
     def bsphere(self):
         pass
+
     @_coords_method
     def bboxes(self):
         pass
+
     @_coords_method
     def inertia(self, *args, **kargs):
         pass
+
     @_coords_method
     def principalCS(self, *args, **kargs):
         pass
+
     @_coords_method
     def principalSizes(self):
         pass
+
     @_coords_method
     def distanceFromPlane(self, *args, **kargs):
         pass
+
     @_coords_method
     def distanceFromLine(self, *args, **kargs):
         pass
+
     @_coords_method
     def distanceFromPoint(self, *args, **kargs):
         pass
+
     @_coords_method
     def directionalSize(self, *args, **kargs):
         pass
+
     @_coords_method
     def directionalWidth(self, *args, **kargs):
         pass
+
     @_coords_method
     def directionalExtremes(self, *args, **kargs):
         pass
@@ -467,26 +479,28 @@ class Geometry(abstractbaseclass):
             The array flags the elements that are inside the given
             bounding box.
         """
-        test = [self.test(nodes=nodes, dir=i, min=bb[0][i], max=bb[1][i], atol=atol) for i in dirs]
+        test = [self.test(nodes=nodes, dir=i, min=bb[0][i], max=bb[1][i],
+                          atol=atol) for i in dirs]
         return np.stack(test).all(axis=0)
 
 
     ########### Coords transformations #################
 
+
     def _coords_transform(func):
         """Perform a transformation on the .coords attribute of the object.
 
         This is a decorator function.
         """
         coords_func = getattr(Coords, func.__name__)
+
         def newf(self, *args, **kargs):
-            """Apply a transformation to the coords attribute"""
             return self._set_coords(coords_func(self.coords, *args, **kargs))
         newf.__name__ = func.__name__
-        newf.__doc__ ="""Apply the :class:`~coords.Coords.%s` transformation to the Geometry object.
-
-        See :meth:`coords.Coords.%s` for details.
-""" % (func.__name__, func.__name__)
+        newf.__doc__ = (
+            f"Apply the :class:`~coords.Coords.{func.__name__}` transformation "
+            "to the Geometry object.\n\n"
+            f"See :meth:`coords.Coords.{func.__name__}` for details.")
         return newf
 
     @_coords_transform
@@ -512,96 +526,127 @@ class Geometry(abstractbaseclass):
     @_coords_transform
     def adjust(self, *args, **kargs):
         pass
+
     @_coords_transform
     def translate(self, *args, **kargs):
         pass
+
     @_coords_transform
     def centered(self, *args, **kargs):
         pass
+
     @_coords_transform
     def align(self, *args, **kargs):
         pass
+
     @_coords_transform
     def rotate(self, *args, **kargs):
         pass
+
     @_coords_transform
     def shear(self, *args, **kargs):
         pass
+
     @_coords_transform
     def reflect(self, *args, **kargs):
         pass
+
     @_coords_transform
     def affine(self, *args, **kargs):
         pass
+
     @_coords_transform
     def toCS(self, *args, **kargs):
         pass
+
     @_coords_transform
     def fromCS(self, *args, **kargs):
         pass
+
     @_coords_transform
     def transformCS(self, *args, **kargs):
         pass
+
     @_coords_transform
     def position(self, *args, **kargs):
         pass
+
     @_coords_transform
     def cylindrical(self, *args, **kargs):
         pass
+
     @_coords_transform
     def hyperCylindrical(self, *args, **kargs):
         pass
+
     @_coords_transform
     def toCylindrical(self, *args, **kargs):
         pass
+
     @_coords_transform
     def spherical(self, *args, **kargs):
         pass
+
     @_coords_transform
     def superSpherical(self, *args, **kargs):
         pass
+
     @_coords_transform
     def toSpherical(self, *args, **kargs):
         pass
+
     @_coords_transform
     def circulize(self, *args, **kargs):
         pass
+
     @_coords_transform
     def bump(self, *args, **kargs):
         pass
+
     @_coords_transform
     def flare(self, *args, **kargs):
         pass
+
     @_coords_transform
     def map(self, *args, **kargs):
         pass
+
     @_coords_transform
     def map1(self, *args, **kargs):
         pass
+
     @_coords_transform
     def mapd(self, *args, **kargs):
         pass
+
     @_coords_transform
     def copyAxes(self, *args, **kargs):
         pass
+
     @_coords_transform
     def swapAxes(self, *args, **kargs):
         pass
+
     @_coords_transform
     def rollAxes(self, *args, **kargs):
         pass
+
     @_coords_transform
     def projectOnPlane(self, *args, **kargs):
         pass
+
     @_coords_transform
     def projectOnSphere(self, *args, **kargs):
         pass
+
     @_coords_transform
     def projectOnCylinder(self, *args, **kargs):
         pass
+
     @_coords_transform
     def isopar(self, *args, **kargs):
         pass
+
     @_coords_transform
     def addNoise(self, *args, **kargs):
         pass
@@ -616,6 +661,7 @@ class Geometry(abstractbaseclass):
     #
     ##########################################################################
 
+
     def setProp(self, prop=None):
         """Create or destroy the property array for the Geometry.
 
@@ -678,7 +724,7 @@ class Geometry(abstractbaseclass):
 
         Parameters
         ----------
-        prop: int or int :term:
+        prop: int or int :term:`array_like`
             The property values to turn into a valid set for the object.
             If a single int, all elements get the same property value.
             If the number of passed values is less than the number of elements,
@@ -745,7 +791,7 @@ class Geometry(abstractbaseclass):
 
         Parameters
         ----------
-        prop: int or int :term:
+        prop: int or int :term:`array_like`
             The property value(s) to be found.
 
         Returns
@@ -776,6 +822,7 @@ class Geometry(abstractbaseclass):
     #
     ##########################################################################
 
+
     def copy(self):
         """Return a deep copy of the Geometry  object.
 
@@ -798,7 +845,7 @@ class Geometry(abstractbaseclass):
 
 
     @abstractmethod
-    def _select(self, sel, compact=False):
+    def _select(self, selected, **kargs):
         """Low level selection
 
         This is an abstract method and has to be reimplemented by the
@@ -807,7 +854,6 @@ class Geometry(abstractbaseclass):
         pass
 
 
-    @utils.warning("warn_select_changed")
     def select(self, sel, compact=False):
         """Select some element(s) from a Geometry.
 
@@ -841,10 +887,10 @@ class Geometry(abstractbaseclass):
         clip: Like select, but with compact=True as default.
 
         """
+        utils.warn("warn_select_changed")
         return self._select(sel, compact=compact)
 
 
-    @utils.warning("warn_select_changed")
     def cselect(self, sel, compact=False):
         """Return the Geometry with the selected elements removed.
 
@@ -878,10 +924,10 @@ class Geometry(abstractbaseclass):
         cclip: Like cselect, but with compact=True as default.
 
         """
+        utils.warn("warn_select_changed")
         return self._select(at.complement(sel, self.nelems()), compact=compact)
 
 
-    @utils.warning("warn_clip_changed")
     def clip(self, sel):
         """Return a Geometry only containing the selected elements.
 
@@ -894,10 +940,10 @@ class Geometry(abstractbaseclass):
         cclip: The complement of clip, returning all but the selected elements.
 
         """
+        utils.warn("warn_clip_changed")
         return self.select(sel, compact=True)
 
 
-    @utils.warning("warn_clip_changed")
     def cclip(self, sel):
         """Return a Geometry with the selected elements removed.
 
@@ -909,6 +955,7 @@ class Geometry(abstractbaseclass):
         cselect: Return a Geometry with only the selected elements.
         clip: The complement of cclip, returning only the selected elements.
         """
+        utils.warn("warn_clip_changed")
         return self.cselect(sel, compact=True)
 
 
@@ -917,7 +964,7 @@ class Geometry(abstractbaseclass):
 
         Parameters
         ----------
-        prop: int or int :term:
+        prop: int or int :term:`array_like`
             The property value(s) for which the elements should be selected.
 
         Returns
@@ -947,7 +994,7 @@ class Geometry(abstractbaseclass):
 
         Parameters
         ----------
-        prop: int or int :term:
+        prop: int or int :term:`array_like`
             The property value(s) of the elements that should be left out.
 
         Returns
@@ -1011,6 +1058,7 @@ class Geometry(abstractbaseclass):
     #
     ##########################################################################
 
+
     @property
     def fields(self):
         """Return the Fields dict of the Geometry.
@@ -1035,7 +1083,7 @@ class Geometry(abstractbaseclass):
         ----------
         fldtype: str
             The field type. See :class:`~field.Field` for details.
-        data: :term:
+        data: :term:`array_like`
             The field data. See :class:`~field.Field` for details.
         fldname: str
             The field name. See :class:`~field.Field` for details. This name
@@ -1064,7 +1112,8 @@ class Geometry(abstractbaseclass):
         from pyformex.field import Field
 
         if not hasattr(self, 'fieldtypes') or fldtype not in self.fieldtypes:
-            raise ValueError("Can not add field of type '%s' to a %s" % (fldtype, self.__class__.__name__))
+            raise ValueError(f"Can not add field of type '{fldtype}' "
+                             f"to a {self.__class__.__name__}")
 
         fld = Field(self, fldtype, data, fldname)
         return self._add_field(fld)
@@ -1153,8 +1202,8 @@ class Geometry(abstractbaseclass):
 
         """
         return '\n'.join([
-            "Field '%s', fldtype '%s', dtype %s, shape %s" % \
-            (f.fldname, f.fldtype, f.data.dtype, f.data.shape) \
+            f"Field '{f.fldname}', fldtype '{f.fldtype}', "
+            f"dtype {f.data.dtype}, shape {f.data.shape}"
             for f in self.fields.values()])
 
 
@@ -1164,6 +1213,7 @@ class Geometry(abstractbaseclass):
     #
     ##########################################################################
 
+
     def write(self, filename, sep=' ', mode='w', **kargs):
         """Write a Geometry to a PGF file.
 
