@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -35,37 +35,34 @@ This module also detects the underlying windowing system.
 Currently, the pyFormex GUI is only guaranteed on X11.
 For other systems, a warning will be printed that some things may not work.
 """
-from __future__ import absolute_import, division, print_function
 
 import pyformex as pf
 from pyformex import Path
 from pyformex import utils
 
-BINDINGS = ('pyside', 'pyside2', 'pyqt4', 'pyqt5')
+BINDINGS = ('pyside2', 'pyside', 'pyqt5', 'pyqt4')
 bindings = pf.cfg['gui/bindings'].lower()
 
 if bindings in BINDINGS:
-    utils.requireModule(bindings)
+    utils.Module.require(bindings)
 
 else:
     # Try using any existing bindings
     bindings = ''
     for b in BINDINGS:
-        if utils.hasModule(b):
+        if utils.Module.has(b):
             bindings = b
             break
 
-#print(bindings)
+if bindings == 'pyside2':
+    from PySide2 import QtCore, QtGui, QtOpenGL, QtWidgets
+    from PySide2.QtCore import Signal, Slot
 
-if bindings == 'pyside':
+elif bindings == 'pyside':
     from PySide import QtCore, QtGui, QtOpenGL
     import PySide.QtGui as QtWidgets
     from PySide.QtCore import Signal, Slot
 
-elif bindings == 'pyside2':
-    from PySide2 import QtCore, QtGui, QtOpenGL, QtWidgets
-    from PySide2.QtCore import Signal, Slot
-
 elif bindings == 'pyqt4':
     import sip
     try:
@@ -84,21 +81,42 @@ elif bindings == 'pyqt4':
     from PyQt4.QtCore import pyqtSignal as Signal
     from PyQt4.QtCore import pyqtSlot as Slot
 
+elif bindings == 'pyqt5':   # UNTESTED!
+    import sip
+    try:
+        sip.setapi('QDate', 2)
+        sip.setapi('QDateTime', 2)
+        sip.setapi('QString', 2)
+        sip.setapi('QTextStream', 2)
+        sip.setapi('QTime', 2)
+        sip.setapi('QUrl', 2)
+        sip.setapi('QVariant', 2)
+    except ValueError as e:
+        raise RuntimeError('Could not set PyQt5 API version (%s)' % e)
+
+    from PyQt5 import QtCore, QtGui, QtOpenGL
+    import PyQt5.QtGui as QtWidgets
+    from PyQt5.QtCore import pyqtSignal as Signal
+    from PyQt5.QtCore import pyqtSlot as Slot
+
 else:
     bindings = ''
 
 if not bindings:
-    raise ValueError("\n"+"*"*40+"\nThe pyFormex GUI requires PySide, PySide2 or PyQt4.\nI could not find neither of them, so I can not continue.\nInstall PySide, PySide2 or PyQt4 (including its OpenGL component)\nand then retry."+"\n"+"*"*40)
+    raise ValueError("\n"+"*"*40+"\nThe pyFormex GUI requires Python bindings for the Qt libraries.\n These are available as PySide2, PySide, PyQt5 or PyQt4.\nI could not find neither of them, so I can not continue.\nInstall one of these bindings for Python3 (including its OpenGL component)\nand then retry."+"\n"+"*"*40)
 
 
-if pf.PY3 and bindings.startswith('pyside'):
+if bindings == 'pyside2':
     def QByteArrayToStr(self):
         """Convert a QByteArray to a Python3 str"""
         return str(self)[2:-1]
-if pf.PY2:
+elif bindings == 'pyside':
     def QByteArrayToStr(self):
-        """Convert a QByteArray to a Python2 str"""
+        """Convert a QByteArray to a Python3 str"""
         return str(self)
+else:
+    raise RuntimeError("Fatal error: currently only pyside2/pyside bindings are supported, not pyqt4/pyqt5")
+
 QtCore.QByteArray.toStr = QByteArrayToStr
 
 
@@ -131,34 +149,13 @@ def loadX11Colors(filename):
             name = ''.join(s[3:]).lower()
             try:
                 x11colors[name] = tuple(int(i) for i in s[:3])
-            except:
+            except Exception:
                 pass
 
     return x11colors
 
-
-
 pf.X11colors = loadX11Colors("/etc/X11/rgb.txt")
 pf.X11 = len(pf.X11colors) > 0
 
 
-# if bindings=='pyside2':
-#     utils.warn("warn_pyside2")
-#     from PySide2.QtX11Extras import QX11Info as x11
-#     pf.X11 = x11.isPlatformX11() # DOES NOT WORK!!!
-#     pf.X11 = True
-#     pf.X11colors = loadX11Colors("/etc/X11/rgb.txt")
-
-# else:
-
-#     try:
-#         QtGui.QColor.setAllowX11ColorNames(True)
-#         pf.X11 = True
-#         pf.X11colors = {}
-#     except:
-#         print("WARNING: THIS IS NOT AN X11 WINDOW SYSTEM!")
-#         print("SOME THINGS MAY NOT WORK PROPERLY!")
-#         pf.X11 = False
-#         pf.X11colors = {}
-
 # End
