@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -24,7 +24,6 @@
 """Menu with pyFormex apps.
 
 """
-from __future__ import absolute_import, division, print_function
 
 import random
 from gettext import gettext as _
@@ -64,7 +63,7 @@ def classify(appdir, pkg, nmax=0):
         _status = 'failed'
 
     all_apps = sorted(apps.detect(appdir))
-    kat = ['all', 'status', 'level', 'topics', 'techniques']
+    kat = ['byname', 'status', 'level', 'topics', 'techniques']
     cat = dict([(k, set()) for k in kat])
     cat['status'] = ['failed', 'checked', 'unchecked']
     cat['level'] = ['beginner', 'normal', 'advanced']
@@ -74,9 +73,9 @@ def classify(appdir, pkg, nmax=0):
     if nmax > 9:  # Do not exagerate!
         # split the full collection in alphabetical groups of length nmax
         lbl, grp = splitAlpha(all_apps, nmax)
-        cat['all'] = lbl
+        cat['byname'] = lbl
         for l, g in zip(lbl, grp):
-            col['all/'+l] = g
+            col['byname/'+l] = g
 
     for i, appname in enumerate(all_apps):
 
@@ -86,7 +85,7 @@ def classify(appdir, pkg, nmax=0):
             app = apps.load(fullname, strict=True)
             if app is None:
                 raise RuntimeError("App '%s' has no run method" % fullname)
-        except:
+        except Exception:
             app = failed
             print("Failed to load app '%s'" % fullname)
 
@@ -310,7 +309,7 @@ class AppMenu(menu.Menu):
     def loadCatalog(self):
         catfile = self.dir / catname
         if catfile.exists():
-            pf.execFile(str(catfile), globals())
+            utils.execFile(str(catfile), globals())
             for k in kat:
                 if k == 'all_apps' and self.mode != 'app':
                     files = col[k]
