@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -28,14 +28,13 @@ rendering capabilities of pyFormex. The full contents of this module
 is available to scripts running in the pyFormex GUI without the need
 to import it.
 """
-from __future__ import absolute_import, division, print_function
 
-import logging
 import numpy as np
 from contextlib import contextmanager
 
 import pyformex as pf
 from pyformex import arraytools as at
+from pyformex import process
 from pyformex import utils
 from pyformex import coords
 from pyformex import Path
@@ -44,6 +43,7 @@ from pyformex.formex import Formex, connect
 from pyformex.gui import widgets, QtCore
 from pyformex.gui import toolbar
 from pyformex.gui import image
+from pyformex.gui import drawlock
 from pyformex.opengl import colors, actors, decors
 
 # Extra things that we want in the scripting language
@@ -53,6 +53,7 @@ _G = widgets.groupInputItem
 _H = widgets.hboxInputItem
 _T = widgets.tabInputItem
 from pyformex.script import *
+from pyformex.lazy import *
 from pyformex.opengl.colors import *
 from pyformex.gui.toolbar import timeout
 from pyformex.gui import image
@@ -116,9 +117,15 @@ def showMessage(text, actions=['OK'], level='info', modal=True, align='00', **ka
         w.move(100, 100)
     if modal:
         return w.getResults()
-    else:
-        w.show()
-        return None
+    # else:
+    #     w.show()
+    #     while not w.result() == 3:
+    #         print(w.result())
+    #         pf.app.processEvents()
+    #         sleep(1)
+    #     print(w.result())
+    #     w.accept()
+    #     return 'exit'
 
 
 def showInfo(text, actions=['OK'], modal=True):
@@ -138,7 +145,7 @@ def ask(question, choices=None, **kargs):
     """Ask a question and present possible answers.
 
     Return answer if accepted or default if rejected.
-    The remaining arguments are passed to the InputDialog getResult method.
+    The remaining arguments are passed to :func:`showMessage`.
     """
     return showMessage(question, choices, 'question', **kargs)
 
@@ -261,7 +268,7 @@ def showDoc(obj=None, rst=True, modal=False):
             pf.GUI.doc_dialog.raise_()
             pf.GUI.doc_dialog.update()
             pf.app.processEvents()
-        except:
+        except Exception:
             pass
 
 
@@ -286,7 +293,7 @@ def editFile(fn, exist=False):
         fn = Path(fn)
         if exist and not fn.exists():
             return
-        utils.system('%s %s' % (pf.cfg['editor'], fn), wait=False)
+        process.start([pf.cfg['editor'], fn])
     else:
         warning('No known editor was found or configured')
 
@@ -356,7 +363,8 @@ def dialogTimedOut():
     return _dialog_result == widgets.TIMEOUT
 
 
-def askFile(cur=None, filter='all', exist=True, multi=False, compr=False, change=True, timeout=None, caption=None, sidebar=None, **kargs):
+def askFile(cur=None, filter='all', exist=True, multi=False, compr=False,
+            change=True, timeout=None, caption=None, sidebar=None, **kargs):
     """Ask for one or more files using a customized file dialog.
 
     This is like :func:`askFileName` but returns a Dict with the full
@@ -391,14 +399,17 @@ def askFile(cur=None, filter='all', exist=True, multi=False, compr=False, change
     _dialog_result = w.result()  # Accepted, rejected or timeout
     if res:
         fn = res.fn
+        print("Original: {fn}")
         if not exist and not multi:
             # Check and force extension for single new file
-            okext = utils.fileExtensionsFromFilter(w.selectedNameFilter())
-            print("Selected filter: %s" % w.selectedNameFilter())
-            print("Accepted extensions: %s" % okext)
-            ok = fn.suffix in okext
+            filtr = w.selectedNameFilter()
+            okext = utils.fileTypesFromFilter(filtr)
+            print(f"Selected filter: {w.selectedNameFilter()}")
+            print(f"Accepted extensions: {okext}")
+            ok = fn.filetype() in okext
             if not ok:
-                res.fn = fn = fn.with_suffix(okext[0])
+                print(f"Got filename {fn}")
+                res.fn = fn = fn.with_suffix('.'+okext[0])
 
         if fn and change:
             if multi:
@@ -523,12 +534,15 @@ def checkWorkdir():
     """
     try:
         tmpfile = utils.TempFile(dir='.')
-    except PermissionError:
-        warning("Your current working directory (%s) is not writable. Change your working directory to a path where you have write permission." % Path.cwd())
+    except (FileNotFoundError, PermissionError):
+        warning(
+            f"Your current working directory {pf.cfg['workdir']} does not exist "
+            f"or is not writable. Change your working directory to an "
+            f"existing path where you have write permission.")
         askDirname()   # this also changes the current workdir
         try:
             tmpfile = utils.TempFile(dir='.')
-        except PermissionError:
+        except (FileNotFoundError, PermissionError):
             return False
     return True
 
@@ -647,7 +661,6 @@ def pause(timeout=None, msg=None):
     - `msg`: string: a message to write to the board to explain the user
       about the pause
     """
-    from pyformex.gui.drawlock import Repeater
     def _continue_():
         return not pf.GUI.drawlock.locked
 
@@ -664,19 +677,35 @@ def pause(timeout=None, msg=None):
         pf.GUI.drawlock.locked = True
     if timeout is None:
         timeout = widgets.input_timeout
-    R = Repeater(_continue_, timeout, sleep=0.1)
+    R = drawlock.Repeater(_continue_, timeout, sleep=0.1)
     R.start()
     pf.GUI.drawlock.release()
 
 
-def sleep(duration, granularity=0.01):
+def sleep(duration, granularity=0.01, func=None):
     """Hold execution for some duration
 
     This holds the execution of the thread where the function is
     called for the specified time (in seconds).
+
+    See also
+    --------
+    `delay`
+
+    Notes
+    -----
+    Because of the setup of the operation, in case of very small duration
+    times the actual duration may be considerably longer than the specified
+    value.
+    If the sleep is intended to slow down drawing instructions, you may
+    consider the use of :func:`delay`. Even if you do not have a draw function
+    in the block you want to delay, a :func:`view` function could be added
+    to apply the delay.
+    Normally you should set granularity < duration.
     """
-    from pyformex.gui.drawlock import Repeater
-    R = Repeater(None, duration, sleep=granularity)
+    if duration > 0:
+        granularity = min(granularity,duration)
+    R = drawlock.Repeater(func, duration=duration, sleep=granularity)
     R.start()
 
 
@@ -695,7 +724,7 @@ def do_after(sec, func):
     import threading
     t = threading.Timer(sec, func)
     t.start()
-    logging.info("Started timer for %s: %s" % (sec, func))
+    pf.logger.info("Started timer for %s: %s" % (sec, func))
 
 
 ########################## print information ################################
@@ -896,7 +925,7 @@ def flyAlong(path, upvector=[0., 1., 0.], sleeptime=None):
             path = path.toFormex()
         if not path.nplex() in (2, 3):
             raise ValueError
-    except:
+    except Exception:
         raise ValueError("The camera path should be (convertible to) a plex-2 or plex-3 Formex!")
 
     nplex = path.nplex()
@@ -1791,7 +1820,7 @@ def reset():
         if len(pf.GUI.viewports.all) == 1:
             size = (-1, -1)
             canvasSize(*size)
-    except:
+    except Exception:
         print("Warning: Resetting canvas before initialization?")
     clear(sticky=True)
     view('front')
@@ -1928,7 +1957,7 @@ def drawNumbers(G, numbers=None, color='black', trl=None, offset=0, prefix='', o
         ontop = getcfg('draw/numbersontop')
     try:
         X = G.centroids()
-    except:
+    except Exception:
         return None
     if trl is not None:
         X = X.trl(trl)
@@ -2143,26 +2172,38 @@ def drawImage(image, w=0, h=0, x=-1, y=-1, color=colors.white, ontop=False):
     return R
 
 
-def drawField(fld, comp=0, scale='RAINBOW', symmetric_scale=False, cvalues=None, **kargs):
+def drawField(fld, comp=0, scale='RAINBOW', symmetric_scale=False,
+              cvalues=None, clageom=None, **kargs):
     """Draw intensity of a scalar field over a Mesh.
 
-    Parameters:
-
-    - `fld`: a Field, specifying some value over a Geometry.
-    - `comp`: int: if fld is a vectorial Field, specifies the component
-      that is to be drawn.
-    - `scale`: one of the color palettes defined in :mod:`colorscale`.
-      If an empty string is specified, the scale is not drawn.
-    - `symmetric_scale`: bool : if `True` the mid value of the color scale will
-      be set to the value corresponding to the middle value of the `fld` data range.
-      If `False` the mid value of the color scale will be set to 0.0 if the range
-      extends over negative and positive values.
-    - `cvalues`: None or list : specify the values between which to span the
-      color palette. If `None` the min , max and mid values are taken from
-      the field data. If `list` the values can be defined by the user as a list
-      of 2 values (min, max) or 3 values (min, mid, max).
-    - `**kargs`: any not-recognized keyword parameters are passed to the
-      draw function to draw the Geometry.
+    Parameters
+    ----------
+    fld: :class:`Field`
+        A Field, specifying some value over a Geometry.
+    comp: int, optional
+        Required if `fld` is a vectorial Field: specifies the component
+        that is to be drawn.
+    scale: str
+        One of the color palettes defined in :mod:`colorscale`.
+        If an empty string is specified, the scale is not drawn.
+    symmetric_scale: bool
+        If `True` the mid value of the color scale will be set to the value
+        corresponding to the middle value of the `fld` data range.
+        If `False` the mid value of the color scale will be set to 0.0
+        if the range extends over negative and positive values.
+    cvalues: list, optional
+        Specifies the min, max and mid values between which to span the
+        color palette. It can be a list of 2 values (min, max) or
+        3 values (min, mid, max).
+        If not provided, the values are taken from the field data.
+    clageom: list of int, optional
+        If provided, it is a list of four integers (x, y, w, h) specifying
+        the position and size (in pixels) of the colorscale. The default
+        size is a height of 200 (adjusted down if the canvas is not high
+        enough) and positioned near the lower left corner of the canvas.
+    **kargs:
+        Other keyword arguments are passed to the draw function to draw
+        the Geometry.
 
     Draws the Field's Geometry with the Field data converted to colors.
     A color legend is added to convert colors to values.
@@ -2206,9 +2247,15 @@ def drawField(fld, comp=0, scale='RAINBOW', symmetric_scale=False, cvalues=None,
     CS = ColorScale(scale, vmin, vmax, vmid, 1., 1.)
     cval = np.array([CS.color(v) for v in data.flat])
     cval = cval.reshape(data.shape+(3,))
-    CLA = ColorLegend(CS, 256, 20, 20, 30, 200, scale=multiplier)
+    if clageom:
+        CLAx, CLAy, CLAw, CLAh = clageom
+    else:
+        CLAh = min(200, pf.canvas.height()-30)
+        CLAx = CLAy = CLAw = CLAh // 10
+    CLA = ColorLegend(CS, 256, CLAx, CLAy, CLAw, CLAh, scale=multiplier)
     drawActor(CLA)
-    decorate(drawText("{} (1.e{})".format(fld.fldname, -multiplier), (20, 250), size=18, color='black'))
+    decorate(drawText(f"{fld.fldname} (1.e{-multiplier})",
+                      (20, 250), size=18, color='black'))
     if fld.fldtype == 'node':
         draw(fld.geometry, color=cval[fld.geometry.elems], **kargs)
     else:
@@ -2540,9 +2587,9 @@ def renderMode(mode, light=None):
     pf.canvas.setRenderMode(mode, light)
     pf.canvas.update()
     toolbar.updateViewportButtons(pf.canvas)
-    #toolbar.updateNormalsButton()
-    #toolbar.updateTransparencyButton()
-    #toolbar.updateLightButton()
+    toolbar.updateNormalsButton()
+    toolbar.updateTransparencyButton()
+    toolbar.updateLightButton()
     pf.GUI.processEvents()
 
 
