@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -26,7 +26,6 @@
 This module contains the main functions responsible for constructing
 and starting the pyFormex GUI.
 """
-from __future__ import absolute_import, division, print_function
 
 import sys, os
 import types
@@ -34,13 +33,14 @@ import warnings
 
 import pyformex as pf
 from pyformex import Path
+from pyformex import process
 from pyformex import utils
 from pyformex import software
 
-# If we get here, either PyQt4 or PySide are imported
+# If we get here, either PySide2, PySide, PyQt5 or PyQt4 are imported
 # Check for OpenGL
-software.checkModule('pyopengl', fatal=True)
-software.checkModule('pil', fatal=True)
+software.Module.has('pyopengl', fatal=True)
+software.Module.has('pil', fatal=True)
 
 from pyformex.gui import (
     signals, QtCore, QtGui, QtWidgets, QPixmap,
@@ -208,7 +208,7 @@ class FileWatcher(QtCore.QFileSystemWatcher):
         try:
             del self.filesWatched[path]
             self.removeWatch(path)
-        except:
+        except Exception:
             pass
 
 
@@ -232,7 +232,7 @@ def getMenuData(name):
     # try:
     #     print("Importing %s menu" % name)
     #     __import__('pyformex.plugins.menus.'+name)
-    # except:
+    # except Exception:
     #     print("Could not load menu '%s'" % name)
     # module = globals().get(name, None)
     # if isinstance(module, types.ModuleType) and hasattr(module, 'MenuData'):
@@ -525,7 +525,6 @@ class Gui(QtWidgets.QMainWindow):
             }
 
 
-
     def createConsole(self, config):
         """Create the message board and console
 
@@ -541,7 +540,7 @@ class Gui(QtWidgets.QMainWindow):
                 self.splitter.addWidget(self.board)
         if 'c' in config:
             if self.console is None:
-                pf.startup_messages += "Added experimental console\n"
+                pf.logger.info("Added experimental console")
                 from pyformex.gui import pyconsole
                 self.console = pyconsole.PyConsole(pf.interpreter)
                 self.console.interpreter.globals = draw.Globals()
@@ -685,7 +684,7 @@ class Gui(QtWidgets.QMainWindow):
         area = pf.cfg['gui/%s' % shortname]
         try:
             toolbar = getattr(self, shortname)
-        except:
+        except Exception:
             toolbar = None
 
         if area:
@@ -730,8 +729,8 @@ class Gui(QtWidgets.QMainWindow):
 
     def toggleCoordsTracker(self, onoff=None):
         def track(x, y, z):
-            X, Y, Z = pf.canvas.unproject(x, y, z, True)
-            print("%s --> %s" % ((x, y, z), (X, Y, Z)))
+            (X, Y, Z), = pf.canvas.unproject(x, y, z, True)
+            # print("%s --> %s" % ((x, y, z), (X, Y, Z)))
             pf.GUI.coordsbox.setValues([X, Y, Z])
 
         if onoff is None:
@@ -789,7 +788,7 @@ class Gui(QtWidgets.QMainWindow):
                 self.canPlay = False
                 try:
                     self.canEdit = apps.findAppSource(appname).exists()
-                except:
+                except Exception:
                     self.canEdit = False
             else:
                 self.canPlay = hasattr(app, 'run')
@@ -862,10 +861,11 @@ class Gui(QtWidgets.QMainWindow):
         e.ignore()
 
 
+    # TODO: check if this is still needed !
     def XPos(self):
         """Get the main window position from the xwininfo command.
 
-        The (Py)Qt4 position does not get updated when
+        The Qt position does not get updated when
         changing the window size from the left.
         This substitute function will find the correct position from
         the xwininfo command output.
@@ -896,6 +896,7 @@ class Gui(QtWidgets.QMainWindow):
 
         """
         pf.debug('Store current settings', pf.DEBUG.CONFIG)
+        # TODO: check if this is still needed
         # FIX QT4 BUG
         # Make sure QT4 has position right
         self.move(*self.XPos())
@@ -1145,10 +1146,10 @@ def xwininfo(windowid=None, name=None):
     else:
         raise ValueError("Either windowid or name have to be specified")
 
-    P = utils.system(cmd % args)
+    P = process.run(cmd % args)
     res = {}
-    if not P.sta:
-        for line in P.out.split('\n'):
+    if not P.returncode:
+        for line in P.stdout.split('\n'):
             s = line.split(':')
             if len(s) < 2:
                 s = s[0].strip().split(' ')
@@ -1181,8 +1182,8 @@ def pidofxwin(windowid):
     #
     # We need a new shell here, otherwise we get a 127 exit.
     #
-    P = utils.system("xprop -id '%s' _NET_WM_PID" % windowid, shell=True)
-    m = re.match(r"_NET_WM_PID\(.*\)\s*=\s*(?P<pid>\d+)", P.out)
+    P = process.run("xprop -id '%s' _NET_WM_PID" % windowid, shell=True)
+    m = re.match(r"_NET_WM_PID\(.*\)\s*=\s*(?P<pid>\d+)", P.stdout)
     if m:
         pid = m.group('pid')
         return int(pid)
@@ -1196,9 +1197,9 @@ def windowExists(windowname):
     On X-Window systems, we can use the xwininfo command to find out whether
     a window with the specified name exists.
     """
-    P = utils.system('xwininfo -name "%s" > /dev/null 2>&1' % windowname,
+    P = process.run('xwininfo -name "%s" > /dev/null 2>&1' % windowname,
                      shell=True)
-    return P.sta == 0
+    return P.returncode == 0
 
 
 def findOldProcesses(max=16):
@@ -1268,7 +1269,7 @@ does not seem to work, use the KILL(9) signal.
 
 
 class Application(QtWidgets.QApplication):
-    """The interactive Qt4 application"""
+    """The interactive Qt application"""
 
     def __init__(self, args):
         QtWidgets.QApplication.__init__(self, args)
@@ -1300,10 +1301,10 @@ def showSplash():
 
 
 def startGUI(args):
-    """Create the QT4 application and GUI.
+    """Create the Qt application and GUI.
 
     A (possibly empty) list of command line options should be provided.
-    QT4 wil remove the recognized QT4 and X11 options.
+    Qt wil remove the recognized Qt and X11 options.
     """
     # This seems to be the only way to make sure the numeric conversion is
     # always correct
@@ -1455,18 +1456,18 @@ pyFormex comes with ABSOLUTELY NO WARRANTY. This is free software, and you are w
         This feature can be turned off by setting
         cfg['warnings/popup'] = False
         """
+        message = str(message)
+        # NOTE: the following will expand our short message identifier
+        # with the expanded message text from messages.py
         full_message = warnings.formatwarning(message, category, filename, lineno, line)
         print(full_message)
-        res, check = draw.showMessage(full_message, level='warning', check="Do not show this warning anymore in future sessions")
-        if check[0]:
-            utils.filterWarning(str(message), category=category)
-            utils.saveWarningFilter(str(message), category=category)
+        res, check = draw.showMessage(full_message, level='warning', check="Do not show this warning anymore in this and future sessions")
+        utils.filterWarning(message, category=category, save=check[0])
 
     if pf.cfg['warnings/popup']:
         warnings.showwarning = show_warning
 
 
-    #print = draw.message
     pf.warning = draw.warning
     pf.error = draw.error
 
@@ -1481,15 +1482,12 @@ pyFormex comes with ABSOLUTELY NO WARRANTY. This is free software, and you are w
         pf.GUI.viewports.setCurrent(0)
         #pf.canvas = pf.GUI.viewports.current
         pf.canvas.setRenderMode(pf.cfg['draw/rendermode'])
-
-        #
-        # PYSIDE: raises (intercepted) exception on startup
-        #
         draw.reset()
 
         # set canvas background
         # (does not work before a draw.reset, do not know why)
-        pf.canvas.setBackground(color=pf.cfg['canvas/bgcolor'], image=pf.cfg['canvas/bgimage'])
+        pf.canvas.setBackground(color=pf.cfg['canvas/bgcolor'],
+                                image=pf.cfg['canvas/bgimage'])
         pf.canvas.update()
 
     # setup the status bar
@@ -1504,8 +1502,10 @@ pyFormex comes with ABSOLUTELY NO WARRANTY. This is free software, and you are w
     # Script/App menu
     if splash is not None:
         splash.showMessage("Loading script/app menu")
-    pf.GUI.scriptmenu = appMenu.createAppMenu(mode='script', parent=pf.GUI.menu, before='help')
-    pf.GUI.appmenu = appMenu.createAppMenu(parent=pf.GUI.menu, before='help')
+    pf.GUI.scriptmenu = appMenu.createAppMenu(
+        parent=pf.GUI.menu, before='help', mode='script')
+    pf.GUI.appmenu = appMenu.createAppMenu(
+        parent=pf.GUI.menu, before='help')
 
     # Create databases
     createDatabases()
@@ -1556,9 +1556,9 @@ pyFormex comes with ABSOLUTELY NO WARRANTY. This is free software, and you are w
     pf.GUI.update()
 
     if pf.cfg['gui/fortune']:
-        P = utils.system(pf.cfg['fortune'])
-        if P.sta == 0:
-            draw.showInfo(P.out)
+        P = process.run(pf.cfg['fortune'])
+        if P.returncode == 0:
+            draw.showInfo(P.stdout)
 
     # display startup warning
     if pf.cfg['gui/startup_warning']:
@@ -1617,7 +1617,7 @@ def runGUI():
         # Make the workdir the current dir
         os.chdir(pf.cfg['workdir'])
         pf.debug("Setting workdir to %s" % pf.cfg['workdir'], pf.DEBUG.INFO)
-    except:
+    except Exception:
         # Save the current dir as workdir
         Settings.updateSettings({'workdir': Path.cwd(), '_save_': True})
     # correctly display the current workdir
@@ -1625,11 +1625,11 @@ def runGUI():
 
     pf.interactive = True
 
-    if pf.cfg['gui/easter_egg'] and False:
+    if pf.cfg['gui/easter_egg'] and True:
         pf.debug("Show easter egg", pf.DEBUG.INFO)
         try:
             draw.playScript(easter_egg, encoding='egg')
-        except:
+        except Exception:
             pass
 
     pf.debug("Start main loop", pf.DEBUG.INFO)
