@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -28,7 +28,6 @@ OpenGL rendering and the pyFormex GUI to image files. There are even
 provisions for automatic saving to a series of files and creating
 a movie from these images.
 """
-from __future__ import absolute_import, division, print_function
 
 from OpenGL import GL
 
@@ -74,7 +73,7 @@ def initialize():
     global image_formats_qt, image_formats_qtr, image_formats_gl2ps, image_formats_fromeps, gl2ps, _producer, _gl2ps_types
 
     # Find interesting supporting software
-    utils.hasExternal('imagemagick')
+    utils.External.has('imagemagick')
     # Set some globals
     pf.debug("Loading Image Formats", pf.DEBUG.IMAGE)
     image_formats_qt = [f.toStr() for f in QtGui.QImageWriter.supportedImageFormats()]
@@ -82,7 +81,7 @@ def initialize():
     if pf.cfg['gui/imagesfromeps']:
         pf.image_formats_qt = []
 
-    if utils.hasModule('gl2ps'):
+    if utils.Module.has('gl2ps'):
 
         import gl2ps
 
@@ -93,7 +92,7 @@ def initialize():
             'tex': gl2ps.GL2PS_TEX,
             'pdf': gl2ps.GL2PS_PDF,
             }
-        if utils.checkVersion('gl2ps', '1.03') >= 0:
+        if utils.Module.check('gl2ps', '>=1.03'):
             _gl2ps_types.update({
                 'svg': gl2ps.GL2PS_SVG,
                 'pgf': gl2ps.GL2PS_PGF,
@@ -174,7 +173,7 @@ def save_canvas(canvas, fn, fmt=None, quality=-1, size=None, alpha=False):
             wc, hc = canvas.getSize()
             try:
                 w, h = size
-            except:
+            except Exception:
                 w, h = wc, hc
             pf.debug("Saving image from virtual buffer with size %sx%s" % (w, h), pf.DEBUG.IMAGE)
             qim = canvas.image(w, h, remove_alpha=not alpha)
@@ -203,7 +202,8 @@ def save_canvas(canvas, fn, fmt=None, quality=-1, size=None, alpha=False):
 
     return sta
 
-initialize()
+# initialize()
+
 
 if gl2ps:
 
@@ -305,11 +305,11 @@ def save_window_rect(filename, format, quality=-1, window='root', crop=None):
     # splitting the command line.
     # TODO: utils should probably be changed to strip quotes after splitting
     P = utils.command(cmd, shell=True)
-    if P.sta:   # He, isn't this standard with utils.command?
-        print(P.sta)
-        print(P.err)
-        print(P.out)
-    return P.sta
+    if P.returncode:   # He, isn't this standard with utils.command?
+        print(P.returncode)
+        print(P.stderr)
+        print(P.stdout)
+    return P.returncode
 
 
 #### USER FUNCTIONS ################
@@ -531,17 +531,19 @@ def createMovie(files, encoder='convert', outfn='output', **kargs):
 
     if encoder == 'convert':
         outfile = outfn.with_suffix('.gif')
-        cmd= "convert "+" ".join(["-{} {}".format(k, kargs[k]) for k in kargs])+" %s %s"%(files, outfile)
+        cmd= "convert " + " ".join(
+            [f"-{k} {kargs[k]}" for k in kargs]) + f" {files} {outfile}"
     elif encoder == 'mencoder':
         outfile = outfn.with_suffix('.avi')
-        cmd = "mencoder \"mf://%s\" -o %s -mf fps=%s -ovc lavc -lavcopts vcodec=msmpeg4v2:vbitrate=%s" % (files, outfile, kargs['fps'], kargs['vbirate'])
+        cmd = (f"mencoder \"mf://{files}\" -o {outfile} -mf fps={kargs['fps']} "
+               f"-ovc lavc -lavcopts vcodec=msmpeg4v2:vbitrate={kargs['vbirate']}")
     else:
         outfile = outfn.with_suffix('.mp4')
-        cmd = "ffmpeg -qscale 1 -r 1 -i %s output.mp4" % files
-    pf.debug(cmd, pf.DEBUG.IMAGE)
+        cmd = f"ffmpeg -qscale 1 -r 1 -i {files} output.mp4"
+        pf.debug(cmd, pf.DEBUG.IMAGE)
     P = utils.command(cmd)
     print("Created file %s" % outfile.resolve())
-    return P.sta
+    return P.returncode
 
 
 def saveMovie(filename, format, windowname=None):
@@ -560,10 +562,10 @@ def saveMovie(filename, format, windowname=None):
     cmd = "xvidcap --fps 5 --window %s --file %s" % (windowid, filename)
     pf.debug(cmd, pf.DEBUG.IMAGE)
     P = utils.command(cmd)
-    return P.sta
+    return P.returncode
 
-
-initialize()
+if not pf.sphinx:
+    initialize()
 
 
 ### End
