@@ -1,11 +1,11 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -25,12 +25,11 @@
 
 Part of this code was borrowed from the TrollTech Qt examples.
 """
-from __future__ import absolute_import, division, print_function
-
 
 caption = "pyFormex Image Viewer"
 
-from pyformex.gui import QtCore, QtGui, QtWidgets, QPixmap, QImage
+import os, sys
+from PySide2 import QtCore, QtGui, QtWidgets
 
 
 def tr(s):
@@ -49,21 +48,21 @@ class ImageViewer(QtWidgets.QMainWindow):
 
     Parameters:
 
-    - `parent`: The parent Qt4 widget (the Qt4 app in the stand alone case).
+    - `parent`: The parent Qt widget (the Qt app in the stand alone case).
     - `path`: string: the full path to the image to be initially displayed.
     """
 
     def __init__(self, parent=None, path=None):
-        QtGui.QMainWindow.__init__(self)
+        QtWidgets.QMainWindow.__init__(self)
 
         self.parent = parent
         self.filename = path
-        self.image = QtGui.QLabel()
+        self.image = QtWidgets.QLabel()
         self.image.setBackgroundRole(QtGui.QPalette.Base)
-        self.image.setSizePolicy(QtGui.QSizePolicy.Ignored, QtGui.QSizePolicy.Ignored)
+        self.image.setSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
         #self.image.setScaledContents(True)
 
-        self.scroll = QtGui.QScrollArea()
+        self.scroll = QtWidgets.QScrollArea()
         self.scroll.setBackgroundRole(QtGui.QPalette.Dark)
         self.scroll.setWidget(self.image)
         self.scroll.setWidgetResizable(True)
@@ -74,29 +73,29 @@ class ImageViewer(QtWidgets.QMainWindow):
 
         self.setWindowTitle(tr(caption))
         self.resize(500, 400)
-        self.setSizePolicy(QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Minimum)
+        self.setSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
 
         if path:
             self.openfile(path)
 
 
     def openfile(self, filename=None):
-        if filename is None:
+        if not filename:
             filename = self.filename
             if filename is None:
                 filename = QtCore.QDir.currentPath()
-            filename = QtGui.QFileDialog.getOpenFileName(self, tr("Open File"), filename)
+            filename = QtWidgets.QFileDialog.getOpenFileName(self, tr("Open File"), filename)[0]
             if not filename:
                 return
 
-        image = QImage(filename)
+        image = QtGui.QImage(filename)
         if image.isNull():
-            QtGui.QMessageBox.information(self, tr(caption), tr("Cannot load %1.").arg(filename))
+            QtWidgets.QMessageBox.information(self, tr(caption), tr("Cannot load {}".format(filename)))
             return
 
-        #print("Size %sx%s" % (image.width(),image.height()))
+        print("Size %sx%s" % (image.width(),image.height()))
         self.filename = str(filename)
-        self.image.setPixmap(QPixmap.fromImage(image))
+        self.image.setPixmap(QtGui.QPixmap.fromImage(image))
         self.scaleFactor = 1.0
 
         self.printAct.setEnabled(True)
@@ -113,7 +112,7 @@ class ImageViewer(QtWidgets.QMainWindow):
             return
 
         self.printer = QtGui.QPrinter()
-        dialog = QtGui.QPrintDialog(self.printer, self)
+        dialog = QtWidgets.QPrintDialog(self.printer, self)
         if dialog.exec_():
             painter = QtGui.QPainter(self.printer)
             rect = painter.viewport()
@@ -148,7 +147,7 @@ class ImageViewer(QtWidgets.QMainWindow):
 
 
     def about(self):
-        QtGui.QMessageBox.about(self, tr("About pyFormex Image Viewer"), tr("""
+        QtWidgets.QMessageBox.about(self, tr("About pyFormex Image Viewer"), tr("""
 <p>The <b>pyFormex Image Viewer</b> was shaped after the
 <b>Image Viewer</b> from the TrollTech Qt documentation.</p>
 <p>The example shows how to combine QLabel
@@ -169,73 +168,73 @@ shows how to use QPainter to print an image.</p>
 
 
     def createActions(self):
-        self.openAct = QtGui.QAction(tr("&Open..."), self)
+        self.openAct = QtWidgets.QAction(tr("&Open..."), self)
         self.openAct.setShortcut(tr("Ctrl+O"))
         self.openAct.triggered.connect(self.openfile)
 
-        self.printAct = QtGui.QAction(tr("&Print..."), self)
+        self.printAct = QtWidgets.QAction(tr("&Print..."), self)
         self.printAct.setShortcut(tr("Ctrl+P"))
         self.printAct.setEnabled(False)
         self.printAct.triggered.connect(self.print_)
 
 
-        self.zoomInAct = QtGui.QAction(tr("Zoom &In (25%)"), self)
+        self.zoomInAct = QtWidgets.QAction(tr("Zoom &In (25%)"), self)
         self.zoomInAct.setShortcut(tr("Ctrl++"))
         self.zoomInAct.setEnabled(False)
         self.zoomInAct.triggered.connect(self.zoomIn)
 
-        self.zoomOutAct = QtGui.QAction(tr("Zoom &Out (25%)"), self)
+        self.zoomOutAct = QtWidgets.QAction(tr("Zoom &Out (25%)"), self)
         self.zoomOutAct.setShortcut(tr("Ctrl+-"))
         self.zoomOutAct.setEnabled(False)
         self.zoomOutAct.triggered.connect(self.zoomOut)
 
-        self.normalSizeAct = QtGui.QAction(tr("&Normal Size"), self)
+        self.normalSizeAct = QtWidgets.QAction(tr("&Normal Size"), self)
         self.normalSizeAct.setShortcut(tr("Ctrl+S"))
         self.normalSizeAct.setEnabled(False)
         self.normalSizeAct.triggered.connect(self.normalSize)
 
-        self.fitToImageAct = QtGui.QAction(tr("Fit &Window to Image"), self)
+        self.fitToImageAct = QtWidgets.QAction(tr("Fit &Window to Image"), self)
         self.fitToImageAct.setShortcut(tr("Ctrl+W"))
         self.fitToImageAct.setEnabled(False)
         #self.fitToImageAct.setCheckable(True)
         self.fitToImageAct.triggered.connect(self.fitToImage)
 
-        self.fitToWindowAct = QtGui.QAction(tr("&Fit Image to Window"), self)
+        self.fitToWindowAct = QtWidgets.QAction(tr("&Fit Image to Window"), self)
         self.fitToWindowAct.setShortcut(tr("Ctrl+F"))
         self.fitToWindowAct.setEnabled(False)
         self.fitToWindowAct.setCheckable(True)
         self.fitToWindowAct.triggered.connect(self.fitToWindow)
 
-        self.aboutAct = QtGui.QAction(tr("&About"), self)
+        self.aboutAct = QtWidgets.QAction(tr("&About"), self)
         self.aboutAct.triggered.connect(self.about)
 
-        if isinstance(self.parent, QtGui.QApplication):
+        if isinstance(self.parent, QtWidgets.QApplication):
 
-            self.exitAct = QtGui.QAction(tr("E&xit"), self)
+            self.exitAct = QtWidgets.QAction(tr("E&xit"), self)
             self.exitAct.setShortcut(tr("Ctrl+Q"))
             self.exitAct.triggered.connect(self.close)
 
-            self.aboutQtAct = QtGui.QAction(tr("About &Qt"), self)
+            self.aboutQtAct = QtWidgets.QAction(tr("About &Qt"), self)
             self.aboutQtAct.triggered.connect(self.parent.aboutQt)
 
         elif isinstance(self.parent, QtWidgets.QDialog):
 
-            self.acceptAct = QtGui.QAction(tr("&Accept"), self)
+            self.acceptAct = QtWidgets.QAction(tr("&Accept"), self)
             self.acceptAct.setShortcut(tr("Ctrl+A"))
             self.acceptAct.triggered.connect(self.parent.accept)
 
-            self.rejectAct = QtGui.QAction(tr("&Reject"), self)
+            self.rejectAct = QtWidgets.QAction(tr("&Reject"), self)
             self.rejectAct.setShortcut(tr("Ctrl+Q"))
             self.rejectAct.triggered.connect(self.parent.reject)
 
 
     def createMenus(self):
-        self.fileMenu = QtGui.QMenu(tr("&File"), self)
+        self.fileMenu = QtWidgets.QMenu(tr("&File"), self)
         self.fileMenu.addAction(self.openAct)
         self.fileMenu.addAction(self.printAct)
         self.fileMenu.addSeparator()
 
-        self.viewMenu = QtGui.QMenu(tr("&View"), self)
+        self.viewMenu = QtWidgets.QMenu(tr("&View"), self)
         self.viewMenu.addAction(self.zoomInAct)
         self.viewMenu.addAction(self.zoomOutAct)
         self.viewMenu.addAction(self.normalSizeAct)
@@ -243,14 +242,14 @@ shows how to use QPainter to print an image.</p>
         self.viewMenu.addAction(self.fitToImageAct)
         self.viewMenu.addAction(self.fitToWindowAct)
 
-        self.helpMenu = QtGui.QMenu(tr("&Help"), self)
+        self.helpMenu = QtWidgets.QMenu(tr("&Help"), self)
         self.helpMenu.addAction(self.aboutAct)
 
         self.menuBar().addMenu(self.fileMenu)
         self.menuBar().addMenu(self.viewMenu)
         self.menuBar().addMenu(self.helpMenu)
 
-        if isinstance(self.parent, QtGui.QApplication):
+        if isinstance(self.parent, QtWidgets.QApplication):
             self.fileMenu.addAction(self.exitAct)
             self.helpMenu.addAction(self.aboutQtAct)
         elif isinstance(self.parent, QtWidgets.QDialog):
@@ -285,7 +284,7 @@ shows how to use QPainter to print an image.</p>
 def main():
     import sys
     global app
-    app = QtGui.QApplication(sys.argv)
+    app = QtWidgets.QApplication(sys.argv)
     if len(sys.argv) > 1:
         path = sys.argv[1]
     else:
