@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -26,7 +26,6 @@
 This modules implements specialized classes and functions for building
 the pyFormex GUI menu system.
 """
-from __future__ import absolute_import, division, print_function
 
 from gettext import gettext as _
 
@@ -42,20 +41,13 @@ from pyformex.gui import (
 from collections import OrderedDict
 
 
-def resetWarnings():
-    """Reset the warning filters to the default."""
-    del pf.prefcfg['warnings/filters']
-    print("This will only become effective in your future sessions!")
-    print("FILTERS:", pf.prefcfg['warnings/filters'])
-
-
 # The menu actions can be simply function names instead of strings, if the
 # functions have already been defined here.
 
 def printwindow():
     pf.app.syncX()
     r = pf.GUI.frameGeometry()
-    print("Qt4 geom(w,h,x,y): %s,%s,%s,%s" % (r.width(), r.height(), r.x(), r.y()))
+    print("Qt geom(w,h,x,y): %s,%s,%s,%s" % (r.width(), r.height(), r.x(), r.y()))
     print("According to xwininfo, (x,y) is %s,%s" % pf.GUI.XPos())
 
 
@@ -107,7 +99,10 @@ def printModules():
 
 
 def printLastCommand():
-    print(utils.lastCommandReport())
+    """Print a nice report of the outcome of the last command"""
+    print('=' * 8 + " LAST COMMAND REPORT " + '=' * 21)
+    print(utils.last_command)
+    print('=' * 50)
 
 
 MenuData = (_('&Actions'), [
@@ -122,7 +117,6 @@ MenuData = (_('&Actions'), [
     ("---", None),
     ## (_('&Reset Picking Mode'),resetPick),
     (_('&Reset GUI'), draw.resetGUI),
-    (_('&Reset Warning Filters'), resetWarnings),
     (_('&Force Finish Script'), script.force_finish),
     (_('&Unload Current App'), unloadCurrentApp),
     ## (_('&Execute single statement'),command),
@@ -138,7 +132,7 @@ MenuData = (_('&Actions'), [
     (_('&Print Bbox'), draw.printbbox),
     (_('&Print Viewport Settings'), draw.printviewportsettings),
     (_('&Print Window Geometry'), printwindow),
-    (_('&Correct the Qt4 Geometry'), moveCorrect),
+    (_('&Correct the Qt Geometry'), moveCorrect),
     (_('&Save Geometry'), saveGeometry),
     (_('&Restore Geometry'), restoreGeometry),
     (_('&Toggle Input Timeout'), toolbar.timeout),
