@@ -1,11 +1,11 @@
-#    -*- coding: utf-8 -*-
+#
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -24,7 +24,6 @@
 """Display help
 
 """
-from __future__ import absolute_import, division, print_function
 
 import sys
 from gettext import gettext as _
@@ -51,7 +50,6 @@ def help(page=None):
         browser = pf.cfg['browser']
     else:
         browser = pf.cfg['viewer']
-    print([browser, page])
     utils.system([browser, page], wait=False)
 
 
@@ -68,13 +66,6 @@ def catchAndDisplay(expression):
         sys.stdout = save
 
 
-## def qappargs():
-##     """Display informeation on the Qt application arguments."""
-##     qtversion = utils.hasModule('pyqt4')
-##     qtversion = '.'.join(qtversion.split('.')[:2])
-##     link = "http://doc.trolltech.com/%s/qapplication.html#QApplication" % qtversion
-##     help(link)
-
 def opengl():
     """Display the OpenGL format description."""
     from pyformex.opengl import canvas
@@ -257,12 +248,13 @@ def DevLinksMenuData():
     dev2to3 = devdir / "p3.rst"
     devtodo = devdir / "TODO"
     devhowto = devdir / "HOWTO-dev.rst"
+    devstyle = devdir / "HOWTO-style.rst"
     devapp = devdir / "scripts-apps.rst"
     devextra = devdir / "install-extra.rst"
     developer = [
         ('Developer HOWTO', devhowto),
-        ('Migration to Python3', dev2to3),
         ('Scripts versus Apps', devapp),
+        ('pyFormex coding style guide', devstyle),
         ('pyFormex TODO list', devtodo),
         ('Installation of extra software', devextra),
         ('Numpy documentation guidelines', 'http://github.com/numpy/numpy/blob/master/doc/HOWTO_DOCUMENT.rst.txt'),
@@ -277,15 +269,15 @@ def DevLinksMenuData():
 def install_external(pkgdir, prgname):
     extdir = pf.cfg['pyformexdir'] / 'extra' / pkgdir
     P = utils.system("cd %s; make && gksu make install" % str(extdir), shell=True)
-    if P.sta:
-        info = P.out
+    if P.returncode:
+        info = P.stdout
     else:
-        if utils.hasExternal(prgname, force=True):
+        if utils.External.has(prgname, force=True):
             info = "Succesfully installed %s" % pkgdir
         else:
             info ="You should now restart pyFormex!"
     draw.showInfo(info)
-    return P.sta
+    return P.returncode
 
 def install_dxfparser():
     install_external('dxfparser', 'pyformex-dxfparser')
@@ -302,7 +294,7 @@ if pf.installtype in 'SG':
 
     MenuData[1].extend([
         ('---', None),
-        (_('&Developer Guidelines'), DevLinksMenuData()),
+        (_('&Developer Guides'), DevLinksMenuData()),
         ])
 
     MenuData[1].append((_('&Install Externals'), [
