@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -24,7 +24,6 @@
 """Functions for the Pref menu.
 
 """
-from __future__ import absolute_import, division, print_function
 
 from gettext import gettext as _
 
@@ -203,7 +202,7 @@ def settings():
     guiscripts = [
         pf.cfg['webgl/guiscript'],
         #        "https://net.feops.com/public/webgl/xtk_xdat.gui.js",
-        #       (pf.cfg['datadir'] / 'xtk_xdat.js').as_uri(),
+        #       (pf.cfg['datadir'] / 'xtk_xdat.gui.js').as_uri(),
         ]
     guiscripts.append('custom')
     webgl_settings = [
@@ -595,6 +594,16 @@ def setOptions():
                 pf.GUI.board.redirect(pf.options.redirect)
 
 
+def resetWarnings():
+    """Reset the warning filters to the default."""
+    if draw.warning('This will remove all your warning filters and return them to factory defaults. This may only become effective in your next session.', actions=['Cancel', 'OK']) == 'OK':
+        del pf.prefcfg['warnings/filters']
+        # There should never be such a value, but just in case:
+        del pf.cfg['warnings/filters']
+        # Reload the filters here to activate the new setting
+        utils.resetWarningFilters()
+
+
 def resetDefaults():
     if draw.warning('This will reset all the current pyFormex settings to your stored defaults.', actions=['Cancel', 'OK']) == 'OK':
         pf.cfg.clear()
@@ -736,6 +745,7 @@ MenuData = (_('&Settings'), [
     (_('&Options'), setOptions),
     (_('&Draw Wait'), setDrawWait),
     (_('&Rendering Params'), setRendering),
+    (_('&Reset Warning Filters'), resetWarnings),
     (_('&Reset to My Defaults'), resetDefaults),
     (_('&Reset to Factory Defaults'), resetFactory),
     ('---', None),
