@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -24,7 +24,6 @@
 """Interactive Python interpreter for pyFormex.
 
 """
-from __future__ import absolute_import, division, print_function
 
 
 import sys
@@ -34,9 +33,6 @@ import pyformex as pf
 from pyformex.gui import QtGui, QtCore, QtWidgets
 from pyformex.gui.guimain import Board
 
-if pf.PY2:
-    range = xrange
-
 
 ##########################################################################
 
@@ -182,7 +178,6 @@ parent=None):
 
 
     def runCommand(self):
-        #print("runcommand")
         command = self.getCommand()
         self.addToHistory(command)
 
@@ -208,7 +203,7 @@ parent=None):
                 self.runSource(command)
             except SystemExit:
                 self.close()
-            except:
+            except Exception:
                 traceback_lines = traceback.format_exc().split('\n')
                 # Remove traceback mentioning this file, and a linebreak
                 for i in (3, 2, 1, -1):
@@ -379,7 +374,7 @@ class OtherPyConsole(Board):
         ##             self.recallHistory()
         ##         else:
         ##             self.clearCurrentBlock()
-        ##     except:
+        ##     except Exception:
         ##         pass
         ##     return None
 
@@ -390,7 +385,7 @@ class OtherPyConsole(Board):
         ##             self.recallHistory()
         ##         else:
         ##             self.historyIndex = len(self.history)
-        ##     except:
+        ##     except Exception:
         ##         pass
         ##     return None
 
@@ -430,7 +425,7 @@ class OtherPyConsole(Board):
                     if line[-1] == ':':
                         self.multiLine = True
                     self.history.insert(0, line)
-                except:
+                except Exception:
                     self.haveLine = False
 
                 if self.haveLine and self.multiLine:  # multi line command
