@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -21,16 +21,14 @@
 ##  You should have received a copy of the GNU General Public License
 ##  along with this program.  If not, see http://www.gnu.org/licenses/.
 ##
-"""Interactive OpenGL Canvas embedded in a Qt4 widget.
+"""Interactive OpenGL Canvas embedded in a Qt widget.
 
 This module implements user interaction with the OpenGL canvas defined in
 module :mod:`canvas`.
 `QtCanvas` is a single interactive OpenGL canvas, while `MultiCanvas`
 implements a dynamic array of multiple canvases.
 """
-from __future__ import absolute_import, division, print_function
 
-import logging
 import math
 import numpy as np
 from OpenGL import GL
@@ -40,7 +38,7 @@ from numpy import *
 
 
 import pyformex as pf
-from pyformex import round, utils
+from pyformex import utils
 
 from pyformex.opengl import canvas
 from pyformex.gui import (
@@ -103,13 +101,13 @@ _modifiername = ['NONE', 'SHIFT', 'CTRL', 'ALT', 'META']
 def modifierFlag(mod):
     try:
         return _modifiers[_modifiername.index(mod)]
-    except:
+    except Exception:
         return NONE
 
 def modifierName(mod):
     try:
         return _modifiername[_modifiers.index(mod)]
-    except:
+    except Exception:
         return 'UNKNOWN'
 
 # mouse modifiers used during picking actions
@@ -146,7 +144,7 @@ def setOpenGLFormat():
         try:
             major, minor = [int(o) for o in pf.options.opengl.split('.')]
             fmt.setVersion(major, minor)
-        except:
+        except Exception:
             pass
 
     if pf.options.multisample:
@@ -327,7 +325,7 @@ class CanvasMouseHandler(object):
         pf.debug("MOUSE SAVED %s" % self.mousefncsaved[mod][button], pf.DEBUG.MOUSE)
         try:
             func = self.mousefncsaved[mod][button].pop()
-        except:
+        except Exception:
             pf.debug("AAAAAHHH, COULD NOT POP", pf.DEBUG.MOUSE)
             func = None
         self.mousefnc[mod][button] = func
@@ -352,7 +350,7 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
     This class provides interactive functionality for the OpenGL canvas
     provided by the :class:`canvas.Canvas` class.
 
-    Interactivity is highly dependent on Qt4. Putting the interactive
+    Interactivity is highly dependent on Qt. Putting the interactive
     functions in a separate class makes it esier to use the Canvas class
     in non-interactive situations or combining it with other GUI toolsets.
 
@@ -685,7 +683,7 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
         pf.debug("resetMouse %s %s" % (button, mod), pf.DEBUG.MOUSE)
         try:
             func = self.mousefncsaved[mod][button].pop()
-        except:
+        except Exception:
             func = None
         self.mousefnc[mod][button] = func
         if button == LEFT and mod == NONE:
@@ -721,7 +719,7 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
         self.resetMouse(LEFT)
         try:
             self.rectangle_func(*self.rectangle)
-        except:
+        except Exception:
             pass
         self.update()
         self.selection_timer = None
@@ -810,16 +808,16 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
     def wait_selection(self):
         """Wait for the user to interactively make a selection."""
         pf.debug("WAIT SELECTION", pf.DEBUG.GUI)
-        #logging.info("wait_selection: %s" % self.events)
+        #pf.logger.debug("wait_selection: %s" % self.events)
         self.selection_timer = QtCore.QThread
         self.selection_busy = True
-        #logging.info("now entering wait")
+        #pf.logger.debug("now entering wait")
         while self.selection_busy:
             if self.events:
                 self.emit_events(self.events.pop(0))
             self.selection_timer.msleep(20)
             pf.app.processEvents()
-        #logging.info("Done waiting")
+        #pf.logger.debug("Done waiting")
         pf.debug("WAIT SELECTION DONE", pf.DEBUG.GUI)
 
 
@@ -857,7 +855,7 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
 
 
     def emit_events(self, events):
-        logging.info("sending events %s" % events)
+        pf.logger.debug("sending events %s" % events)
         for event in events:
             pf.app.sendEvent(self, event)
 
@@ -1494,7 +1492,7 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
         self.button = e.button()
         self.mod = e.modifiers() & ALLMODS
         #imod = int(self.mod)
-        #bmod = "{:032b}".format(imod)
+        #bmod = f"{imod:032b}"
         #print("PRESS BUTTON %s WITH MODIFIER %s(%s)" % (self.button,bmod,imod))
         func = self.getMouseFunc()
         if func:
@@ -1653,7 +1651,7 @@ class MultiCanvas(QtWidgets.QGridLayout):
         if settings is None:
             try:
                 settings = self.current.settings
-            except:
+            except Exception:
                 settings = {}
         pf.debug("Create new viewport with settings:\n%s"%settings, pf.DEBUG.CANVAS)
         ##
@@ -1884,7 +1882,7 @@ Viewport %s;  Current:%s;  Settings:
         """Load the canvas settings from file"""
         try:
             C = Config(filename)
-        except:
+        except Exception:
             raise ValueError("Invalid Camera save file: %s" % filename)
         self.loadConfig(C)
 
