@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -37,14 +37,14 @@ of collections of simple geometric data: points, lines, triangles, tetrahedrons.
 The prefered way to compute inertia data of a geometric model is through the
 :meth:`Geometry.inertia` methods.
 """
-from __future__ import absolute_import, division, print_function
+
+import numpy as np
 
 from pyformex import arraytools as at
 from pyformex.coords import Coords
 from pyformex.formex import Formex
 from pyformex.coordsys import CoordSys
 
-import numpy as np
 
 class Tensor(np.ndarray):
     """A second order symmetric(!) tensor in 3D vector space.
@@ -110,17 +110,17 @@ class Tensor(np.ndarray):
         [0, 5, 4],
         [5, 1, 3],
         [4, 3, 2],
-        ])
+    ])
 
 
     def __new__(clas, data=None, symmetric=True, cs=None):
         """Create a new Tensor instance"""
         try:
             data = at.checkArray(data, shape=(3, 3), kind='f', allow='if')
-        except:
+        except Exception:
             try:
                 data = at.checkArray(data, shape=(6,), kind='f', allow='if')
-            except:
+            except Exception:
                 raise ValueError("Data should have shape (3,3) or (6,)")
             data = data[Tensor._contracted_index]
         ar = data.view(clas)
@@ -139,26 +139,32 @@ class Tensor(np.ndarray):
         :meth:`__new__` method) defines new attributes, these atttributes
         need to be reset in this method.
         """
-        if obj is None: return
+        if obj is None:
+            return
         self.cs = getattr(obj, 'cs', CoordSys())
-        #~ pass  # currently no new attributes defined in __new__
+        # currently no new attributes defined in __new__
         # self._newattr = getattr(obj, '_newattr', None)
 
     @property
     def xx(self):
         return self[0, 0]
+
     @property
     def yy(self):
         return self[1, 1]
+
     @property
     def zz(self):
         return self[2, 2]
+
     @property
     def yz(self):
         return self[1, 2]
+
     @property
     def zx(self):
         return self[0, 2]
+
     @property
     def xy(self):
         return self[0, 1]
@@ -230,7 +236,7 @@ class Tensor(np.ndarray):
         if sort:
             s = prin.argsort()[::-1]
             prin, axes = prin[s], axes[s]
-        if right_handed and not at.allclose(at.normalize(np.cross(axes[0], axes[1])), axes[2]):
+        if right_handed and at.vectorTripleProduct(*axes) < 0.:
             axes[2] = -axes[2]
         return prin, axes
 
@@ -341,16 +347,17 @@ class Inertia(Tensor):
         """
 
         trl = at.checkArray(ref, shape=(3,), kind='f') - self.ctr
-        return self.translate(self, trl, toG=toG)
+        return self.translate(trl, toG=toG)
 
 
     def toCS(self, cs):
         """Transform the coordinates to another CoordSys.
 
         """
-        raise ImplementationError("Inertia.toCS is currently not implemented")
+        raise NotImplementedError("Inertia.toCS is currently not implemented")
         # We need to check the following (after transposing CoordSys.rot)
-        return self.tensor.translateTo(cs.trl) + self.tensor.rotate(np.dot(self.CS.rot.T, cs.rot))
+        # return self.tensor.translateTo(cs.trl) + self.tensor.rotate(
+        #     np.dot(self.CS.rot.T, cs.rot))
 
 
 def point_inertia(X, mass=None, center_only=False):
@@ -389,10 +396,10 @@ def point_inertia(X, mass=None, center_only=False):
     Xc = X - C
     x, y, z = Xc[:, 0], Xc[:, 1], Xc[:, 2]
     xx, yy, zz, yz, zx, xy = x*x, y*y, z*z, y*z, z*x, x*y
-    I = np.column_stack([yy+zz, zz+xx, xx+yy, -yz, -zx, -xy])
+    I = np.column_stack([yy+zz, zz+xx, xx+yy, -yz, -zx, -xy])  # noqa: E741
     if mass is not None:
-        I *= mass
-    I = I.sum(axis=0)
+        I *= mass  # noqa: E741
+    I = I.sum(axis=0)  # noqa: E741
     return M, C, I
 
 
@@ -443,9 +450,7 @@ def surface_volume_inertia(x, center_only=False):
     def K(x, y):
         x1, x2, x3 = x[:, 0], x[:, 1], x[:, 2]
         y1, y2, y3 = y[:, 0], y[:, 1], y[:, 2]
-        return x1 * (y1+y2+y3) + \
-               x2 * (y2+y3) + \
-               x3 * (y3)
+        return x1 * (y1+y2+y3) + x2 * (y2+y3) + x3 * (y3)
 
     x = at.checkArray(x, shape=(-1, 3, 3), kind='f')
     v = surface_volume(x)
@@ -465,7 +470,7 @@ def surface_volume_inertia(x, center_only=False):
     a3 = ((K(x1, x2) + K(x2, x1)) * v).sum(axis=0)
     a4 = ((K(x2, x0) + K(x0, x2)) * v).sum(axis=0)
     a5 = ((K(x0, x1) + K(x1, x0)) * v).sum(axis=0)
-    I = np.array([a0, a1, a2, a3, a4, a5]) / 20.
+    I = np.array([a0, a1, a2, a3, a4, a5]) / 20.  # noqa: E741
     return V, C, I
 
 
@@ -517,16 +522,14 @@ def tetrahedral_inertia(x, density=None, center_only=False):
     >>> print(tetrahedral_volume(F.coords))
     [ 1873.23]
     >>> print(*tetrahedral_inertia(F.coords))
-    1873.23 1873.23 [ 15.92  0.78  3.73] [ 43520.32 194711.28 191168.77   4417.66 -46343.16  11996.2 ]
+    1873.23 1873.23 [ 15.92  0.78  3.73] \
+    [ 43520.32 194711.28 191168.77   4417.66 -46343.16  11996.2 ]
 
     """
     def K(x, y):
         x1, x2, x3, x4 = x[:, 0], x[:, 1], x[:, 2], x[:, 3]
         y1, y2, y3, y4 = y[:, 0], y[:, 1], y[:, 2], y[:, 3]
-        return x1 * (y1+y2+y3+y4) + \
-               x2 * (y2+y3+y4) + \
-               x3 * (y3+y4) + \
-               x4 * (y4)
+        return x1 * (y1+y2+y3+y4) + x2 * (y2+y3+y4) + x3 * (y3+y4) + x4 * (y4)
 
     x = at.checkArray(x, shape=(-1, 4, 3), kind='f')
     v = tetrahedral_volume(x)
@@ -549,7 +552,7 @@ def tetrahedral_inertia(x, density=None, center_only=False):
     a3 = ((K(x1, x2) + K(x2, x1)) * v).sum(axis=0)
     a4 = ((K(x2, x0) + K(x0, x2)) * v).sum(axis=0)
     a5 = ((K(x0, x1) + K(x1, x0)) * v).sum(axis=0)
-    I = np.array([a0, a1, a2, a3, a4, a5]) / 20.
+    I = np.array([a0, a1, a2, a3, a4, a5]) / 20.  # noqa: E741
     return V, M, C, I
 
 
