@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -26,7 +26,6 @@
 This tries to load the compiled libraries, and replaces those that failed
 to load with the (slower) Python versions.
 """
-from __future__ import absolute_import, division, print_function
 
 import pyformex as pf
 __all__ = ['misc', 'nurbs', 'accelerated']
@@ -35,17 +34,13 @@ misc = nurbs = None
 accelerated = []
 
 
-def checkVersion(lib):
-    pf.debug("Succesfully loaded the pyFormex compiled library %s" % lib.__name__, pf.DEBUG.LIB)
-    pf.debug("  Library version is %s" % lib.__version__, pf.DEBUG.LIB)
-    if not lib.__version__ == pf.__version__:
-        if pf.PY3:
-            target = 'lib3'
-        if pf.PY2:
-            target = 'lib'
-
-        raise RuntimeError("Incorrect acceleration library version (have %s, required %s)\nIf you are running pyFormex directly from sources, this might mean you have to run 'make %s' in the top directory of your pyFormex source tree.\nElse, this probably means pyFormex was not correctly installed." % (lib.__version__, pf.__version__, target))
-    accelerated.append(lib)
+def checkVersion(module):
+    pf.debug("Succesfully loaded the pyFormex compiled module %s" % module.__name__, pf.DEBUG.LIB)
+    pf.debug("  Module version is %s" % module.__version__, pf.DEBUG.LIB)
+    if not module.__version__ == pf.__version__:
+        target = 'lib3'
+        raise RuntimeError("Incorrect acceleration module version (have %s, required %s)\nIf you are running pyFormex directly from sources, this might mean you have to run 'make %s' in the top directory of your pyFormex source tree.\nElse, this probably means pyFormex was not correctly installed." % (module.__version__, pf.__version__, target))
+    accelerated.append(module)
 
 
 accelerate = gui = False
@@ -87,5 +82,4 @@ pf.debug(nurbs, pf.DEBUG.LIB)
 # make sure we could at least import one version
 assert(misc is not None)
 
-
 # End
