@@ -1,11 +1,11 @@
 /* */
 //
-//  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+//  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 //  pyFormex is a tool for generating, manipulating and transforming 3D
 //  geometrical models by sequences of mathematical operations.
 //  Home page: http://pyformex.org
 //  Project page:  http://savannah.nongnu.org/projects/pyformex/
-//  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+//  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 //  Distributed under the GNU General Public License version 3 or later.
 //
 //  This program is free software: you can redistribute it and/or modify
@@ -35,7 +35,7 @@
 
 /****************** LIBRARY VERSION AND DOCSTRING *******************/
 
-static char *__version__ = "1.0.7";
+static char *__version__ = "2.0";
 static char *__doc__ = "pyformex.lib.misc_\n\
 \n\
 This module provides accelerated versions of miscellaneous pyFormex functions.\n\
@@ -59,217 +59,6 @@ float dotprod(float *a, int ia, float *b, int ib, int n)
   return t;
 }
 
-#if PY_MAJOR_VERSION >= 3
-//  PyFile_AsFile does not exist in Python3 !!
-//  so we do not have these accelerated functions
-#else
-
-/**************************************************** tofile_float32 ****/
-/* Write an array to file */
-/*
-   Use:  tofile_float32(data,file,format)
-   The elements of a 2-D array are written in row order with the given format
-   to the open file. After each row, a newline is written.
-*/
-
-static PyObject * tofile_float32(PyObject *dummy, PyObject *args)
-{
-  PyObject *arg1=NULL, *arg2=NULL;
-  PyObject *arr1=NULL;
-  FILE *fp;
-  char *fmt; /* single element format */
-
-  if (!PyArg_ParseTuple(args, "OOs", &arg1, &arg2, &fmt)) return NULL;
-  arr1 = PyArray_FROM_OTF(arg1, NPY_FLOAT, NPY_ARRAY_IN_ARRAY);
-  if (arr1 == NULL) return NULL;
-  fp = PyFile_AsFile(arg2);
-  if (!fp) goto fail;
-
-  float *val;
-  val = (float *)PYARRAY_DATA(arr1);
-  npy_intp * dims;
-  dims = PYARRAY_DIMS(arg1);
-  int nr,nc;
-  nr = dims[0];
-  nc = dims[1];
-
-  int i,j;
-  for (i=0; i<nr; i++) {
-    for (j=0; j<nc; j++) {
-      fprintf(fp,fmt,*(val++));
-    }
-    fprintf(fp,"\n");
-  }
-
-  /* Clean up and return */
-  Py_DECREF(arr1);
-  Py_INCREF(Py_None);
-  return Py_None;
-
- fail:
-  Py_XDECREF(arr1);
-  return NULL;
-}
-
-/**************************************************** tofile_int32 ****/
-/* Write an array to file */
-
-static PyObject * tofile_int32(PyObject *dummy, PyObject *args)
-{
-  PyObject *arg1=NULL, *arg2=NULL;
-  PyObject *arr1=NULL;
-  FILE *fp;
-  char *fmt; /* single element format */
-
-  if (!PyArg_ParseTuple(args, "OOs", &arg1, &arg2, &fmt)) return NULL;
-  arr1 = PyArray_FROM_OTF(arg1, NPY_INT, NPY_ARRAY_IN_ARRAY);
-  if (arr1 == NULL) return NULL;
-  fp = PyFile_AsFile(arg2);
-  if (!fp) goto fail;
-
-  int *val;
-  val = (int *)PYARRAY_DATA(arr1);
-  npy_intp * dims;
-  dims = PYARRAY_DIMS(arg1);
-  int nr,nc;
-  nr = dims[0];
-  nc = dims[1];
-
-  int i,j;
-  for (i=0; i<nr; i++) {
-    for (j=0; j<nc; j++) {
-      fprintf(fp,fmt,*(val++));
-    }
-    fprintf(fp,"\n");
-  }
-
-  /* Clean up and return */
-  Py_DECREF(arr1);
-  Py_INCREF(Py_None);
-  return Py_None;
-
- fail:
-  Py_XDECREF(arr1);
-  return NULL;
-}
-
-/**************************************************** tofile_ifloat32 ****/
-/* Write an indexed array to file */
-/*
-   Use:  tofile_ifloat32(ind,data,file,format)
-   This is like tofile_float32, but each row from data is preceded with an
-   index number from ind.
-*/
-
-
-static PyObject * tofile_ifloat32(PyObject *dummy, PyObject *args)
-{
-  PyObject *arg1=NULL, *arg2=NULL, *arg3=NULL;
-  PyObject *arr1=NULL, *arr2=NULL;
-  FILE *fp;
-  char *fmt; /* single element format */
-
-  if (!PyArg_ParseTuple(args, "OOOs", &arg1, &arg2, &arg3, &fmt)) return NULL;
-  arr1 = PyArray_FROM_OTF(arg1, NPY_INT, NPY_ARRAY_IN_ARRAY);
-  if (arr1 == NULL) return NULL;
-  arr2 = PyArray_FROM_OTF(arg2, NPY_FLOAT, NPY_ARRAY_IN_ARRAY);
-  if (arr2 == NULL) goto fail;
-  fp = PyFile_AsFile(arg3);
-  if (!fp) goto fail;
-
-  float *val;
-  val = (float *)PYARRAY_DATA(arr2);
-  npy_intp * dims;
-  dims = PYARRAY_DIMS(arg2);
-  int nr,nc;
-  nr = dims[0];
-  nc = dims[1];
-
-  int *ind;
-  ind = (int *)PYARRAY_DATA(arr1);
-  dims = PYARRAY_DIMS(arg1);
-  if (dims[0] != nr) goto fail;
-
-  int i,j;
-  for (i=0; i<nr; i++) {
-    fprintf(fp,"%i ",*(ind++));
-    for (j=0; j<nc; j++) {
-      fprintf(fp,fmt,*(val++));
-    }
-    fprintf(fp,"\n");
-  }
-
-  /* Clean up and return */
-  Py_DECREF(arr1);
-  Py_DECREF(arr2);
-  Py_INCREF(Py_None);
-  return Py_None;
-
- fail:
-  Py_XDECREF(arr1);
-  Py_XDECREF(arr2);
-  return NULL;
-}
-
-/**************************************************** tofile_iint32 ****/
-/* Write an indexed array to file */
-/*
-   Use:  tofile_iint32(ind,data,file,format)
-   This is like tofile_int32, but each row from data is preceded with an
-   index number from ind.
-*/
-
-
-static PyObject * tofile_iint32(PyObject *dummy, PyObject *args)
-{
-  PyObject *arg1=NULL, *arg2=NULL, *arg3=NULL;
-  PyObject *arr1=NULL, *arr2=NULL;
-  FILE *fp;
-  char *fmt; /* single element format */
-
-  if (!PyArg_ParseTuple(args, "OOOs", &arg1, &arg2, &arg3, &fmt)) return NULL;
-  arr1 = PyArray_FROM_OTF(arg1, NPY_INT, NPY_ARRAY_IN_ARRAY);
-  if (arr1 == NULL) return NULL;
-  arr2 = PyArray_FROM_OTF(arg2, NPY_INT, NPY_ARRAY_IN_ARRAY);
-  if (arr2 == NULL) goto fail;
-  fp = PyFile_AsFile(arg3);
-  if (!fp) goto fail;
-
-  int *val;
-  val = (int *)PYARRAY_DATA(arr2);
-  npy_intp * dims;
-  dims = PYARRAY_DIMS(arg2);
-  int nr,nc;
-  nr = dims[0];
-  nc = dims[1];
-
-  int *ind;
-  ind = (int *)PYARRAY_DATA(arr1);
-  dims = PYARRAY_DIMS(arg1);
-  if (dims[0] != nr) goto fail;
-
-  int i,j;
-  for (i=0; i<nr; i++) {
-    fprintf(fp,"%i ",*(ind++));
-    for (j=0; j<nc; j++) {
-      fprintf(fp,fmt,*(val++));
-    }
-    fprintf(fp,"\n");
-  }
-
-  /* Clean up and return */
-  Py_DECREF(arr1);
-  Py_DECREF(arr2);
-  Py_INCREF(Py_None);
-  return Py_None;
-
- fail:
-  Py_XDECREF(arr1);
-  Py_XDECREF(arr2);
-  return NULL;
-}
-
-#endif
 
 /**************************************************** coords_fuse ****/
 /* Fuse nodes : new and much faster algorithm */
@@ -550,8 +339,6 @@ void average_direction_indexed(float *vec, int ndim, int*ind, int nvec, float to
 }
 
 
-
-
 static PyObject * averageDirection(PyObject *dummy, PyObject *args)
 {
   PyObject *arg1=NULL;
@@ -1466,60 +1253,39 @@ static PyObject * isosurface(PyObject *dummy, PyObject *args)
 /********************************************************/
 /* The methods defined in this module */
 static PyMethodDef extension_methods[] = {
-    {"_fuse", coords_fuse, METH_VARARGS, "Fuse nodes."},
-    {"nodalSum", nodalSum, METH_VARARGS, "Nodal sum."},
-    {"averageDirection", averageDirection, METH_VARARGS, "Average directions."},
-    {"averageDirectionIndexed", averageDirectionIndexed, METH_VARARGS, "Average directions."},
-    {"isoline", isoline, METH_VARARGS, isoline__doc__},
-    {"isosurface", isosurface, METH_VARARGS, isosurface__doc__},
-#if PY_MAJOR_VERSION < 3
-    {"tofile_float32", tofile_float32, METH_VARARGS, "Write float32 array to file."},
-    {"tofile_int32", tofile_int32, METH_VARARGS, "Write int32 array to file."},
-    {"tofile_ifloat32", tofile_ifloat32, METH_VARARGS, "Write indexed float32 array to file."},
-    {"tofile_iint32", tofile_iint32, METH_VARARGS, "Write indexed int32 array to file."},
-#endif
-    {NULL, NULL, 0, NULL}        /* Sentinel */
+  {"_fuse", coords_fuse, METH_VARARGS, "Fuse nodes."},
+  {"nodalSum", nodalSum, METH_VARARGS, "Nodal sum."},
+  {"averageDirection", averageDirection, METH_VARARGS, "Average directions."},
+  {"averageDirectionIndexed", averageDirectionIndexed, METH_VARARGS, "Average directions."},
+  {"isoline", isoline, METH_VARARGS, isoline__doc__},
+  {"isosurface", isosurface, METH_VARARGS, isosurface__doc__},
+  {NULL, NULL, 0, NULL}        /* Sentinel */
 };
 
 /* Initialize the module */
-#if PY_MAJOR_VERSION >= 3
-
 static struct PyModuleDef moduledef = {
-        PyModuleDef_HEAD_INIT,
-        "misc_",   // module name
-        NULL,      // module doc
-        -1,        //sizeof(struct module_state),
-        extension_methods,
-        NULL,
-        NULL, //myextension_traverse,
-        NULL, //myextension_clear,
-        NULL
+  PyModuleDef_HEAD_INIT,
+  "misc_",   // module name
+  NULL,      // module doc
+  -1,        //sizeof(struct module_state),
+  extension_methods,
+  NULL,
+  NULL, //myextension_traverse,
+  NULL, //myextension_clear,
+  NULL
 };
 
-
-#define INITERROR return NULL
-PyMODINIT_FUNC PyInit_misc_(void)
-#else
-#define INITERROR return
-void initmisc_(void)
-#endif
+PyObject *PyInit_misc_(void)
 {
   PyObject* m;
-#if PY_MAJOR_VERSION >= 3
   m = PyModule_Create(&moduledef);
-#else
-  m = Py_InitModule3("misc_", extension_methods, NULL);
-#endif
   if (m == NULL)
-    INITERROR;
+    return NULL;
   PyModule_AddStringConstant(m,"__version__",__version__);
   PyModule_AddStringConstant(m,"__doc__",__doc__);
   PyModule_AddIntConstant(m,"accelerated",1);
   import_array(); /* Get access to numpy array API */
-
-#if PY_MAJOR_VERSION >= 3
   return m;
-#endif
 }
 
 /* End */
