@@ -1,11 +1,11 @@
 /* */
 //
-//  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+//  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 //  pyFormex is a tool for generating, manipulating and transforming 3D
 //  geometrical models by sequences of mathematical operations.
 //  Home page: http://pyformex.org
 //  Project page:  http://savannah.nongnu.org/projects/pyformex/
-//  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+//  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 //  Distributed under the GNU General Public License version 3 or later.
 //
 //  This program is free software: you can redistribute it and/or modify
@@ -26,7 +26,6 @@
 // This module is partly inspired by the Nurbs toolbox Python port by
 // Runar Tenfjord (http://www.aria.uklinux.net/nurbs.php3)
 //
-
 #include "Python.h"
 #define NPY_NO_DEPRECATED_API NPY_1_7_API_VERSION
 #include "numpy/arrayobject.h"
@@ -39,7 +38,7 @@
 
 /****************** LIBRARY VERSION AND DOCSTRING *******************/
 
-static char *__version__ = "1.0.7";
+static char *__version__ = "2.0";
 static char *__doc__ = "pyformex.lib.nurbs_ module\n\
 \n\
 This module provides accelerated versions of the pyFormex NURBS\n\
@@ -2600,62 +2599,47 @@ static PyObject * surfaceDerivs(PyObject *self, PyObject *args)
 
 static PyMethodDef extension_methods[] =
 {
-	{"binomial", binomial, METH_VARARGS, binomial_doc},
-	{"horner", horner, METH_VARARGS, horner_doc},
-	{"bernstein", bernstein, METH_VARARGS, bernstein_doc},
-	{"allBernstein", allBernstein, METH_VARARGS, allBernstein_doc},
-	{"curvePoints", curvePoints, METH_VARARGS, curvePoints_doc},
-	{"curveDerivs", curveDerivs, METH_VARARGS, curveDerivs_doc},
-	{"curveKnotRefine", curveKnotRefine, METH_VARARGS, curveKnotRefine_doc},
-	{"curveDecompose", curveDecompose, METH_VARARGS, curveDecompose_doc},
-	{"curveKnotRemove", curveKnotRemove, METH_VARARGS, curveKnotRemove_doc},
-	{"curveDegreeElevate", curveDegreeElevate, METH_VARARGS, curveDegreeElevate_doc},
-	{"curveDegreeReduce", curveDegreeReduce, METH_VARARGS, curveDegreeReduce_doc},
-	{"curveGlobalInterpolationMatrix", curveGlobalInterpolationMatrix, METH_VARARGS, curveGlobalInterpolationMatrix_doc},
-	{"surfacePoints", surfacePoints, METH_VARARGS, surfacePoints_doc},
-	{"surfaceDerivs", surfaceDerivs, METH_VARARGS, surfaceDerivs_doc},
-	{NULL, NULL, 0, NULL}        /* Sentinel */
+  {"binomial", binomial, METH_VARARGS, binomial_doc},
+  {"horner", horner, METH_VARARGS, horner_doc},
+  {"bernstein", bernstein, METH_VARARGS, bernstein_doc},
+  {"allBernstein", allBernstein, METH_VARARGS, allBernstein_doc},
+  {"curvePoints", curvePoints, METH_VARARGS, curvePoints_doc},
+  {"curveDerivs", curveDerivs, METH_VARARGS, curveDerivs_doc},
+  {"curveKnotRefine", curveKnotRefine, METH_VARARGS, curveKnotRefine_doc},
+  {"curveDecompose", curveDecompose, METH_VARARGS, curveDecompose_doc},
+  {"curveKnotRemove", curveKnotRemove, METH_VARARGS, curveKnotRemove_doc},
+  {"curveDegreeElevate", curveDegreeElevate, METH_VARARGS, curveDegreeElevate_doc},
+  {"curveDegreeReduce", curveDegreeReduce, METH_VARARGS, curveDegreeReduce_doc},
+  {"curveGlobalInterpolationMatrix", curveGlobalInterpolationMatrix, METH_VARARGS, curveGlobalInterpolationMatrix_doc},
+  {"surfacePoints", surfacePoints, METH_VARARGS, surfacePoints_doc},
+  {"surfaceDerivs", surfaceDerivs, METH_VARARGS, surfaceDerivs_doc},
+  {NULL, NULL, 0, NULL}        /* Sentinel */
 };
 
 /* Initialize the module */
-#if PY_MAJOR_VERSION >= 3
-
 static struct PyModuleDef moduledef = {
-        PyModuleDef_HEAD_INIT,
-        "misc_",   // module name
-        NULL,      // module doc
-        -1,        //sizeof(struct module_state),
-        extension_methods,
-        NULL,
-        NULL, //myextension_traverse,
-        NULL, //myextension_clear,
-        NULL
+  PyModuleDef_HEAD_INIT,
+  "nurbs_",   // module name
+  NULL,      // module doc
+  -1,        //sizeof(struct module_state),
+  extension_methods,
+  NULL,
+  NULL, //myextension_traverse,
+  NULL, //myextension_clear,
+  NULL
 };
 
-
-#define INITERROR return NULL
-PyMODINIT_FUNC PyInit_nurbs_(void)
-#else
-#define INITERROR return
-void initnurbs_(void)
-#endif
+PyObject *PyInit_nurbs_(void)
 {
   PyObject* m;
-#if PY_MAJOR_VERSION >= 3
   m = PyModule_Create(&moduledef);
-#else
-  m = Py_InitModule3("nurbs_", extension_methods, NULL);
-#endif
   if (m == NULL)
-    INITERROR;
+    return NULL;
   PyModule_AddStringConstant(m,"__version__",__version__);
   PyModule_AddStringConstant(m,"__doc__",__doc__);
   PyModule_AddIntConstant(m,"accelerated",1);
   import_array(); /* Get access to numpy array API */
-
-#if PY_MAJOR_VERSION >= 3
   return m;
-#endif
 }
 
 /* End */
