@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -25,7 +25,8 @@
 """Error and Warning Messages
 
 """
-from __future__ import absolute_import, division, print_function
+
+# flake8: noqa
 
 import pyformex as pf
 
@@ -51,26 +52,28 @@ def getMessage(msg):
     return msg
 
 
-print_function = """..
+system_command = """..
 
-print is now a function
------------------------
-This version of pyFormex enforces scripts to use the print function rather than
-the print statement. This means that you should not use::
+utils.system and utils.command have changed!
+--------------------------------------------
+The functions for executing external commands (utils.system and
+utils.command) have changed:
 
-  print something
+- the `raise_error` argument has been renamed to `check`.
+- in case of `wait=True` (which is the default), the following attributes
+  of the return value P have been renamed:
 
-but rather::
-
-  print(something)
-
-You can convert your scripts automatically with the command::
-
-  2to3 -f print -wn SCRIPTFILE
+  - P.out: becomes P.stdout
+  - P.err: becomes P.stderr
+  - P.sta: becomes P.returncode
 
+The old names are still available, but using them will cause this warning.
+They will be removed in future though, so users are urged to change them
+asap.
 """
 
-warn_addAxis_changed = "arraytools.addAxis has changed for negative values of the axis parameter. It now specifies the position of the new axis in the expanded array. This means that for negative values you should now specify a value that is one less than it was in the old behavior. Thus: -1 now means a new axis at the end."
+warn_Connectivity_inverse = "The default behavior of Connectivity.inverse has changed. It now returns a Varray by default. To get the old return value (a -1 padded array), you can either add the 'expand=True' parameter or (preferably) explicitely convert the returned Varray:  conn.inverse().toArray()."
+
 warn_clip_changed = "The clip and cclip methods have changed. If the selector contains negative numbers, these will be selected as in the (c)select methods."
 warn_coords_match_changed = "The Coords.match function has changed. The argument 'clean' has been removed. The behavior with clean=True can be obtained with the hasMatch method"
 warn_curve_approx = "Curve.approx has been changed. It is now an alias for Curve.approximate. To get the same results as with the old ndiv parameter, you can still specify ndiv as a keyword parameter. The old parameter ntot should be replaced with nseg."
@@ -125,7 +128,6 @@ warn_project_compression = "The contents of the file does not appear to be compr
 warn_project_create = "The create=True argument should be replaced with access='w'"
 warn_project_legacy = "The legacy=True argument has become superfluous"
 warn_properties_setname = "!! 'setname' is deprecated, please use 'name'"
-warn_pyside2 = "THIS IS AN EXPERIMENTAL PySide2 VERSION!\nSOME THINGS MAY NOT WORK PROPERLY!"
 
 warn_regular_grid = "The function simple.regularGrid has changed!. The points are now ordered first along the 0-axis, then along the 1-axis, etc... This is to be consistent with other grid numbering schemes in pyFormex. The old numbering scheme (first along the highest axis) can be obtained by passing the 'swapaxes=True' argument to the function."
 warn_select_changed = "The select and cselect methods have changed for Mesh type opbjects. The default is now compact=False, as suggested in https://savannah.nongnu.org/bugs/?40662#comment7. If you want to get the result compacted, use clip/cclip instead, or add '.compact()'"
@@ -150,7 +152,6 @@ error_widgets_enableitem = "Error in a dialog item enabler. This should not happ
 error_no_gts_bin = "I am missing the gts binary programs on your system.\nTherefore, some surface operations will not be available or fail.\n\nOn Debian, you can install the missing programs with `apt-get install libgts-bin`.\n"
 error_no_gts_extra = "I am missing the gts binary programs on your system.\nTherefore, some surface operations will not be available or fail.\n\nOn Debian, you can install the missing programs with `apt-get install pyformex-extra`.\n"
 
-depr_adjacencyArrays = "adjacencyArrays is deprecated. Use Adjacency.frontWalk() instead."
 depr_mesh_getlowerentities_unique = "The use of the unique argument in getLowerEntities is deprecated. Use \n sel = self.elType().getEntities(level) \n lower = self.elems.insertLevel(sel)[1] "
 depr_pathextension = "patchextension is deprecated. Use border().extrude() instead."
 
@@ -161,7 +162,7 @@ depr_abqdata_outres = "The use of the `res` and `out` arguments in AbqData is de
 depr_avgNodalScalarOnAdjacentNodes = "avgNodalScalarOnAdjacentNodes is deprecated. It may be removed in future, unless someone can prove its virtue, generalize, cleanup and document the code and provide an example. See the source code for more comments."
 depr_connectionSteps1 = "connectionSteps is deprecated and has been removed. Use frontWalk instead. See the FrontWalk example: walk 3 gives an equivalent result, though you might prefer the simpler solution of walk 2."
 depr_anyVector = "arraytools.anyVector is deprecated. Use checkArray([1,2,3],shape=(3,),kind='f',allow='i') instead."
-
+depr_connectedLineElems = "connectivity.connectedLineElems is deprecated. You should use Connectivity.chained or Connectivity.chain instead. Please read the docstring: the arguments and return values are different!"
 warn_trfMatrix_deprecated = "trfMatrix is deprecated. Use trfmat instead."
 warn_vectorRotation_deprecated = "vectorRotation is deprecated. Use rotMatrix2 instead."
 warn_rotationAnglesFromMatrix_deprecated = "rotationAnglesFromMatrix is deprecated. Use cardanAngles instead."
