@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -38,12 +38,11 @@ while still preserving the intended functionality.
 (C) 2005,2008,2019 Benedict Verhegghe
 Distributed under the GNU GPL version 3 or later
 """
-from __future__ import absolute_import, division, print_function
 
 from collections import defaultdict
 try:
     from collections.abc import Mapping
-except:
+except Exception:
     from collections import Mapping
 
 
@@ -228,7 +227,7 @@ class Dict(defaultdict):
         We use the format Dict({}), so that the string is a valid Python
         representation of the Dict.
         """
-        return "Dict(%s)" % dict.__repr__(self)
+        return f"{self.__class__.__name__}({dict.__repr__(self)})"
 
     def __str__(self):
         """Nicely format the Dict as a string.
@@ -256,7 +255,7 @@ class Dict(defaultdict):
         except AttributeError as e:
             try:
                 return self.__getitem__(key)
-            except:
+            except Exception:
                 raise e
 
     def __setattr__(self, key, value=None):
@@ -363,7 +362,7 @@ class CDict(Dict):
                     res = self[k][key]
                     if res:
                         return res
-                except:
+                except Exception:
                     continue
             elif isinstance(self[k], Mapping):
                 # Any other mapping: accept if it has the key itself
