@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -32,7 +32,6 @@ the current OpenGL framework in pyFormex.
 (C) 2013 Benedict Verhegghe and the pyFormex project.
 
 """
-from __future__ import absolute_import, division, print_function
 
 import numpy as np
 import OpenGL.GL as GL
@@ -791,7 +790,7 @@ class Camera(object):
 
         try:
             self.projection_callback(self)
-        except:
+        except Exception:
             pass
         self.lensChanged = False
 
@@ -955,7 +954,7 @@ class Camera(object):
 
         try:
             self.modelview_callback(self)
-        except:
+        except Exception:
             pass
         self.viewChanged = False
 
@@ -1154,7 +1153,7 @@ class Camera(object):
         config = Config()
         try:
             config.read(filename)
-        except:
+        except Exception:
             raise ValueError("Invalid Camera save file: %s" % filename)
         self.loadConfig(config)
 
