@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -24,7 +24,6 @@
 """This implements an OpenGL drawing widget for painting 3D scenes.
 
 """
-from __future__ import absolute_import, division, print_function
 
 import numpy as np
 
@@ -32,9 +31,9 @@ from OpenGL import GL, GLU
 
 import pyformex as pf
 
-from pyformex import utils, coords
+from pyformex import utils
 from pyformex import arraytools as at
-
+from pyformex.coords import Coords, bbox
 from pyformex.mydict import Dict
 from collections import OrderedDict
 from pyformex.collection import Collection
@@ -489,7 +488,7 @@ class CanvasSettings(Dict):
                 else:
                     raise
                 ok[k] = v
-            except:
+            except Exception:
                 if strict:
                     raise ValueError("Invalid key/value for CanvasSettings: %s = %s" % (k, v))
         return ok
@@ -557,7 +556,7 @@ def print_lighting(s):
     try:
         settings = pf.GUI.viewports.current.settings
         print("%s: LIGTHING %s (%s)" %(s, settings.lighting, id(settings)))
-    except:
+    except Exception:
         print("No settings yet")
 
 
@@ -629,7 +628,6 @@ class Canvas(object):
 
     def sceneBbox(self):
         """Return the bbox of all actors in the scene"""
-        from pyformex.coords import bbox
         return bbox(self.scene.actors)
 
 
@@ -759,7 +757,7 @@ class Canvas(object):
         try:
             func = getattr(self, 'do_'+attr)
             func(state, oldstate)
-        except:
+        except Exception:
             pass
 
 
@@ -852,7 +850,7 @@ class Canvas(object):
             from pyformex.plugins.imagearray import qimage2numpy
             try:
                 image = qimage2numpy(self.settings.bgimage, indexed=False)
-            except:
+            except Exception:
                 pass
         actor = Actor(F, name='background', rendermode='smooth',
                       color=[self.settings.bgcolor], texture=image,
@@ -1284,7 +1282,7 @@ class Canvas(object):
                     axes = axes + ((1., 0., 0.),)
                     #print("canvas4: %s (%s)" % (angles, axes))
                 self.camera.setAngles(angles, axes)
-            except:
+            except Exception:
                 raise ValueError("Invalid view angles specified: %s %s" % (angles, orient))
 
         # set camera distance and clipping planes
@@ -1297,12 +1295,12 @@ class Canvas(object):
             self.camera.setLens(fovy, self.aspect)
             # Default correction is sqrt(3)
             correction = float(pf.cfg['gui/autozoomfactor'])
-            tf = coords.tand(fovy/2.)
+            tf = at.tand(fovy/2.)
 
             from pyformex import simple
             bbix = simple.regularGrid(X0, X1, [1, 1, 1], swapaxes=True)
             bbix = np.dot(bbix, self.camera.rot[:3, :3])
-            bbox = coords.Coords(bbix).bbox()
+            bbox = Coords(bbix).bbox()
             dx, dy, dz = bbox[1] - bbox[0]
             vsize = max(dx/self.aspect, dy)
             dsize = bbox.dsize()
@@ -1324,10 +1322,10 @@ class Canvas(object):
             # print "near,far = %s, %s" % (near,far)
             #print (0.0001*vsize,0.01*dist,near)
             # make sure near is positive
-            near = max(near, 0.0001*vsize, 0.01*dist, np.finfo(coords.Float).tiny)
+            near = max(near, 0.0001*vsize, 0.01*dist, np.finfo(at.Float).tiny)
             # make sure far > near
             if far <= near:
-                far += np.finfo(coords.Float).eps
+                far += np.finfo(at.Float).eps
             #print "near,far = %s, %s" % (near,far)
             self.camera.setClip(near, far)
             self.camera.resetArea()
