@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -26,7 +26,6 @@
 This module contains a collection of predefined decorations that
 can be useful additions to a geometry scene rendering.
 """
-from __future__ import absolute_import, division, print_function
 
 import pyformex as pf
 from pyformex import simple
@@ -42,10 +41,25 @@ import numpy as np
 
 
 class BboxActor(Actor):
-    """Draws a bounding bbox.
+    """Create a bounding box actor.
 
     A bounding box is a hexaeder in global axes. The hexaeder is
     drawn in wireframe mode with default color black.
+
+    Parameters
+    ----------
+    bbox: :term:`coords_like`
+        A Coords with two points: the minimal and maximal coordinates
+        of the bounding box to be drawn.
+    **kargs: keyword parameters
+        Keyword parameters like in the :func:`draw` funnction.
+        The `mode`, `lighting`, `opak` parameters are fixed and can not be
+        used.
+
+    Returns
+    -------
+    :class:`Actor`
+        An Actor representing a bounding box.
     """
     def __init__(self, bbox, **kargs):
         F = simple.cuboid(*bbox)
@@ -200,7 +214,7 @@ class ColorLegend(Actor):
 
             if font is None:
                 font = FontTexture.default()
-            elif isinstance(font, (str, unicode)):
+            elif isinstance(font, str):
                 font = FontTexture(font, size)
             self.font = font
             fh = self.font.height
