@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -24,7 +24,6 @@
 """OpenGL rendering objects for the new OpenGL2 engine.
 
 """
-from __future__ import absolute_import, division, print_function
 
 import numpy as np
 from numpy import int32, float32
@@ -451,9 +450,9 @@ class Drawable(Attributes):
 
     def __str__(self):
         keys = sorted(set(self.keys()) - set(('_default_dict_',)))
-        print("Keys %s" % keys)
+        #print("Keys %s" % keys)
         out = utils.formatDict(utils.selectDict(self, keys))
-        print(out)
+        #print(out)
         return out
 
 ########################################################################
@@ -540,7 +539,7 @@ class BaseActor(Attributes):
             if not isinstance(texture, Texture):
                 try:
                     texture = Texture(texture)
-                except:
+                except Exception:
                     texture = None
         self.texture = texture
 
@@ -668,7 +667,7 @@ class Actor(BaseActor):
     def bbox(self):
         try:
             return self.object.bbox()
-        except:
+        except Exception:
             print("No bbox because no _coords for object of type %s" % type(self.object))
             return np.zeros(6).reshape(2, 3)
 
@@ -922,12 +921,12 @@ class Actor(BaseActor):
         if wiremode > 0 and self.edges is not None:
             if wiremode == 1:
                 # all edges:
-                print("ADDWIRES %s" % self.edges)
-                print(self.edges.shape)
+                #print("ADDWIRES %s" % self.edges)
+                #print(self.edges.shape)
                 elems = self.subElems(nsel=self.edges)
             elif wiremode == 2:
                 # border edges
-                print("SELF.ELEMS",self.elems)
+                #print("SELF.ELEMS",self.elems)
                 inv = at.inverseIndex(self.elems.reshape(-1, 1))[:, -1]
                 #print("INVERSE",inv)
                 M = Mesh(self.coords, self.elems)
@@ -1049,12 +1048,12 @@ class Actor(BaseActor):
         """Set the Actors alpha value."""
         try:
             self.alpha = self.bkalpha = float(alpha)
-        except:
+        except Exception:
             del self.alpha
             del self.bkalpha
         try:
             self.bkalpha = float(bkalpha)
-        except:
+        except Exception:
             pass
         if self.opak is None:
             self.opak = (self.alpha == 1.0) and (self.bkalpha == 1.0)
@@ -1067,7 +1066,7 @@ class Actor(BaseActor):
             if not isinstance(texture, Texture):
                 try:
                     texture = Texture(texture)
-                except:
+                except Exception:
                     print("Error while creating Texture from %s" % type(texture))
                     raise
                     texture = None
