@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -31,19 +31,21 @@ the current OpenGL framework in pyFormex.
 (C) 2013 Benedict Verhegghe and the pyFormex project.
 
 """
-from __future__ import absolute_import, division, print_function
 
 import numpy as np
 import pyformex.arraytools as at
 
 
+#TODO: Remove the dependence on np.matrix, which is deprecated
+
+
 class Vector4(np.matrix):
     """One or more homogeneous coordinates
 
     """
     def __new__(clas, data=None):
         """Create a new Vector4 instance"""
-        data = np.asarray(data)
+        data = np.asanyarray(data)
         if data.ndim < 1 or data.ndim > 2:
             raise ValueError("Expected 1 or 2-dimensinal data")
         if data.shape[-1] == 4:
@@ -212,10 +214,10 @@ class Matrix4(np.matrix):
 
         try:
             rot = at.checkArray(angle, (4, 4), 'f')[:3, :3]
-        except:
+        except Exception:
             try:
                 rot = at.checkArray(angle, (3, 3), 'f')
-            except:
+            except Exception:
                 angle = at.checkFloat(angle)
                 rot = np.matrix(at.rotationMatrix(angle, axis))
         self.rot = rot*self.rot
@@ -285,7 +287,7 @@ class Matrix4(np.matrix):
         try:
             x = at.checkArray(x, (3,), 'f')
             return np.dot(x, self[:3, :3]) + self[3, :3]
-        except:
+        except Exception:
             x = at.checkArray(x, (4,), 'f')
             return np.dot(x, self)
 
