@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -32,7 +32,6 @@ strict attributes required by the OpenGl rendering engine.
 These functions are generally not intended for direct used by the user, but
 for use in the opengl rendering functions.
 """
-from __future__ import absolute_import, division, print_function
 
 import pyformex as pf
 from pyformex.opengl.colors import GLcolor
@@ -50,7 +49,7 @@ def saneFloat(value):
     """
     try:
         value = float(value)
-    except:
+    except Exception:
         value = None
     return value
 
@@ -67,7 +66,7 @@ def saneLineStipple(stipple):
     """
     try:
         stipple = [int(i) for i in stipple]
-    except:
+    except Exception:
         stipple = None
     return stipple
 
@@ -116,7 +115,7 @@ def saneColor(color=None):
         if c.dtype.kind == 'i':
             # We have a color index
             return c
-    except:
+    except Exception:
         pass
 
     # not a color index: it must be colors
@@ -136,7 +135,7 @@ def saneColor(color=None):
         if color.dtype.kind == 'f' and color.shape[-1] == 3 or color.shape[-1] == 4:
             # Looks like we have a sane color array
             return color.astype(np.float32)
-    except:
+    except Exception:
         pass
 
     return None
