@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -24,7 +24,8 @@
 """This implements an OpenGL drawing widget for painting 3D scenes.
 
 """
-from __future__ import absolute_import, division, print_function
+
+import numpy as np
 
 from pyformex import arraytools as at
 from pyformex import coords
@@ -73,14 +74,14 @@ class ItemList(list):
 #            ##
 #            #
 #            try:
-#            except:
+#            except Exception:
 #                print("Could not remove object of type %s from list" % type(a))
 #                ids = [id(i) for i in self]
 #                try:
 #                    ind = ids.index(id(a))
 #                    print("However, the object is in the list: removing it by id")
 #                    del self[ind]
-#                except:
+#                except Exception:
 #                    print("The object is not in the list: skipping")
 
 
@@ -230,8 +231,8 @@ class Scene(object):
 
         Returns a list with the actors that point to the specifief object.
         """
-        print(id(obj))
-        print([id(a.object) for a in self.actors])
+        #print(id(obj))
+        #print([id(a.object) for a in self.actors])
         return [a for a in self.actors if a.object is obj]
 
 
@@ -299,9 +300,10 @@ def sane_bbox(bb):
     bb = at.checkArray(bb, (2, 3), 'f')
     # make sure we have no NaNs in the bbox
     try:
-        bb = at.nan_to_num(bb)
-    except:
+        bb = np.nan_to_num(bb)
+    except Exception as e:
         print("Invalid Bbox: %s" % bb)
+        raise e
     # make sure bbox size is nonzero in all directions
     sz = bb[1]-bb[0]
     ds = 0.01 * at.length(sz)
