@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -25,7 +25,6 @@
 
 This module defines tools for texture rendering in pyFormex.
 """
-from __future__ import absolute_import, division, print_function
 
 from OpenGL import GL
 import numpy as np
@@ -55,7 +54,7 @@ class Texture(object):
 
     def __init__(self, image, mode=1, format=GL.GL_RGBA, texformat=GL.GL_RGBA):
         self.texid = None
-        if isinstance(image, (str, unicode)):
+        if isinstance(image, str):
             from pyformex.plugins.imagearray import image2array
             image = image2array(image, 'RGBA')
         else:
