@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -60,14 +60,18 @@ path and file related functionally into this module and extend the Path
 class with any interesting functionality that has common use.
 
 In order for this module to be of general use however, we have kept
-things that are strictly pyFormex oriented out of this module
+things that are strictly pyFormex oriented out of this module.
+
+This version is for Python3 only. See pyFormex 1.0.7 for a version that
+supports both Python2.7 and Python3.x.
 
 """
-from __future__ import absolute_import, division, print_function
 
-import os, sys, shutil, tempfile, re
+import os
+import shutil
+import tempfile
+import re
 
-PY2 = sys.hexversion < 0x03000000
 
 class Path(str):
     """
@@ -217,7 +221,6 @@ class Path(str):
             return args[0]
         return str.__new__(self, os.path.normpath(os.path.join(*args)))
 
-
     def __truediv__(self, component):
         """
         Defines / operator for joining path components
@@ -226,25 +229,18 @@ class Path(str):
 
     # We do not define __rtruediv__: use Path('...') / instead
 
-    if PY2:
-        # Just in case one runs a script without importing new style division
-        __div__ = __truediv__
-
-
     def __add__(self, suffix):
         """
         Defines + operator for joining path suffixes
         """
         return Path(str(self)+suffix)
 
-
     def __repr__(self):
         """
         String representation of a path
         """
         return ''.join(["Path('", self, "')"])
 
-
     @property
     def parts(self):
         """
@@ -282,7 +278,6 @@ class Path(str):
             p = head
         return tuple(parts)
 
-
     @property
     def parents(self):
         """
@@ -298,7 +293,6 @@ class Path(str):
             parents.append(parents[-1].parent)
         return tuple(parents)
 
-
     @property
     def parent(self):
         """
@@ -311,7 +305,6 @@ class Path(str):
         """
         return Path(os.path.dirname(self))
 
-
     @property
     def name(self):
         """Return the final path component.
@@ -323,7 +316,6 @@ class Path(str):
         """
         return os.path.basename(self)
 
-
     @property
     def stem(self):
         """
@@ -344,7 +336,6 @@ class Path(str):
             stem += ext
         return stem
 
-
     @property
     def suffix(self):
         """
@@ -369,7 +360,6 @@ class Path(str):
             ext = ''
         return ext
 
-
     @property
     def lsuffix(self):
         """
@@ -387,7 +377,6 @@ class Path(str):
         """
         return self.suffix.lower()
 
-
     @property
     def ftype(self):
         """
@@ -405,6 +394,37 @@ class Path(str):
         """
         return self.suffix.lower().lstrip('.')
 
+    @property
+    def without_suffix(self):
+        """
+        Return the Path without the suffix.
+
+        The file suffix is the last substring of the final component
+        starting at a dot that is neither the start nor the end
+        of the component.
+
+        Returns
+        -------
+        Path
+            The Path without the suffix.
+
+        Notes
+        -----
+        This is equivalent to::
+
+            self.parent / self.stem
+
+        If the path has no suffix, the output is identical to the input.
+
+        Examples
+        --------
+        >>> f = Path('/dD/aA.bB')
+        >>> f.without_suffix
+        Path('/dD/aA')
+        >>> f.parent / f.stem
+        Path('/dD/aA')
+        """
+        return Path(os.path.splitext(self)[0])
 
     def exists(self):
         """
@@ -412,28 +432,24 @@ class Path(str):
         """
         return os.path.exists(self)
 
-
     def is_dir(self):
         """
         Return True if the Path exists and is a directory
         """
         return os.path.isdir(self)
 
-
     def is_file(self):
         """
         Return True if the Path exists and is a file
         """
         return os.path.isfile(self)
 
-
     def is_symlink(self):
         """
         Return True if the Path exists and is a symlink
         """
         return os.path.islink(self)
 
-
     def is_badlink(self):
         """
         Return True if the Path exists and is a bad symlink
@@ -442,7 +458,6 @@ class Path(str):
         """
         return os.path.islink(self) and not os.path.exists(self.real())
 
-
     def is_absolute(self):
         """
         Return True if the Path is absolute.
@@ -456,7 +471,6 @@ class Path(str):
         """
         return os.path.isabs(self)
 
-
     def with_name(self, name):
         """
         Return a new Path with the filename changed.
@@ -476,8 +490,7 @@ class Path(str):
         >>> Path('data/testrun.inp').with_name('testimg.png')
         Path('data/testimg.png')
         """
-        return self.parent / name
-
+        return self.parent / name    # noqa
 
     def with_suffix(self, suffix):
         """
@@ -486,8 +499,9 @@ class Path(str):
         Parameters
         ----------
         suffix: str
-            Suffix to replace the last component's suffix. The replacement
-            string does not need to start with a dot. See Examples.
+            Suffix to replace the last component's :meth:`suffix`.
+            The replacement string will normally start with a dot.
+            If it doesn't, not dot is added. See Examples.
 
         Returns
         -------
@@ -499,12 +513,11 @@ class Path(str):
         --------
         >>> Path('data/testrun.inp').with_suffix('.cfg')
         Path('data/testrun.cfg')
-        >>> Path('data/testrun.inp').with_suffix('_bis.inp')
-        Path('data/testrun_bis.inp')
+        >>> Path('data/testrun.inp').with_suffix('_1.inp')
+        Path('data/testrun_1.inp')
         """
         return Path(os.path.splitext(self)[0] + suffix)
 
-
     def absolute(self):
         """
         Return an absolute version of the path.
@@ -528,7 +541,6 @@ class Path(str):
         """
         return Path(os.path.abspath(self))
 
-
     def resolve(self):
         """Return absolute path resolving all symlinks.
 
@@ -547,14 +559,18 @@ class Path(str):
         """
         return Path(os.path.realpath(self))
 
-
     def expanduser(self):
         """Expand the ~ and ~user in Path.
 
+        A leading '~' in the Path is expanded tot the home directory
+        of the user executing the code. A leading '~user' is expanded
+        to the home directory of the user named 'user'.
+
         Returns
         -------
         Path
-            The Path with ~ and ~user expanded.
+            The Path with ~ and ~user expanded, the latter only if user
+            exists.
 
         Examples
         --------
@@ -565,7 +581,6 @@ class Path(str):
         """
         return Path(os.path.expanduser(self))
 
-
     def as_uri(self):
         """
         Return the Path as an URI.
@@ -574,16 +589,16 @@ class Path(str):
         -------
         str
             A string starting with 'file://' followed by the resolved
-            absolute path of the Path. Also ~ and ~user are expanded.
+            absolute path of the Path. Also ~ and ~user are expanded
+            (if user exists).
 
         Examples
         --------
-        >>> Path('~user/some/file.html').as_uri()
-        'file:///home/user/some/file.html'
+        >>> Path('~/some/file.html').as_uri() # doctest: +ELLIPSIS
+        'file:///home/.../some/file.html'
         """
         return 'file://' + self.expanduser().resolve()
 
-
     def samefile(self, other_file):
         """
         Test whether two pathnames reference the same actual file
@@ -605,7 +620,6 @@ class Path(str):
         """
         return os.path.samefile(self, other_file)
 
-
     def commonprefix(self, *other):
         """
         Return the longest common leading part in a list of paths.
@@ -633,40 +647,27 @@ class Path(str):
         """
         return Path(os.path.commonprefix([self]+list(other)))
 
+    def commonpath(self, *other):
+        """
+        Return the longest common sub-path in a list of paths.
 
-    if PY2:
-        def commonpath(self, other, *args):
-            common = self.commonprefix(self, other, *args)
-            cparts = common.parts
-            sparts = self.parts
-            last = len(cparts) - 1
-            if cparts[last] == sparts[last]:
-                return Path(*cparts)
-            else:
-                return Path(*cparts[:-1])
-    else:
-        def commonpath(self, *other):
-            """
-            Return the longest common sub-path in a list of paths.
+        Parameters
+        ----------
+        *other: one or more :term:`path_like`
+            Other file path(s) to compare with.
 
-            Parameters
-            ----------
-            *other: one or more :term:`path_like`
-                Other file path(s) to compare with.
-
-            Returns
-            -------
-            Path
-                The longest common sub-path in all the file paths.
-
-            Examples
-            --------
-            >>> p = Path('/etc/password')
-            >>> p.commonpath(p,'/etc/pam.d')
-            Path('/etc')
-            """
-            return Path(os.path.commonpath([self]+list(other)))
+        Returns
+        -------
+        Path
+            The longest common sub-path in all the file paths.
 
+        Examples
+        --------
+        >>> p = Path('/etc/password')
+        >>> p.commonpath(p,'/etc/pam.d')
+        Path('/etc')
+        """
+        return Path(os.path.commonpath([self]+list(other)))
 
     def joinpath(self, *other):
         """
@@ -692,7 +693,6 @@ class Path(str):
         """
         return Path(os.path.join(self, *other))
 
-
     def relative_to(self, other):
         """
         Return a relative path version of a path.
@@ -723,7 +723,6 @@ class Path(str):
         """
         return Path(os.path.relpath(self, start=other))
 
-
     def mkdir(self, mode=0o775, parents=False, exist_ok=False):
         """
         Create a directory.
@@ -752,28 +751,24 @@ class Path(str):
             else:
                 os.mkdir(self, mode)
 
-
     def rmdir(self):
         """
         Remove an empty directory.
         """
         os.rmdir(self)
 
-
     def unlink(self):
         """
         Remove an existing file.
         """
         os.unlink(self)
 
-
     def remove(self):
         """
         Remove a file, but silently ignores non-existing"""
         if self.exists():
             self.unlink()
 
-
     def removeTree(self, top=True):
         """
         Recursively delete a directory tree.
@@ -789,7 +784,6 @@ class Path(str):
         if not top:
             self.mkdir(exist_ok=True)
 
-
     def move(self, dst):
         """
         Rename or move a file or directory
@@ -813,7 +807,6 @@ class Path(str):
         os.replace(self, dst)
         return Path(dst)
 
-
     def copy(self, dst):
         """
         Copy the file under another name.
@@ -825,7 +818,6 @@ class Path(str):
         """
         return Path(shutil.copy(self, dst))
 
-
     def symlink(self, dst):
         """
         Create a symlink for this Path.
@@ -833,13 +825,12 @@ class Path(str):
         Parameters
         ----------
         dst: :term:`path_like`
-            Path of the symlink, which will point to self if succesfully
+            Path of the symlink, which will point to self if successfully
             created.
         """
         os.symlink(self, dst)
         return Path(dst)
 
-
     def touch(self):
         """
         Create an empty file or update an existing file's timestamp.
@@ -850,7 +841,6 @@ class Path(str):
         """
         self.open('a').close()
 
-
     def truncate(self):
         """
         Create an empty file or truncate an existing file.
@@ -860,7 +850,6 @@ class Path(str):
         """
         self.open('w').close()
 
-
     def chmod(self, mode):
         """
         Change the access permissions of a file.
@@ -876,7 +865,6 @@ class Path(str):
         """
         return os.chmod(self, mode)
 
-
     def stat(self):
         """
         Return the full stat info for the file.
@@ -894,21 +882,18 @@ class Path(str):
         """
         return os.stat(self)
 
-
     def mtime(self):
         """
         Return the (UNIX) time of last change
         """
         return self.stat().st_mtime
 
-
     def size(self):
         """
         Return the file size in bytes
         """
         return self.stat().st_size
 
-
     def owner(self):
         """
         Return the login name of the file owner.
@@ -916,7 +901,6 @@ class Path(str):
         import pwd
         return pwd.getpwuid(self.stat().st_uid).pw_name
 
-
     def group(self):
         """
         Return the group name of the file gid.
@@ -924,83 +908,51 @@ class Path(str):
         import grp
         return grp.getgrgid(self.stat().st_gid).gr_name
 
+    def open(self, mode='r', buffering=-1, encoding=None, errors=None):
+        """
+        Open the file pointed to by the Path.
 
-    if PY2:
+        Parameters are like in Python's built-in :func:`.open` function.
+        """
+        return open(self, mode=mode, buffering=buffering,
+                    encoding=encoding, errors=errors)
 
-        def open(self, mode='r', buffering=-1):
-            return open(self, mode, buffering)
+    def read_bytes(self):
+        """
+        Open the file in bytes mode, read it, and close the file.
+        """
+        with self.open(mode='rb') as f:
+            return f.read()
 
+    def write_bytes(self, data):
+        """
+        Open the file in bytes mode, write to it, and close the file.
+        """
+        with self.open('wb') as f:
+            return f.write(data)
 
-        def read_text(self):
-            with self.open('r') as f:
-                return f.read()
+    def read_text(self, encoding=None, errors=None):
+        """
+        Open the file in text mode, read it, and close the file.
+        """
+        with self.open(mode='r', encoding=encoding, errors=errors) as f:
+            return f.read()
 
+    def write_text(self, text, encoding=None, errors=None):
+        """
+        Open the file in text mode, write to it, and close the file.
 
-        read_bytes = read_text
-
-
-        def write_text(self, text):
-            with self.open('w') as f:
-                f.write(text)
-            return self.size()
-
-
-        write_bytes = write_text
-
-
-    else:
-
-
-        def open(self, mode='r', buffering=-1, encoding=None, errors=None):
-            """
-            Open the file pointed to by the Path.
-
-            Parameters are like in Python's built-in :func:`python.open` function.
-            """
-            return open(self, mode=mode, buffering=buffering,
-            encoding=encoding, errors=errors)
-
-
-        def read_bytes(self):
-            """
-            Open the file in bytes mode, read it, and close the file.
-            """
-            with self.open(mode='rb') as f:
-                return f.read()
-
-
-        def write_bytes(self, data):
-            """
-            Open the file in bytes mode, write to it, and close the file.
-            """
-            with self.open('wb') as f:
-                return f.write(data)
-
-
-        def read_text(self, encoding=None, errors=None):
-            """
-            Open the file in text mode, read it, and close the file.
-            """
-            with self.open(mode='r', encoding=encoding, errors=errors) as f:
-                return f.read()
-
-
-        def write_text(self, text, encoding=None, errors=None):
-            """
-            Open the file in text mode, write to it, and close the file.
-
-            Examples
-            --------
-            >>> p = Path('my_text_file')
-            >>> p.write_text('Text file contents')
-            18
-            >>> p.read_text()
-            'Text file contents'
-
-            """
-            with self.open('w', encoding=encoding, errors=errors) as f:
-                return f.write(text)
+        Examples
+        --------
+        >>> p = Path('my_text_file')
+        >>> p.write_text('Text file contents')
+        18
+        >>> p.read_text()
+        'Text file contents'
 
+        """
+        with self.open('w', encoding=encoding, errors=errors) as f:
+            return f.write(text)
 
     def walk(self):
         """
@@ -1011,64 +963,43 @@ class Path(str):
         """
         return os.walk(self)
 
+    def scandir(self):
+        """
+        Returns all entries in a directory
+        """
+        return os.scandir(self)
 
-    if PY2:
-        def scandir(self):
-            return next(os.walk(self))[1:]
+    def dirs(self):
+        """
+        List the subdirectories in a directory path.
 
-        def dir(self):
-            dirs, files = self.scandir()
-            return sorted(dirs+files)
+        Returns
+        -------
+        list of str
+            A list of the names of all directory type entries in the
+            Path. If the Path is not a directory or not accessible,
+            an exception is raised.
+        """
+        return sorted([i.name for i in os.scandir(self) if i.is_dir()])
 
-        def dirs(self):
-            return sorted(next(os.walk(self))[1])
+    def files(self):
+        """
+        List the files in a directory path.
 
-        def files(self):
-            return sorted(next(os.walk(self))[2])
-
-    else:
-
-        def scandir(self):
-            """
-            Returns all entries in a directory
-            """
-            return os.scandir(self)
-
-
-        def dirs(self):
-            """
-            List the subdirectories in a directory path.
-
-            Returns
-            -------
-            list of str
-                A list of the names of all directory type entries in the
-                Path. If the Path is not a directory or not accessible,
-                an exception is raised.
-            """
-            return sorted([i.name for i in os.scandir(self) if i.is_dir()])
-
-
-        def files(self):
-            """
-            List the files in a directory path.
-
-            Returns
-            -------
-            list of str
-                A list of the names of all file type entries in the
-                Path. If the Path is not a directory or not accessible,
-                an exception is raised.
-            """
-            return sorted([i.name for i in os.scandir(self) if i.is_file()])
-
-
-        def symlinks(self):
-            """
-            Returns all symlinks in a drirectory.
-            """
-            return sorted([i.name for i in os.scandir(self) if i.is_symlink()])
+        Returns
+        -------
+        list of str
+            A list of the names of all file type entries in the
+            Path. If the Path is not a directory or not accessible,
+            an exception is raised.
+        """
+        return sorted([i.name for i in os.scandir(self) if i.is_file()])
 
+    def symlinks(self):
+        """
+        Returns all symlinks in a drirectory.
+        """
+        return sorted([i.name for i in os.scandir(self) if i.is_symlink()])
 
     def glob(self, recursive=False):
         """
@@ -1118,7 +1049,6 @@ class Path(str):
         import glob
         return sorted([Path(i) for i in glob.glob(self, recursive=recursive)])
 
-
     def listTree(self, listdirs=False, topdown=True, sorted=False,
                  excludedirs=[], excludefiles=[],
                  includedirs=[], includefiles=[], symlinks=True):
@@ -1175,7 +1105,10 @@ class Path(str):
         handling.
 
         """
-        force_list = lambda s: (s,) if isinstance(s, (str, unicode, bytes)) else s
+        def force_list(s):
+            """Force a parameter to be a sequence (if it is a string"""
+            return (s,) if isinstance(s, (str, bytes)) else s
+
         excludedirs = force_list(excludedirs)
         includedirs = force_list(includedirs)
         excludefiles = force_list(excludefiles)
@@ -1208,7 +1141,6 @@ class Path(str):
             filelist = [f for f in filelist if not os.path.islink(f)]
         return filelist
 
-
     def filetype(self, compressed=['.gz', '.bz2']):
         """
         Return a normalized file type based on the filename suffix.
@@ -1258,7 +1190,6 @@ class Path(str):
                 ext = ext1+ext
         return ext.lstrip('.')
 
-
     def ftype_compr(self, compressed=['.gz', '.bz2']):
         """
         Return the file type and compression based on suffix.
@@ -1295,29 +1226,33 @@ class Path(str):
         else:
             return ftype, ''
 
-
-    @classmethod
-    def cwd(clas):
+    @staticmethod
+    def cwd():
         """
-        Return the current working directory.
+        Return the current working directory
+
+        Returns
+        -------
+        Path
+            The current working directory.
+
         """
         return Path(os.getcwd())
 
-
-    @classmethod
-    def home(clas):
+    @staticmethod
+    def home():
         """
         Return the user's home directory.
+
+        Returns
+        -------
+        Path
+            The user's home directory as defined by the environment
+            variable HOME.
         """
         return Path(os.environ['HOME'])
 
 
-    @classmethod
-    def tempdir(suffix=None, prefix=None, dir=None):
-        return tempfile.mkdtemp(suffix, prefix, dir)
-
-
-
 def matchAny(target, *regexps):
     """Check whether target matches any of the regular expressions.
 
@@ -1336,9 +1271,9 @@ def matchAny(target, *regexps):
 
     Examples
     --------
-    >>> matchAny('test.jpg', '.*\.png', '.*\.jpg')
+    >>> matchAny('test.jpg', '.*[.]png', '.*[.]jpg')
     True
-    >>> matchAny('test.jpeg', '.*\.png', '.*\.jpg')
+    >>> matchAny('test.jpeg', '.*[.]png', '.*[.]jpg')
     False
     >>> matchAny('test.jpg')
     False
@@ -1349,7 +1284,6 @@ def matchAny(target, *regexps):
     return False
 
 
-
 if __name__ == "__main__":
 
     import doctest
