@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -30,13 +30,11 @@ add the path of the calpy module to sys.path.
 Importing this module will automatically check the availabilty of calpy
 and set the sys.path accordingly.
 """
-from __future__ import absolute_import, division, print_function
 
 import sys
 
 import pyformex as pf
 from pyformex import utils
-from pyformex import software
 
 calpy_path = None  # never tried to detect
 
@@ -45,17 +43,17 @@ def detect(trypaths=None):
 
     global calpy_path
 
-    calpy = software.checkExternal('calpy')
+    calpy = utils.External.has('calpy')
     if not calpy:
         return
 
     print("You have calpy version %s" % calpy)
     path = ''
     calpy = calpy.split('-')[0]  # trim the version trailer
-    if software.checkVersion('calpy', '0.3.4-rev3', external=True) >= 0:
-        P = utils.command('calpy --whereami')
-        if not P.sta:
-            path = P.out.splitlines()[0]
+    if utils.External.check('calpy', '0.3.4-rev3') >= 0:
+        P = utils.command('calpy3 --whereami')
+        if not P.returncode:
+            path = P.stdout.splitlines()[0]
             pf.debug("I found calpy in %s" % path)
     if not path:
         if trypaths is None:
@@ -77,10 +75,6 @@ def detect(trypaths=None):
 
 
 def check(trypaths=None):
-    """Warn the user that calpy was not found."""
-    if pf.PY3:
-        pf.warning("Calpy, can currently not yet be run from Python3.")
-        return False
 
     if calpy_path is None:
         detect(trypaths)
@@ -90,7 +84,7 @@ def check(trypaths=None):
     except ImportError:
         pass
 
-    if software.hasModule('calpy', check=True):
+    if utils.Module.has('calpy', check=True):
         return True
     else:
         pf.warning("Sorry, I can not run this example, because you do not have calpy installed (at least not in a place where I can find it).")
@@ -112,7 +106,7 @@ else:
             We want to use the calpy interpolation facilities without
             having to set up a full model for calpy processing.
             This class just sets the necessary data to make the
-            interpolation methods (GP2NOdes, NodalAcc, NodalAvg) work.
+            interpolation methods (GP2Nodes, NodalAcc, NodalAvg) work.
 
             Parameters:
 
