@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -27,13 +27,11 @@ Interface with Abaqus/Calculix FE input files (.inp).
 
 
 """
-from __future__ import absolute_import, division, print_function
 
 import re
 import numpy as np
 from pyformex import Path
 from pyformex import utils
-from pyformex.coords import concatenate
 
 re_eltypeB = re.compile("^(?P<type>B)(?P<ndim>[23])(?P<degree>\d)?(?P<mod>(OS)?H*)$")
 re_eltype = re.compile("^(?P<type>.*?)(?P<ndim>[23]D)?(?P<nplex>\d+)?(?P<mod>[HIMRSW]*)$")
@@ -111,7 +109,7 @@ def abq_eltype(eltype):
         d = m.groupdict()
         try:
             nplex = int(d['nplex'])
-        except:
+        except Exception:
             if 'degree' in d:
                 degree = int(m.group('degree'))
                 if degree == 2:
@@ -132,7 +130,7 @@ def abq_eltype(eltype):
             d['ndim'] = '2'
         try:
             ndim = int(d['ndim'][0])
-        except:
+        except Exception:
             ndim = 3
         d['ndim'] = ndim
         if 'mod' not in d or d['mod'] is None:
@@ -258,7 +256,7 @@ def do_SYSTEM(opts, data):
     A = [float(v) for v in s[:3]]
     try:
         B = [float(v) for v in s[3:]]
-    except:
+    except Exception:
         B, C = None, None
     if len(data) > 1:
         C = [float(v) for v in data[1].split('')]
@@ -293,8 +291,8 @@ def do_NODE(opts, data):
         coords += t
 
     if 'coords' in part:
-        part['nodid'] = concatenate([part['nodid'], nodid])
-        part['coords'] = concatenate([part['coords'], coords], axis=0)
+        part['nodid'] = np.concatenate([part['nodid'], nodid])
+        part['coords'] = np.concatenate([part['coords'], coords], axis=0)
     else:
         part['nodid'] = nodid
         part['coords'] = coords
