@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -28,7 +28,6 @@
 Determine the (inner) voronoi diagram of a triangulated surface.
 Determine approximation for the centerline.
 """
-from __future__ import absolute_import, division, print_function
 
 from numpy import *
 
@@ -216,7 +215,7 @@ def removeTriangles(elems):
     Triangles appearing in the centerline are removed by this function.
     Both input and output are the connectivity of the centerline.
     """
-    rev = Connectivity(elems).inverse()
+    rev = Connectivity(elems).inverse(expand=True)
     if rev.shape[1] > 2:
         w =  where(rev[:, -3] != -1)[0]
         for i in w:
