@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -25,15 +25,17 @@
 """A class for holding results from Finite Element simulations.
 
 """
-from __future__ import absolute_import, division, print_function
-
-
-import pyformex as pf
-from pyformex.arraytools import *
-from pyformex.script import export
-from collections import OrderedDict
 
 import re
+from collections import OrderedDict
+
+import numpy as np
+
+import pyformex as pf
+import pyformex.arraytools as at
+
+from pyformex.script import export
+
 
 class FeResult(object):
     """Finite Element Results Database.
@@ -119,14 +121,14 @@ class FeResult(object):
         self.nelems = nelems
         self.nnodes = nnodes
         self.length = length
-        self.nodid = -ones((nnodes,), dtype=int32)
-        self.nodes = zeros((nnodes, 3), dtype=float32)
+        self.nodid = -np.ones((nnodes,), dtype=np.int32)
+        self.nodes = np.zeros((nnodes, 3), dtype=np.float32)
         self.elems = {}
         self.nset = {}
         self.eset = {}
 
     def Dofs(self, data):
-        self.dofs = array(data)
+        self.dofs = np.array(data)
         self.displ = self.dofs[self.dofs[:6] > 0]
         if self.displ.max() > 3:
             self.datasize['U'] = 6
@@ -147,23 +149,23 @@ class FeResult(object):
 
     def Nodeset(self, key, data):
         self.nsetkey = key
-        self.nset[key] = asarray(data)
+        self.nset[key] = np.asarray(data)
 
     def NodesetAdd(self, data):
-        self.nset[self.nsetkey] = union1d(self.nset[self.nsetkey], asarray(data))
+        self.nset[self.nsetkey] = np.union1d(self.nset[self.nsetkey], np.asarray(data))
 
     def Elemset(self, key, data):
         self.esetkey = key
-        self.eset[key] = asarray(data)
+        self.eset[key] = np.asarray(data)
 
     def ElemsetAdd(self, data):
-        self.eset[self.esetkey] = union1d(self.eset[self.esetkey], asarray(data))
+        self.eset[self.esetkey] = np.union1d(self.eset[self.esetkey], np.asarray(data))
 
     def Finalize(self):
-        self.nid = inverseUniqueIndex(self.nodid)
+        self.nid = at.inverseUniqueIndex(self.nodid)
         for k in self.elems:
-            v = asarray(self.elems[k])
-            self.elems[k] = asarray(self.nid[v])
+            v = np.asarray(self.elems[k])
+            self.elems[k] = np.asarray(self.nid[v])
         self.modeldone = True
         # we use lists, to keep the cases in order
         self.res = OrderedDict()
@@ -203,15 +205,16 @@ class FeResult(object):
 
     def NodeOutput(self, key, nodid, data):
         if key not in self.R:
-            self.R[key] = zeros((self.nnodes, self.dataSize(key, data)), dtype=float32)
+            self.R[key] = np.zeros((self.nnodes, self.dataSize(key, data)),
+                                   dtype=np.float32)
         if key == 'U':
             self.R[key][nodid-1][self.displ-1] = data
         elif key == 'S':
             n1 = self.hdr['ndi']
-            n2 = self.hdr['nshr']
-            ind = arange(len(data))
+            # n2 = self.hdr['nshr']  # TODO: unused ??
+            ind = np.arange(len(data))
             ind[n1:] += (3-n1)
-            #print(ind)
+            # print(ind)
             self.R[key][nodid-1][ind] = data
         else:
             self.R[key][nodid-1][:len(data)] = data
@@ -229,7 +232,7 @@ class FeResult(object):
             self.step = list(self.res.keys())[-1]
             self.inc = list(self.res[self.step].keys())[-1]
             self.R = self.res[self.step][self.inc]
-        except:
+        except Exception:
             self.step = None
             self.inc = None
             self.R = None
@@ -261,7 +264,7 @@ class FeResult(object):
             self.step = step
             self.inc = inc
             self.R = self.res[self.step][self.inc]
-        except:
+        except Exception:
             self.R = {}
 
 
@@ -348,11 +351,16 @@ class FeResult(object):
             for i, step in self.res.items():
                 for j, inc in step.items():
                     for k, v in inc.items():
-                        if isinstance(v, ndarray):
+                        if isinstance(v, np.ndarray):
                             data = "%s %s" % (v.dtype.kind, str(v.shape))
                         else:
                             data = str(v)
                         print("Step %s, Inc %s, Res %s (%s)" % (i, j, k, data))
 
 
-#End
+    def save(self, filename):
+        from pyformex.plugins.saveload import savePZF
+        savePZF(filename, _type="FeResult", **self.__dict__)
+
+
+# End
