@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -26,11 +26,9 @@
 This is a pyFormex plugin. It is not intended to be executed as a script,
 but to be loaded as a plugin.
 """
-from __future__ import absolute_import, division, print_function
 
 import pyformex as pf
-from pyformex import zip, utils
-from pyformex.formex import *
+from pyformex.lazy import *
 
 from pyformex.gui import menu
 from pyformex.gui.draw import *
