@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -67,8 +67,6 @@ No change ::
   ref(i,j)|F  -> F.reflect(i-1,j)
 
 """
-from __future__ import absolute_import, division, print_function
-from pyformex import zip, round
 
 from pyformex.formex import Formex
 
@@ -76,7 +74,10 @@ from pyformex.formex import Formex
 
 Formex.order = Formex.nelems
 Formex.plexitude = Formex.nplex
-Formex.grade = Formex.ndim
+
+def grade(self):
+    return 3
+Formex.grade = grade
 
 Formex.cantle = Formex.element
 Formex.signet = Formex.point
@@ -85,7 +86,7 @@ Formex.cop = Formex.remove
 
 Formex.cantle2str = Formex.element2str
 Formex.signet2str = Formex.point2str
-Formex.pex = Formex.unique
+Formex.pex = Formex.removeDuplicate
 
 # methods that can be emulated in Formex
 
