@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -29,7 +29,6 @@ but to be loaded into pyFormex using the plugin facility.
 The geometry menu is intended to become the major interactive geometry menu
 in pyFormex.
 """
-from __future__ import absolute_import, division, print_function
 
 import pyformex as pf
 from pyformex import utils
@@ -38,25 +37,21 @@ from pyformex import filewrite
 from pyformex import simple
 
 from pyformex.geomfile import GeometryFile
-
 from pyformex.gui import menu
-from pyformex.gui.draw import *
-
 from pyformex.plugins import objects
 from pyformex.plugins import partition
 from pyformex.plugins import sectionize
-from pyformex.plugins import surface_menu
+#from pyformex.plugins import surface_menu
 from pyformex.plugins import saveload
+from pyformex.gui.draw import *
 
 _name_ = 'geometry_menu'
 
-
 # settings for this module
 outline_linewidth = 2
 outline_color = 'red'
 
 
-
 ##################### selection of objects ##########################
 
 # We put these in an init function to allow --doctest to run without GUI
@@ -64,7 +59,8 @@ outline_color = 'red'
 def _init_():
     global selection
     global selection_F, selection_M, selection_TS, selection_PL, selection_NC, setSelection, drawSelection
-    selection = pf.GUI.selection['geometry']
+    if pf.GUI:
+        selection = pf.GUI.selection['geometry']
 
 
 def geomList():
@@ -286,62 +282,61 @@ def readInp(fn=None):
         return
 
 
-def writeGeometry(obj, filename, filetype=None, compr=False, **kargs):
+def writeGeometry(obj, filename, ftype=None, compr=False, **kargs):
     """Write the geometry items in objdict to the specified file.
 
     Returns the number of objects written.
     """
     nobj = 0
     filename = Path(filename)
-    if filetype is None:
-        filetype = filename.filetype()
+    if ftype is None:
+        ftype, compr = filename.ftype_compr()
 
-    if filetype in ['pzf']:
+    if ftype in ['pzf']:
         res = ask("Include the current camera/canvas settings?", ["No", "Camera only", "Full Canvas Layout"])
         if res.startswith("Camera"):
             obj['_camera'] = True
         elif res.startswith("Full"):
             obj['_canvas'] = True
 
-    print("Writing file of type %s" % filetype)
-    ext = '.'+filetype
+    print("Writing file of type %s" % ftype)
 
-    if ext in utils.fileExtensions('pgf', compr=compr):
+    if ftype in utils.fileTypes('pgf', compr=compr):
         sep = '' if kargs['mode']=='binary' else ' '
         shortlines = kargs['mode'].startswith('short')
         nobj = writeGeomFile(filename, obj, sep=sep, shortlines=shortlines)
 
-    elif ext in utils.fileExtensions('pzf', compr=compr):
+    elif ftype in utils.fileTypes('pzf', compr=compr):
         saveload.savePZF(filename, **obj)
         nobj = len(obj)
 
-    elif ext in utils.fileExtensions('obj', compr=compr) or \
-             ext in utils.fileExtensions('off', compr=compr) or \
-             ext in utils.fileExtensions('ply', compr=compr):
+    elif ftype in utils.fileTypes('obj', compr=compr) or \
+         ftype in utils.fileTypes('off', compr=compr) or \
+         ftype in utils.fileTypes('ply', compr=compr):
         for name in obj:
             # There is only one because of the single selection mode
             mesh = obj[name]
             if not isinstance(mesh, Mesh):
                 try:
                     mesh = mesh.toMesh()
-                except:
+                except Exception:
                     error("Object is not a Mesh and can not be converted to a Mesh.")
                     continue
-            if ext in utils.fileExtensions('obj', compr=compr):
+            if ftype in utils.fileTypes('obj', compr=compr):
                 filewrite.writeOBJ(filename, mesh)
-            elif ext in utils.fileExtensions('off', compr=compr):
+            elif ftype in utils.fileTypes('off', compr=compr):
                 filewrite.writeOFF(filename, mesh)
-            elif ext in utils.fileExtensions('ply', compr=compr):
+            elif ftype in utils.fileTypes('ply', compr=compr):
                 filewrite.writePLY(filename, mesh)
             nobj += 1
 
     else:
-        error("Don't know how to export in '%s' format" % filetype)
+        error("Don't know how to export in '%s' format" % ftype)
 
     return nobj
 
 
-def exportGeometry(types, selmode, compr=False, **kargs):
+def exportGeometry(types, selmode, compr=True, **kargs):
     """Write geometry to file.
 
     mode: 'multi' allows writing more than one object
@@ -360,9 +355,9 @@ def exportGeometry(types, selmode, compr=False, **kargs):
     if res:
         fn = res['fn']
         del res['fn']
-        print("Writing geometry file %s" % fn)
+        print(f"Writing geometry file {fn}")
         res = writeGeometry(db.odict(), fn, compr=compr, **res)
-        print("Contents: %s" % res)
+        print(f"Contents: {res}")
 
 
 def exportPgf():
@@ -403,15 +398,15 @@ def setAttributes():
         F = FL[0]
         try:
             color = F.color
-        except:
+        except Exception:
             color = 'black'
         try:
             alpha = F.alpha
-        except:
+        except Exception:
             alpha = 0.7
         try:
             visible = F.visible
-        except:
+        except Exception:
             visible = True
         res = askItems([
             _I('caption', name),
@@ -432,7 +427,7 @@ def printDataSize():
         S = named(s)
         try:
             size = S.info()
-        except:
+        except Exception:
             size = 'no info available'
         print("* %s (%s): %s" % (s, S.__class__.__name__, size))
 
@@ -824,7 +819,7 @@ def rotatePrincipal():
     """Rotate the selection according to the last shown principal axes."""
     try:
         data = named('_principal_data_')
-    except:
+    except Exception:
         data = showPrincipal()
     FL = selection.check()
     if FL:
@@ -840,7 +835,7 @@ def transformPrincipal():
     """
     try:
         data = named('_principal_data_')
-    except:
+    except Exception:
         data = showPrincipal()
     FL = selection.check()
     if FL:
@@ -897,6 +892,9 @@ def doOnSelectedMeshes(method):
 def removeDegenerate():
     doOnSelectedMeshes(Mesh.removeDegenerate)
 
+def removeDuplicate():
+    doOnSelectedMeshes(Mesh.removeDuplicate)
+
 
 def compactMesh():
     """Compact the Mesh"""
@@ -1301,6 +1299,7 @@ def create_menu():
             ("&Compact", compactMesh),
             ("&Fuse nodes", fuseMesh),
             ("&Remove degenerate", removeDegenerate),
+            ("&Remove duplicate", removeDuplicate),
             ("&Renumber nodes", [
                 ("In element order", renumberMesh),
                 ("In random order", renumberMeshRandom),
@@ -1316,7 +1315,7 @@ def create_menu():
         ("&Close", close_menu),
         ]
     M = menu.Menu(_menu, items=MenuData, parent=pf.GUI.menu, before='help')
-    ## if not utils.hasExternal('dxfparser'):
+    ## if not utils.External.has('dxfparser'):
     ##     I = M.item("&Import ").item("AutoCAD .dxf")
     ##     I.setEnabled(False)
     return M
@@ -1350,8 +1349,8 @@ def run():
     _init_()
     reload_menu()
 
-if __name__ == '__draw__':
-    run()
+# if __name__ == '__draw__':
+#     run()
 
 
 # End
