@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -30,7 +30,6 @@ that reads a full stack of Dicom images into a 3D numpy array.
 
 Some of this code was based on ideas found on the PyQwt mailing list.
 """
-from __future__ import absolute_import, division, print_function
 
 import numpy as np
 import PIL.Image
@@ -38,12 +37,11 @@ import PIL.Image
 import pyformex as pf
 from pyformex import utils
 from pyformex import arraytools as at
-from pyformex import gui
 from pyformex.gui import QtGui, QImage
 
 QColor = QtGui.QColor
 
-if gui.bindings == 'pyside2':
+if pf.gui.bindings == 'pyside2':
     QImage.numBytes = QImage.byteCount
 
 ####################################################################
@@ -72,6 +70,12 @@ def image2array(filename, mode=None, flip=True):
         when using images as fonts in :class:`FontTexture`, because the
         FontTexture engine itself takes account of the top-down image
         storage.
+
+    Examples
+    --------
+    >>> im = image2array(pf.cfg['datadir'] / 'butterfly.png')
+    >>> im.shape
+    (419, 420, 3)
     """
     im = PIL.Image.open(filename)
     if mode and im.mode != mode:
@@ -95,8 +99,8 @@ def array2image(ar, filename):
     filename: :term:`path_like`
         The name of the file where the image is to be saved.
     """
-    img = PIL.Image.fromarray(ar)
-    img.save(filename)
+    im = PIL.Image.fromarray(ar)
+    im.save(filename)
 
 
 def image2string(filename):
@@ -110,7 +114,6 @@ def image2string(filename):
     return nx, ny, data
 
 
-
 ####################################################################
 # Handle images using QImage
 
@@ -239,21 +242,21 @@ def qimage2numpy(image, resize=(0, 0), order='RGBA', flip=True, indexed=None):
                           QImage.Format_ARGB32,
                           QImage.Format_RGB32):
         buf = image.bits()
-        if gui.bindings == 'pyqt4':
+        if pf.gui.bindings == 'pyqt4':
             buf = buf.asstring(image.numBytes())
-        ar = np.frombuffer(buf, dtype='ubyte', count=image.numBytes()).reshape(h, w, 4)
+        ar = np.frombuffer(buf, dtype='ubyte',
+                           count=image.numBytes()).reshape(h, w, 4)
         idx = ['BGRA'.index(c) for c in order]
         ar = ar[..., idx]
         ct = None
 
     elif image.format() == QImage.Format_Indexed8:
         ct = np.array(image.colorTable(), dtype=np.uint32)
-        #print("IMAGE FORMAT is INDEXED with %s colors" % ct.shape[0])
         ct = ct.view(np.uint8).reshape(-1, 4)
         idx = ['BGRA'.index(c) for c in order]
         ct = ct[..., idx]
         buf = image.bits()
-        if gui.bindings == 'pyqt4':
+        if pf.gui.bindings == 'pyqt4':
             buf = buf.asstring(image.numBytes())
         ar = np.frombuffer(buf, dtype=np.uint8)
         if ar.size % h == 0:
@@ -268,10 +271,12 @@ def qimage2numpy(image, resize=(0, 0), order='RGBA', flip=True, indexed=None):
         if ar.size != w*h:
             # This should no longer happen, since we have now adjusted
             # the numpy buffer width to the correct image width.
-            pf.warning("Size of image data (%s) does not match the reported dimensions: %s x %s = %s" % (ar.size, w, h, w*h))
+            pf.warning(f"Size of image data ({ar.size}) does not match "
+                       f"the reported dimensions: {w} x {h} = {w*h}")
 
     else:
-        raise ValueError("qimage2numpy only supports 32bit and 8bit images. Your qimage format is %s" % image.format())
+        raise ValueError("qimage2numpy only supports 32bit and 8bit images. "
+                         f"Your qimage format is {image.format()}")
 
     # Put upright as expected
     if flip:
@@ -279,8 +284,8 @@ def qimage2numpy(image, resize=(0, 0), order='RGBA', flip=True, indexed=None):
 
     # Convert indexed to nonindexed if requested
     if indexed is False and ct is not None:
-            ar = ct[ar]
-            ct = None
+        ar = ct[ar]
+        ct = None
 
     # Return only full colors if requested
     if indexed is False:
@@ -290,94 +295,96 @@ def qimage2numpy(image, resize=(0, 0), order='RGBA', flip=True, indexed=None):
 
 
 def numpy2qimage(array):
-        """
-        Convert a 2D or 3D integer numpy array into a QImage
+    """
+    Convert a 2D or 3D integer numpy array into a QImage
 
-        Parameters
-        ----------
-        array: 2D or 3D int array
-            If the input array is 2D, the array is converted into a gray image.
-            If the input array is 3D, the last axis should have length 3 or 4
-            and represents the color channels in order RGB or RGBA.
+    Parameters
+    ----------
+    array: 2D or 3D int array
+        If the input array is 2D, the array is converted into a gray image.
+        If the input array is 3D, the last axis should have length 3 or 4
+        and represents the color channels in order RGB or RGBA.
 
-        Notes
-        -----
-        This is equivalent to calling :func:`gray2qimage` for a 2D array
-        and :func:`rgb2qimage` for a 3D array.
+    Notes
+    -----
+    This is equivalent to calling :func:`gray2qimage` for a 2D array
+    and :func:`rgb2qimage` for a 3D array.
 
-        """
-        if np.ndim(array) == 2:
-                return gray2qimage(array)
-        elif np.ndim(array) == 3:
-                return rgb2qimage(array)
-        raise ValueError("can only convert 2D or 3D arrays")
+    """
+    if np.ndim(array) == 2:
+        return gray2qimage(array)
+    elif np.ndim(array) == 3:
+        return rgb2qimage(array)
+    raise ValueError("can only convert 2D or 3D arrays")
 
 
 def gray2qimage(gray):
-        """
-        Convert a 2D numpy array to gray QImage.
+    """
+    Convert a 2D numpy array to gray QImage.
 
-        Parameters
-        ----------
-        gray: uint8 array (height,width)
-            Array with the grey values of an image with size (height,width).
+    Parameters
+    ----------
+    gray: uint8 array (height,width)
+        Array with the grey values of an image with size (height,width).
 
-        Returns
-        -------
-        QImage
-            A QImage with the corresponding gray image. The image format
-            will be indexed.
-        """
-        if len(gray.shape) != 2:
-                raise ValueError("gray2QImage can only convert 2D arrays")
+    Returns
+    -------
+    QImage
+        A QImage with the corresponding gray image. The image format
+        will be indexed.
+    """
+    if len(gray.shape) != 2:
+        raise ValueError("gray2QImage can only convert 2D arrays")
 
-        gray = np.require(gray, np.uint8, 'C')
-        h, w = gray.shape
-        result = QImage(gray.data, w, h, QImage.Format_Indexed8)
-        result.ndarray = gray
-        for i in range(256):
-                result.setColor(i, QColor(i, i, i).rgb())
-        return result
+    gray = np.require(gray, np.uint8, 'C')
+    h, w = gray.shape
+    result = QImage(gray.data, w, h, QImage.Format_Indexed8)
+    result.ndarray = gray
+    for i in range(256):
+        result.setColor(i, QColor(i, i, i).rgb())
+    return result
 
 
 def rgb2qimage(rgb):
-        """
-        Convert a 3D numpy array into a 32-bit QImage.
+    """
+    Convert a 3D numpy array into a 32-bit QImage.
 
-        Parameters
-        ----------
-        rgb: int array (height,width,ncomp)
-            Int array with the pixel values of the image. The data can have
-            3 (RGB) or 4 (RGBA) components.
+    Parameters
+    ----------
+    rgb: int array (height,width,ncomp)
+        Int array with the pixel values of the image. The data can have
+        3 (RGB) or 4 (RGBA) components.
 
-        Returns
-        -------
-        QImage
-            A QImage with size (height,width) in the format
-            RGB32 (3 components) or ARGB32 (4 components).
-        """
-        if len(rgb.shape) != 3:
-                raise ValueError("rgb2QImage expects the first (or last) dimension to contain exactly three (R,G,B) channels")
-        if rgb.shape[2] != 3:
-                raise ValueError("rgb2QImage can only convert 3D arrays")
+    Returns
+    -------
+    QImage
+        A QImage with size (height,width) in the format
+        RGB32 (3 components) or ARGB32 (4 components).
+    """
+    if len(rgb.shape) != 3:
+        raise ValueError(
+            "rgb2QImage expects the first (or last) dimension "
+            "to contain exactly three (R,G,B) channels")
+    if rgb.shape[2] != 3:
+        raise ValueError("rgb2QImage can only convert 3D arrays")
 
-        h, w, channels = rgb.shape
+    h, w, channels = rgb.shape
 
-        # Qt expects 32bit BGRA data for color images:
-        bgra = np.empty((h, w, 4), np.uint8, 'C')
-        bgra[..., 0] = rgb[..., 2]
-        bgra[..., 1] = rgb[..., 1]
-        bgra[..., 2] = rgb[..., 0]
+    # Qt expects 32bit BGRA data for color images:
+    bgra = np.empty((h, w, 4), np.uint8, 'C')
+    bgra[..., 0] = rgb[..., 2]
+    bgra[..., 1] = rgb[..., 1]
+    bgra[..., 2] = rgb[..., 0]
 
-        if channels == 4:
-            bgra[..., 3] = rgb[..., 3]
-            fmt = QImage.Format_ARGB32
-        else:
-            fmt = QImage.Format_RGB32
+    if channels == 4:
+        bgra[..., 3] = rgb[..., 3]
+        fmt = QImage.Format_ARGB32
+    else:
+        fmt = QImage.Format_RGB32
 
-        result = QImage(bgra.data, w, h, fmt)
-        result.ndarray = bgra
-        return result
+    result = QImage(bgra.data, w, h, fmt)
+    result.ndarray = bgra
+    return result
 
 
 def qimage2glcolor(image, resize=(0, 0)):
@@ -455,189 +462,7 @@ def saveGreyImage(a, f, flip=True):
     im.save(f)
 
 
-
-
-if utils.checkModule('pydicom') or pf.sphinx:
-
-    class DicomStack(object):
-        """
-        A stack of DICOM images.
-
-        Note
-        ----
-        This class is only available if you have pydicom installed.
-
-
-        The DicomStack class stores a collection of DICOM images
-        and provides conversion to ndarray.
-
-        The DicomStack is initialized by a list of file names.
-        All input files are scanned for DICOM image data and
-        non-DICOM files are skipped.
-        From the DICOM files, the pixel and slice spacing are read,
-        as well as the origin.
-        The DICOM files are sorted in order of ascending origin_z value.
-
-        While reading the DICOM files, the following attributes are set:
-
-        - `files`: a list of the valid DICOM files, in order of ascending
-          z-value.
-        - `pixel_spacing`: a dict with an (x,y) pixel spacing tuple as key
-          and a list of indices of the matching images as value.
-        - `slice_thickness`: a list of the slice thicknesses of the
-          images, in the same order as `files`.
-        - `xy_origin`: a dict with an (x,y) position the pixel (0,0) as key
-          and a list of indices of the matching images as value.
-        - `z_origin`: a list of the z positions of the images,
-          in the same order as `files`.
-        - `rejected`: list of rejected files.
-
-        """
-
-        class Object(object):
-            """_A dummy object to allow attributes"""
-            pass
-
-
-        def __init__(self, files, zsort=True, reverse=False):
-            """Initialize the DicomStack."""
-            # defer import for startup efficiency
-            import pydicom
-
-            ok = []
-            rejected = []
-            for fn in files:
-                obj = DicomStack.Object()
-                dataset = pydicom.dcmread(fn)
-                try:
-                    obj.fn = fn
-                    obj.image = dataset.pixel_array
-                    obj.spacing = dataset.PixelSpacing
-                    try:
-                        obj.spacingz = dataset.SpacingBetweenSlices
-                    except:
-                        obj.spacingz = None
-                    obj.origin = np.array(dataset.ImagePositionPatient)
-                    obj.intercept = dataset.RescaleIntercept
-                    obj.slope = dataset.RescaleSlope
-                    ok.append(obj)
-                except:
-                    rejected.append(obj)
-                    raise
-
-            if zsort:
-                ok.sort(key=lambda obj: obj.origin[2], reverse=reverse)
-
-            self.ok, self.rejected = ok, rejected
-
-
-
-        def nfiles(self):
-            """Return the number of accepted files."""
-            return len(self.ok)
-
-
-        def files(self):
-            """Return the list of accepted filenames"""
-            return [obj.fn for obj in self.ok]
-
-
-        def rejected(self):
-            """Return the list of rejected filenames"""
-            return [obj.fn for obj in self.rejected]
-
-
-        def pspacing(self):
-            """Return the pixel spacing and slice thickness.
-
-            Return the pixel spacing (x,y) and the slice thickness (z)
-            in the accepted images.
-
-            Returns: a float array of shape (nfiles,3).
-            """
-            return np.array([obj.spacing for obj in self.ok])
-
-
-        def origin(self):
-            """Return the origin of all accepted images.
-
-            Return the world position of the pixel (0,0) in all accepted images.
-
-            Returns: a float array of shape (nfiles,3).
-            """
-            return np.array([obj.origin for obj in self.ok])
-
-
-        def zvalues(self):
-            """Return the zvalue of all accepted images.
-
-            The zvalue is the z value of the origin of the image.
-
-            Returns: a float array of shape (nfiles).
-            """
-            return np.array([obj.origin[2] for obj in self.ok])
-
-
-        def zspacing(self):
-            """Check for constant slice spacing."""
-            zval = self.zvalues()
-            zdif = zval[1:] - zval[:-1]
-            if np.allclose(zdif, zdif[0]):
-                self.spacingz = zdif[0]
-            else:
-                self.spacingz = None
-            return self.spacingz
-
-
-        def spacing(self):
-            """Return uniform spacing parameters, if uniform."""
-            pspacing = self.pspacing()
-            if np.allclose(pspacing[:, 0], pspacing[0, 0]) and \
-               np.allclose(pspacing[:, 1], pspacing[0, 1]):
-                self.spacingp = pspacing[0]
-                if self.zspacing():
-                    return np.concatenate([self.spacingp, [self.spacingz]])
-            return None
-
-
-        def image(self, i):
-            """Return the image at index i"""
-            return self.ok[i].image
-
-
-        def pixar(self, raw=False):
-            """Return the DicomStack as an array
-
-            Returns all images in a single array. This is only succesful
-            if all accepted images have the same size.
-            """
-            if raw:
-                data = np.dstack([obj.image for obj in self.ok])
-            else:
-                 data = np.dstack([obj.image*obj.slope+obj.intercept for obj in self.ok])
-            return data
-
-
-    def dicom2numpy(files):
-        """
-        Easy conversion of a set of dicom images to a numpy array.
-
-        Parameters
-        ----------
-        files: list of :term:`path_like`
-            List of file names containing the subsequent DICOM images
-            in the stack.
-            The file names should be in the correct order.
-
-        Returns
-        -------
-        pixar: int array (nfiles, height, width)
-            Pixel array with the nfiles images.
-        spacing:
-
-        """
-        ds = DicomStack(files)
-        return ds.pixar(), ds.spacing()[0]
-
+if utils.Module.has('pydicom') or pf.sphinx:
+    from .dicomstack import DicomStack, dicom2numpy   # noqa: F401
 
 # End
