@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -24,14 +24,13 @@
 """Jobs Menu
 
 """
-from __future__ import absolute_import, division, print_function
 
 import pyformex as pf
 from pyformex import utils
 from pyformex.gui import menu
 
 from numpy import *
-from pyformex.formex import *
+from pyformex.lazy import *
 from pyformex.gui.draw import *
 from pyformex.opengl.colors import *
 
@@ -109,10 +108,10 @@ def getRemoteDirs(host, userdir):
     """
     cmd = "ssh %s 'cd %s;ls -F|egrep \".*/\"'" % (host, userdir)
     P = utils.command(cmd, shell=True)
-    if P.sta:
+    if P.returncode:
         dirs = []
     else:
-        dirs = [j.strip('/') for j in P.out.split('\n')]
+        dirs = [j.strip('/') for j in P.stdout.split('\n')]
     return dirs
 
 
@@ -124,9 +123,9 @@ def getRemoteDirs(host, userdir):
 ##     """
 ##     cmd = "ssh %s 'cd %s;ls -F'" % (host,userdir)
 ##     P = utils.command(cmd,shell=True)
-##     if P.sta:
-##         P.out = ''
-##     dirs = P.out.split('\n')
+##     if P.returncode:
+##         P.stdout = ''
+##     dirs = P.stdout.split('\n')
 ##     dirs = [ j.strip('/') for j in dirs ]
 ##     return dirs
 
@@ -139,7 +138,7 @@ def transferFiles(host, userdir, files, targetdir):
     files = ['%s:%s/%s' % (host, userdir.rstrip('/'), f) for f in files]
     cmd = "scp %s %s" % (' '.join(files), targetdir)
     P = utils.command(cmd)
-    return P.sta
+    return P.returncode
 
 
 def rsyncFiles(srcdir, tgtdir, include=['*'], exclude=[], exclude_first=False, rsh='ssh -q', chmod='ug+rwX,o-rwx', opts='-rv'):
@@ -211,18 +210,18 @@ def submitJob(srcdir, tgtdir, include=[], delete_old=True):
     """
     if delete_old:
         P = rsyncFiles(srcdir, tgtdir, include=[], exclude=['*'], exclude_first=True, opts=' -rv --delete --delete-excluded')
-        if P.sta:
+        if P.returncode:
             pf.warning("Could not delete old files from request folder!")
 
     if include:
         P = rsyncFiles(srcdir, tgtdir, include=include, exclude=['*'])
     else:
         P = rsyncFiles(srcdir, tgtdir, exclude=['*.request'], include=include, exclude_first=True)
-    if P.sta:
-        print(P.out)
+    if P.returncode:
+        print(P.stdout)
     else:
         P = rsyncFiles(srcdir, tgtdir, include=['*.request'], exclude=['*'])
-    if P.sta:
+    if P.returncode:
         pf.warning("Some error occurred during file transfer!")
 
 
@@ -249,8 +248,8 @@ def remoteCommand(host=None, command=None):
 
     if host and command:
         P = utils.command(['ssh', host, command])
-        print(P.out)
-        return P.sta
+        print(P.stdout)
+        return P.returncode
 
 
 def runLocalProcessor(filename='', processor='abaqus'):
@@ -273,7 +272,7 @@ def runLocalProcessor(filename='', processor='abaqus'):
         cmd = cmd.replace('$C', cpus)
         cmd = "cd %s;%s" % (dirname, cmd)
         P = utils.command(cmd, shell=True)
-        print(P.out)
+        print(P.stdout)
 
 
 def runLocalAbaqus(filename=''):
@@ -332,7 +331,7 @@ def killClusterJob(jobname=None):
         print(host)
         print(cmd)
         P = utils.command(['ssh', host, "%s" % cmd])
-        print(P.out)
+        print(P.stdout)
 
 
 the_host = None
@@ -407,7 +406,7 @@ def getResultsFromServer(jobname=None, targetdir=None, ext=['.fil']):
         res = askItems(jobname_input + [
             _I('target dir', targetdir, itemtype='button', func=changeTargetDir),
             _I('create subdir', False, tooltip="Create subdir (with same name as remote) in target dir"),
-            ('_post.py', True),
+            ('.post.py', True),
             ('.fil', False),
             ('.odb', False),
             _I('other', [], tooltip="A list of '.ext' strings"),
@@ -420,7 +419,7 @@ def getResultsFromServer(jobname=None, targetdir=None, ext=['.fil']):
             if res['create subdir']:
                 targetdir = targetdir / jobname
                 mkdir(targetdir)
-            ext = [e for e in ['.fil', '_post.py', '.odb'] if res[e]]
+            ext = [e for e in ['.fil', '.post.py', '.odb'] if res[e]]
             res += [e for e in res['other'] if e.startswith('.')]
     if jobname and ext:
         files = ['%s%s' % (jobname, e) for e in ext]
@@ -428,7 +427,7 @@ def getResultsFromServer(jobname=None, targetdir=None, ext=['.fil']):
         with busyCursor():
             if transferFiles(host, userdir, files, targetdir) == 0:
                 the_jobname = jobname
-                print("Files succesfully transfered")
+                print("Files successfully transfered")
 
 
 
