@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -27,12 +27,12 @@
 The Mesh methods in this module are deprecated and will likely be removed in
 a future version of pyFormex. Their use is highly discouraged.
 """
-from __future__ import absolute_import, division, print_function
 
+import numpy as np
 
 from pyformex.mesh import *
 from pyformex import utils
-
+from pyformex import arraytools
 utils.warn('The plugins.mesh_ext module is deprecated and will be removed in future. If you need any of its functionality, ask the developers to port it to some other module.')
 
 ##############################################################################
@@ -161,7 +161,7 @@ def scaledJacobian(self, scaled=True, blksize=100000):
         ], dtype=int)
         nc = 4
     elif self.elName()=='hex8':
-        iacre=array([
+        iacre=np.array([
         [[0, 4], [1, 5], [2, 6], [3, 7], [4, 7], [5, 4], [6, 5], [7, 6]],
         [[0, 1], [1, 2], [2, 3], [3, 0], [4, 5], [5, 6], [6, 7], [7, 4]],
         [[0, 3], [1, 0], [2, 1], [3, 2], [4, 0], [5, 1], [6, 2], [7, 3]],
@@ -169,13 +169,14 @@ def scaledJacobian(self, scaled=True, blksize=100000):
         nc = 8
     acre = self.coords[self.elems][:, iacre]
     vacre = acre[:, :, :, 1]-acre[:, :, :, 0]
-    cvacre = concatenate(vacre, axis=1)
-    J = vectorTripleProduct(*cvacre).reshape(ne, nc)
+    cvacre = np.concatenate(vacre, axis=1)
+    from pyformex import arraytools
+    J = arraytools.vectorTripleProduct(*cvacre).reshape(ne, nc)
     if not scaled:
         return J
     else:
         # volume of 3 normal edges
-        normvol = prod(length(cvacre), axis=0).reshape(ne, nc)
+        normvol = np.prod(arraytools.length(cvacre), axis=0).reshape(ne, nc)
         Jscaled = J/normvol
         return Jscaled.min(axis=1)
 
@@ -259,7 +260,7 @@ def nodalAveraging(self, val, iter=1, mask=None, includeself=False):
     # zoomAll()
     """
 
-    avgval = checkArray1D(val, kind='f', size=self.ncoords())
+    avgval = arraytools.checkArray1D(val, kind='f', size=self.ncoords())
     if iter==0:
         return avgval
     nadj = self.getEdges().adjacency(kind='n')
@@ -267,14 +268,15 @@ def nodalAveraging(self, val, iter=1, mask=None, includeself=False):
         nadj = concatenate([nadj, arange(alen(nadj)).reshape(-1, 1)], axis=1)
     inadj = nadj>=0  # False if == -1
     lnadj = inadj.sum(axis=1)  # nr of adjacent nodes
-    lnadj = lnadj.astype(Float)  # NEEDED!!!, otherwise it becomes float64 and fails if mask is not None !
-    #### Why would float64 fail and float32 not???
+
+    lnadj = lnadj.astype(np.float32)  # NEEDED!!!, otherwise it becomes float64 and fails if mask is not None !
+
     if mask is None:
         for j in range(iter):
-            avgval = sum(avgval[nadj]*inadj, axis=1)/lnadj  # multiplying by inadj set to zero the values where nadj==-1
+            avgval = np.sum(avgval[nadj]*inadj, axis=1)/lnadj  # multiplying by inadj set to zero the values where nadj==-1
     else:
         for j in range(iter):
-            avgval[mask] = (sum(avgval[nadj]*inadj, axis=1)/lnadj)[mask]
+            avgval[mask] = (np.sum(avgval[nadj]*inadj, axis=1)/lnadj)[mask]
     return avgval
 
 
@@ -310,7 +312,7 @@ def edgeSpin(edges, elems, check=True):
         n1 = n0[:, ::-1]
         spinbad = [(edges == elems[:, i]).sum(axis=1)==2 for i in n1]
         spinbad = array(sum(spinbad, axis=0), dtype=bool)
-        diff = sum(spinok==spinbad)
+        diff = np.sum(spinok==spinbad)
         if diff>0:
             raise ValueError("there are %d edges which are not in elems" % diff)
     return spinok
@@ -325,7 +327,7 @@ def doubleSpinEdges(self, return_mask=False):
     spin2, mask = doubleSpinEdges(S, True)
     draw(Mesh(S.coords, S.getEdges()[mask][spin2]), color='blue', linewidth=4)
     """
-    conn = self.getElemEdges().inverse()
+    conn = self.getElemEdges().inverse(expand=True)
     conn2 = (conn >= 0).sum(axis=-1) == 2
     conn = conn[conn2]  # remove border edges
     e2 = self.getEdges()[conn2]
@@ -340,7 +342,7 @@ def doubleSpinEdges(self, return_mask=False):
 def frontWalkEdge(self, maskedge, **kargs):
     """Front walk over elems connected by edges not in maskedge"""
     adj = self.adjacency(level=1)
-    cadj = self.getElemEdges().inverse()[maskedge]
+    cadj = self.getElemEdges().inverse(expand=True)[maskedge]
     cadj = concatenate([cadj, cadj[:, ::-1]])
     cpos = adj[cadj[:, 0]] == cadj[:, 1].reshape(-1, 1)
     adj[cadj[:, 0], where(cpos)[1]]=-1
