@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -24,7 +24,6 @@
 """Partitioning tools
 
 """
-from __future__ import absolute_import, division, print_function
 
 import numpy
 
@@ -33,7 +32,7 @@ from pyformex import Path
 from pyformex.opengl import colors
 from pyformex.opengl import decors
 from pyformex.gui.draw import *
-from pyformex.formex import *
+from pyformex.lazy import *
 from pyformex import geomtools
 
 inverse = numpy.linalg.linalg.inv
