@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -25,8 +25,8 @@
 
 Generic 2D plotting functions for pyFormex.
 """
-from __future__ import absolute_import, division, print_function
 
+import numpy as np
 
 import pyformex as pf
 from pyformex import utils
@@ -45,7 +45,7 @@ def init_plot2d_system(plot2d=None):
     else:
         # need initialisation
         plot2d = pf.cfg['plot2d']
-        if utils.hasModule(plot2d):
+        if utils.Module.has(plot2d):
             if plot2d == 'gnuplot':
                 import Gnuplot as plt
             elif plot2d == 'qwt':
@@ -56,7 +56,7 @@ def init_plot2d_system(plot2d=None):
                 import matplotlib.pyplot as plt
         else:
             plot2d = None
-            pf.error("I can not draw the plot because I could not load the requested 2d plot library '%s' for your Python version (%s). You need to install one of the supported plot libraries and/or set the appropriate preference in your pyFormex configuration file or via the Settings->Settings Dialog menu item." % (plot2d_system, 2 if pf.PY2 else 3))
+            pf.error("I can not draw the plot because I could not load the requested 2d plot library '%s' for your Python version (%s). You need to install one of the supported plot libraries and/or set the appropriate preference in your pyFormex configuration file or via the Settings->Settings Dialog menu item." % (plot2d_system, 3))
 
     plot2d_system = plot2d
     return plot2d_system
@@ -124,7 +124,7 @@ def createHistogram(data, cumulative=False, **kargs):
     Create a histogram from data
 
     """
-    y, x = at.histogram(data, **kargs)
+    y, x = np.histogram(data, **kargs)
     if cumulative:
         y = y.cumsum()
     return y, x
