@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -25,11 +25,10 @@
 """Polygonal facets.
 
 """
-from __future__ import absolute_import, division, print_function
 
 
 import pyformex as pf
-from pyformex.formex import *
+from pyformex.lazy import *
 from pyformex.geometry import Geometry
 from pyformex.plugins.curve import PolyLine
 from pyformex.trisurface import TriSurface
@@ -161,7 +160,7 @@ class Polygon(Geometry):
         """
         #print("AREA(self) %s" % self.area())
         # creating elems array at once (more efficient than appending)
-        from pyformex.gui.draw import draw, pause, undraw
+        #from pyformex.gui.draw import draw, pause, undraw, drawNumbers
         from pyformex.geomtools import insideTriangle
         x = self.coords
         n = x.shape[0]
@@ -171,6 +170,8 @@ class Polygon(Geometry):
         c = self.internalAngles()
         # loop in order of smallest angles
         itri = 0
+        #draw(x)
+        #drawNumbers(x)
         while n > 3:
             #print("ANGLES",c)
             # try minimal angle
@@ -198,7 +199,7 @@ class Polygon(Geometry):
                 cnew = cn[1:3]
                 reme = roll(e, -j)[2:-1]
                 T = x[newtri].reshape(1, 3, 3)
-                P = x[reme].reshape(-1, 1, 3)
+                P = x[reme].reshape(1, -1, 3)
                 check = insideTriangle(T, P)
                 if not check.any():
                     # Triangle is ok
@@ -238,7 +239,6 @@ class Polygon(Geometry):
 
 if __name__ == '__draw__':
 
-
     def randomPL(n=5, r=0.7, noise=0.0):
         x = randomNoise((n), r*3., 3.)
         y = sorted(randomNoise((n), 0., 360.))
