@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -27,24 +27,26 @@
 Postprocessing means collecting a geometrical model and computed values
 from a numerical simulation, and render the values on the domain.
 """
-from __future__ import absolute_import, division, print_function
 
-from pyformex.arraytools import *
+import numpy as np
 
 
 # Some functions to calculate a scalar value from a vector
 # TODO: base these on numpy.linalg.norm or arraytools.norm
 def norm2(A):
-    return sqrt(square(asarray(A)).sum(axis=-1))
+    return np.sqrt(np.square(np.asarray(A)).sum(axis=-1))
+
 
 def norm(A, x):
-    return power(power(asarray(A), x).sum(axis=-1), 1./x)
+    return np.power(np.power(np.asarray(A), x).sum(axis=-1), 1./x)
+
 
 def max(A):
-    return asarray(A).max(axis=-1)
+    return np.asarray(A).max(axis=-1)
+
 
 def min(A):
-    return asarray(A).min(axis=-1)
+    return np.asarray(A).min(axis=-1)
 
 
 def frameScale(nframes=10, cycle='up', shape='linear'):
@@ -66,11 +68,11 @@ def frameScale(nframes=10, cycle='up', shape='linear'):
 
       ``'sine'``: sinusoidal scaling
     """
-    s = arange(nframes+1)
+    s = np.arange(nframes+1)
     if cycle in ['updown', 'revert']:
-        s = concatenate([s, fliplr(s[:-1].reshape((1, -1)))[0]])
+        s = np.concatenate([s, np.fliplr(s[:-1].reshape((1, -1)))[0]])
     if cycle in ['revert']:
-        s = concatenate([s, -fliplr(s[:-1].reshape((1, -1)))[0]])
+        s = np.concatenate([s, -np.fliplr(s[:-1].reshape((1, -1)))[0]])
     return s.astype(float)/nframes
 
 
