@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -24,17 +24,15 @@
 """Postprocessing Menu
 
 """
-from __future__ import absolute_import, division, print_function
 
 from numpy import *
 
 import pyformex as pf
-from pyformex import round
 from pyformex import utils
 from pyformex.gui import menu, QtGui, QtCore, QtWidgets
 
 from collections import OrderedDict
-from pyformex.formex import *
+from pyformex.lazy import *
 from pyformex.gui.colorscale import ColorScale
 from pyformex.opengl.decors import ColorLegend
 from pyformex.gui.draw import *
@@ -219,10 +217,13 @@ def showModel(nodes=True, elems=True):
     lights(False)
     transparent(True)
     clear()
-    print('Elements in model:')
-    for k, v in DB.elems.items():
-        print("%s: %s" % (k, len(v)))
-    M = [Mesh(DB.nodes, el, eltype='quad%d'%el.shape[1], prop=i) for i, el in enumerate(DB.elems.values())]
+    #print(DB.elems)
+    for k in DB.elems:
+        # TODO: WHY HAS THIS LOST THE ELTYPE coming from EeEx calpy????????
+        #print("%s: %s" % (k, len(DB.elems[k])))
+        #print(type(DB.elems[k]))
+        DB.elems[k] = Elems(DB.elems[k], eltype='quad%d'%DB.elems[k].shape[1])
+    M = [Mesh(DB.nodes, DB.elems[k], prop=k) for k in DB.elems]
     if nodes:
         draw([m.coords for m in M], nolight=True)
     if elems:
@@ -258,10 +259,10 @@ def showResults(nodes, elems, displ, text, val, showref=False, dscale=100.,
             warning("The displacements do not match the mesh: the mesh coords have shape %s; but the displacements have shape %s. I will continue without displacements." % (nodes.shape, displ.shape))
             displ = None
 
+    # print(f"Type of elems is {type(elems)}")
     if not isinstance(elems, list):
         elems = [elems]
 
-    print(["ELEMS: %s" % str(el.shape) for el in elems])
     if val is not None:
         print("VAL: %s" % str(val.shape))
 
@@ -414,8 +415,8 @@ def animateScenes(scenes, count=1, sleeptime=None):
 ##             post = fn.with_suffix('.post')
 ##             cmd = "%s/lib/postabq %s > %s" % (pf.cfg['pyformexdir'],fn,post)
 ##             P = utils.command(cmd,shell=True)
-##             if P.sta:
-##                 print(P.out)
+##             if P.returncode:
+##                 print(P.stdout)
 
 
 
@@ -564,7 +565,7 @@ def selectDB(db=None):
     If db is an FeResult instance, it is set as the current database.
     If None is given, a dialog is popped up to select one.
 
-    If a database is succesfully selected, the screen is cleared and the
+    If a database is successfully selected, the screen is cleared and the
     geometry of the model is displayed.
 
     Returns the database or None.
@@ -614,9 +615,10 @@ def importCalculix(fn=None):
         parts = readInpFile(meshfile)
         print(type(parts))
         print(parts.keys())
-        meshes = parts.values()[0]
+        # TODO: this does no longer work in py3
+        meshes = list(parts.values())[0]
         print(type(meshes))
-        #fem = Model(meshes=meshes,fuse=False)
+        #fem = FEModel(meshes=meshes,fuse=False)
         DB = ccxdat.createResultDB(meshes)
         ngp = 8
         ccxdat.readResults(resfile, DB, DB.nnodes, DB.nelems, ngp)
@@ -672,7 +674,7 @@ def importFlavia(fn=None):
 
 
 def importDB(fn=None):
-    """Import a _post.py database and select it as the current."""
+    """Import a .post.py database and select it as the current."""
 
     if fn is None:
         fn = askFilename(pf.cfg['workdir'], 'postproc')
@@ -719,7 +721,8 @@ def dialog_getresults():
     """Return the dialog data with short keys."""
     dialog.acceptData()
     data = dialog.results
-    data['resindex'] = result_types.values().index(data['restype'])
+    # TODO sanitize the use of list
+    data['resindex'] = list(result_types.values()).index(data['restype'])
     return data
 
 
@@ -747,12 +750,12 @@ def show_results(data):
 
     nodes = DB.nodes
     if elgroup == '--ALL--':
-        elems = DB.elems.values()
+        elems = list(DB.elems.values())
+        print("ALL ELEMS")
     else:
         elems = [DB.elems[elgroup]]
 
     dscale = data['dscale']
-    print(DB.step, DB.inc)
     displ = DB.getres('U')
     if displ is not None:
         displ = displ[:, 0:3]
@@ -779,8 +782,7 @@ def show_results(data):
     # Get the scalar element result values from the results.
     val = None
     if resindex > 0:
-        key = result_types.keys()[resindex]
-        print("RESULT KEY = %s" % key)
+        key = list(result_types.keys())[resindex]
         if key == 'Computed':
             if askPoint():
                 val = Coords(nodes).distanceFromPoint(point)
@@ -789,8 +791,7 @@ def show_results(data):
             if key == 'U':
                 val = norm2(val)
     if val is not None:
-        txt += result_types.values()[resindex]
-    #print("RESULT ELTYPE: %s" % [e.eltype.name() for e in elems])
+        txt += list(result_types.values())[resindex]
     showResults(nodes, elems, displ, txt, val, showref, dscale, count, sleeptime, symmetric_scale)
     return val
 
@@ -845,7 +846,7 @@ def open_dialog():
             _I('step', text='Step', choices=DB.getSteps(), onselect=set_inc_choices),
             _I('inc', text='Increment', choices=[1]),
             _I('elgroup', text='Element Group', choices=['--ALL--', ]),
-            _I('restype', text='Type of result', choices=result_types.values()),
+            _I('restype', text='Type of result', choices=list(result_types.values())),
             _I('autoscale', text='Autocalculate deformation scale', value=True),
             _I('dscale', text='Deformation scale', value=100.),
             _I('symmetric_scale', text='Symmetric scale', value=False),
@@ -887,19 +888,19 @@ def open_dialog():
         default='Show',
         )
     # Update the data items from saved values
-    try:
-        newdata = named('PostProcMenu_data')
-    except:
-        newdata = {}
-        pass
-    if selection.check(single=True):
-        newdata['feresult'] = selection.names[0]
-    if DB:
-        newdata['elgroup'] = ['--ALL--', ] + DB.elems.keys()
-    dialog.updateData(newdata)
+    # try:
+    #     newdata = named('PostProcMenu_data')
+    # except Exception:
+    #     newdata = {}
+    #     pass
+    # if selection.check(single=True):
+    #     newdata['feresult'] = selection.names[0]
+    # if DB:
+    #     newdata['elgroup'] = ['--ALL--', ] + list(DB.elems.keys())
+    # dialog.updateData(newdata)
 
-    dialog['step'].setChoices(DB.getSteps())
-    dialog['inc'].setChoices(DB.getIncs(DB.getSteps()[0]))
+    # dialog['step'].setChoices(DB.getSteps())
+    # dialog['inc'].setChoices(DB.getIncs(DB.getSteps()[0]))
     dialog.show()
     #pf.PF['__PostProcMenu_dialog__'] = dialog
 
