@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -137,7 +137,6 @@ Camera settings.
 See also: example SaveLoad
 
 """
-from __future__ import absolute_import, division, print_function
 
 import sys
 import json
@@ -146,6 +145,7 @@ import numpy as np
 
 import pyformex as pf
 from pyformex import utils
+from pyformex.path import Path
 from pyformex.coords import Coords
 from pyformex.geometry import Geometry
 from pyformex.formex import Formex
@@ -182,74 +182,20 @@ def dict2Config(d):
 
 
 def bytes2str(b):
-    """Convert bytes to str in any version"""
-    s = str(b)
-    if pf.PY3:
-        s = s[2:-1]
-    return s
+    """Convert bytes to str"""
+    return str(b)[2:-1]
 
 
-if pf.PY3:
-    # Python3 correctly restores .json to 'str' (since this is unicode).
-    json_loads = json.loads
+def readStr(filename):
+    """Read a string from a saved numpy character
 
-    def readStr(filename):
-        """Read a string from a saved numpy character
-
-        The character array may be of kind 'S' (bytes) or 'U' (unicode)
-        but always returns an object of class str.
-        """
-        a = np.load(filename)
-        if a.dtype.kind == 'S':
-            a = a.astype('U')
-        return str(a)
-
-if pf.PY2:
-    # Under Python2, loading .json results in unicode strings
-    # We need to change these to bytes in order to get back 'str' types.
-    # Got this from stackoverflow.com
-
-    def _byteify(data, ignore_dicts = False):
-        # if this is a unicode string, return its string representation
-        if isinstance(data, unicode):
-            return data.encode('utf-8')
-        # if this is a list of values, return list of byteified values
-        if isinstance(data, list):
-            return [_byteify(item, ignore_dicts=True) for item in data]
-        # if this is a dictionary, return dictionary of byteified keys and values
-        # but only if we haven't already byteified it
-        if isinstance(data, dict) and not ignore_dicts:
-            return {
-                _byteify(key, ignore_dicts=True): _byteify(value, ignore_dicts=True)
-                for key, value in data.iteritems()
-            }
-        # if it's anything else, return it in its original form
-        return data
-
-    def json_load_byteified(file_handle):
-        return _byteify(
-            json.load(file_handle, object_hook=_byteify),
-            ignore_dicts=True
-        )
-
-    def json_loads_byteified(json_text):
-        return _byteify(
-            json.loads(json_text, object_hook=_byteify),
-            ignore_dicts=True
-        )
-
-    json_loads = json_loads_byteified
-
-    def readStr(filename):
-        """Read a string from a saved numpy character
-
-        The character array may be of kind 'S' (bytes) or 'U' (unicode)
-        but always returns an object of type str.
-        """
-        a = np.load(filename)
-        if a.dtype.kind == 'U':
-            a = a.astype('S')
-        return str(a)
+    The character array may be of kind 'S' (bytes) or 'U' (unicode)
+    but always returns an object of class str.
+    """
+    a = np.load(filename)
+    if a.dtype.kind == 'S':
+        a = a.astype('U')
+    return str(a)
 
 
 def Coords_pzf_dict(self):
@@ -409,7 +355,7 @@ def savePZF(filename, **kargs):
 
     Parameters
     ----------
-    filename: str
+    filename: :term:`path_like`
         Name of the file on which to save the objects. It is recommended
         to use an extension '.pzf'.
     kargs: keyword arguments
@@ -431,10 +377,12 @@ def savePZF(filename, **kargs):
     See also example SaveLoad.
 
     """
+    filename = Path(filename)
+    pf.verbose(1, f"Write PZF file {filename.absolute()}")
     save_dict = {}
     for k in kargs:
         if k.endswith('_') or '__' in k or k=='':
-            raise ValueError("Invalid keyword argument '%s' for savePZF" % k)
+            raise ValueError(f"Invalid keyword argument '{k}' for savePZF")
         if k.startswith('_'):
             if k == '_camera':
                 kargs[k] = Config(pf.canvas.camera.settings)
@@ -446,14 +394,15 @@ def savePZF(filename, **kargs):
             d = utils.prefixDict(o.pzf_dict(), '%s__%s__' % (k, clas))
             save_dict.update(d)
         else:
-            print("Object %s of type %s can not (yet) be written to PZF file: skipping." % (k, type(o)))
+            pf.verbose(2, f"Object {k} of type {type(o)} can not (yet) "
+                       f"be written to PZF file: skipping.")
 
     # Do not store camera if we store canvas
     if '_canvas' in kargs and '_camera' in kargs:
         del kargs['_camera']
-    print("Saving %s objects to PZF file %s" % (len(save_dict), filename))
-    print("Contents: %s" % sorted(save_dict.keys()))
-    save_dict['__FORMAT'] = "PZF %s (created by %s)\n" % (_pzf_version, pf.fullVersion())
+    pf.verbose(2, f"Saving {len(save_dict)} objects to PZF file")
+    pf.verbose(2, f"Contents: {sorted(save_dict.keys())}")
+    save_dict['__FORMAT'] = f"PZF {_pzf_version} (created by {pf.fullVersion()})\n"
     with zipfile.ZipFile(filename, 'w') as zip:
         save2zip(zip, save_dict)
 
@@ -488,8 +437,8 @@ def split_PZF_keys(d):
                 if isinstance(d[k], np.ndarray) and d[k].size == 0:
                     d[k] = None
                 od[attr] = d[k]
-                if pf.PY3 and isinstance(od[attr], np.ndarray) and od[attr].dtype.kind == 'S':
-                    # Convert bytes to unicode in Python3
+                if isinstance(od[attr], np.ndarray) and od[attr].dtype.kind == 'S':
+                    # Convert bytes to unicode
                     od[attr] = od[attr].astype('U')
                 #print(type(od[attr]))
 
@@ -524,17 +473,17 @@ def loadFields(obj, pzfd, fields):
 def loadAttrib(obj, attrib):
     """Load attrib dict on the object"""
     attrib = bytes(attrib)
-    d = json_loads(attrib)
+    d = json.loads(attrib)
     pf.debug("attribs for %s object: %s" % (obj.__class__.__name__, d), pf.DEBUG.PGF)
     obj.attrib(**d)
 
 
-def loadPZF(fil):
+def loadPZF(filename):
     """Load pyFormex objects from a file in PGF format.
 
     Parameters
     ----------
-    fil: str
+    filename: :term:`path_like`
         Name of the file from which to load the objects.
         It is normally a file with extension '.pzf'.
 
@@ -575,20 +524,20 @@ def loadPZF(fil):
     See also example SaveLoad.
 
     """
-    print("Reading PZF file %s" % fil)
-    D = np.load(fil)
+    filename = Path(filename)
+    pf.verbose(1, f"Read PZF file {filename.absolute()}")
+    D = np.load(filename)
     d = split_PZF_keys(D)
     for k in d:
         O = None
         dk = d[k]
         clas = dk.pop('class')
-        print("Loading %s '%s'" % (clas, k))
+        pf.verbose(2, f"Loading {clas} '{k}'")
         fields = dk.pop('fields', None)
         attrib = dk.pop('attrib', None)
         if clas == 'Config':
-            if pf.PY3:
-                if isinstance(dk['settings'], bytes):
-                    dk['settings'] = dk['settings'].decode('latin1')
+            if isinstance(dk['settings'], bytes):
+                dk['settings'] = dk['settings'].decode('latin1')
             O = Config()
             O.read(dk['settings'])
         else:
