@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -26,12 +26,11 @@
 
 Surface operations plugin menu for pyFormex.
 """
-from __future__ import absolute_import, division, print_function
 
 from collections import OrderedDict
 
 import pyformex as pf
-from pyformex import zip, simple, timer
+from pyformex import timer
 from pyformex.gui import widgets, menu
 from pyformex.plugins import plot2d, fe_abq
 
@@ -68,7 +67,7 @@ def draw_normals(n, avg=False):
     else:
         try:
             siz = float(siz)
-        except:
+        except Exception:
             siz = 0.05 * C.dsize()
     if avg:
         color = 'orange'
@@ -94,7 +93,8 @@ class SurfaceObjects(DrawableObjects):
         pf.GUI.selection['geometry'].set(names)
 
 
-selection = SurfaceObjects()
+if pf.GUI:
+    selection = SurfaceObjects()
 
 ##################### select, read and write ##########################
 
@@ -345,20 +345,20 @@ def merge():
     selection.draw()
 
 
-def export_surface(types=['surface', 'gts', 'stl', 'off', 'neu', 'smesh', 'vtp', 'vtk']):
+
+def export_surface(types=['surface', 'off', 'gts', 'stl'], compr=True):
+    """Export surface to file format with transparent compression"""
     F = selection.check(single=True)
     if F:
-        if isinstance(types, str):
-            ftype = types
-            types = [types]
-        else:
-            ftype = None
-        fn = askNewFilename(pf.cfg['workdir'], types)
+        fn = askNewFilename(pf.cfg['workdir'], types, compr=compr)
         if fn:
-            ftype = fn.ftype
-            print("Exporting surface model to %s (%s)" % (fn, ftype))
+            print(f"Exporting surface model to {fn}")
             with busyCursor():
-                F.write(fn, ftype)
+                F.write(fn)
+
+def export_surface_alt(types=['neu', 'smesh', 'vtp', 'vtk']):
+    """Export surface to file format that do not support compression yet"""
+    export_surface(types, compr=False)
 
 # TODO: this should be merged with export_surface
 
@@ -447,7 +447,7 @@ def fillBorders():
     S = showBorder()
     try:
         B = named('border')
-    except:
+    except Exception:
         return
     if B:
         props = [b.prop[0] for b in B]
@@ -554,7 +554,7 @@ def showStatistics(key=None, domain=True, dist=False, cumdist=False, clip=None,
             if percentile:
                 try:
                     from scipy.stats.stats import scoreatpercentile
-                except:
+                except Exception:
                     warning("""..
 
 **The **percentile** clipping option is not available.
@@ -618,7 +618,7 @@ def _close_stats_dia():
         try:
             _stat_dia.close()
             # this may fail if fialog closed by window manager
-        except:
+        except Exception:
             pass
         _stat_dia = None
 
@@ -1506,6 +1506,7 @@ def create_menu():
             ("&Export Surface Model", export_surface),
             ("&Export as STL", export_stl),
             ("&Export as WebGL", export_webgl),
+            ("&Export Alternate Formats", export_surface_alt),
         ]),
         ("---", None),
         ("&Create surface", [
@@ -1628,8 +1629,8 @@ def reload_menu():
 ####################################################################
 ######### What to do when the script is executed ###################
 
-if __name__ == '__draw__':
+# if __name__ == '__draw__':
 
-    reload_menu()
+#     reload_menu()
 
 # End
