@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -29,17 +29,15 @@ tetgen program
 tetgen is a quality tetrahedral mesh generator and a 3D Delaunay triangulator.
 See http://tetgen.org
 """
-from __future__ import absolute_import, division, print_function
 
-from pyformex import software
-software.requireExternal('tetgen')
+from pyformex import utils
+utils.External.require('tetgen')
 
 from pyformex import Path
-from pyformex.coords import *
+from pyformex.lazy import *
 from pyformex.connectivity import Connectivity
 from pyformex.mesh import Mesh
 from pyformex.filewrite import *
-from pyformex import utils
 
 
 def readNodeFile(fn):
@@ -341,7 +339,7 @@ def writeNodes(fn, coords, offset=0):
     coords = asarray(coords).reshape((-1, 3))
     with open(fn, 'w') as fil:
         fil.write("%d %d 0 0\n" % coords.shape)
-        writeIData(coords, fil, "%f ", ind=offset)
+        writeIData(fil, coords, fmt="%f ", ind=offset)
 
 
 def writeSmesh(fn, facets, coords=None, holes=None, regions=None):
@@ -421,7 +419,7 @@ def runTetgen(fn, options=''):
     tetgen will generate a volume tetraeder mesh inside the surface,
     and create a new approximation of the surface as a by-product.
     """
-    if not utils.hasExternal('tetgen'):
+    if not utils.External.has('tetgen'):
         pf.warning("""..
 
 I could not find the 'tetgen' command.
@@ -432,7 +430,7 @@ tetgen is a quality tetrahedral mesh generator and a 3D Delaunay triangulator. S
 
     if Path(fn).exists():
         P = utils.command('tetgen -z%s %s' % (options, fn))
-        return P.sta
+        return P.returncode
 
 
 def readTetgen(fn):
@@ -523,8 +521,8 @@ def tetgenConvexHull(pts):
         fn = tmpdir / 'convexhull.node'
         writeNodes(fn, coords=pts, offset=0)
         P = utils.command('tetgen %s' % fn)
-        if P.sta:
-            print(P.out)
+        if P.returncode:
+            print(P.stdout)
             raise RuntimeError("Error occurred in tetgen command")
         tetmesh = readTetgen(fn.with_suffix('.1.ele'))['tetgen.ele']
         convexhull = TriSurface(tetmesh.getBorderMesh())
@@ -545,8 +543,8 @@ def checkSelfIntersectionsWithTetgen(self, verbose=False):
         options = '-V' if verbose else ''
         cmd = "tetgen -d %s %s" % (options, fn)
         P = utils.command(cmd)
-        print(P.out)
-        return asarray([int(l.split(' ')[0]) for l in P.out.split('acet #')[1:]]).reshape(-1, 2)-1
+        print(P.stdout)
+        return asarray([int(l.split(' ')[0]) for l in P.stdout.split('acet #')[1:]]).reshape(-1, 2)-1
 
 
 def tetMesh(surfacefile, quality=2.0, volume=None, outputdir=None):
@@ -576,7 +574,7 @@ def tetMesh(surfacefile, quality=2.0, volume=None, outputdir=None):
     -------
     Mesh
         A tetrahedral Mesh (eltype='tet4') filling the input surface,
-        provided the tetgen program finished succesfully.
+        provided the tetgen program finished successfully.
     """
     options = ''
     if quality is True:
