@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -26,14 +26,13 @@
 
 Graphic Tools plugin menu for pyFormex.
 """
-from __future__ import absolute_import, division, print_function
 
 import pyformex as pf
 from pyformex import utils
 from pyformex.gui import menu
 from pyformex.plugins import objects
 
-from pyformex.formex import *
+from pyformex.lazy import *
 from pyformex.gui.draw import *
 from pyformex.plugins.tools import *
 from pyformex.trisurface import TriSurface
@@ -715,7 +714,7 @@ def projectOnSurface2(p, **args):
     that returns empty list instead of error"""
     try:
         return p.projectOnSurface(**args)
-    except:
+    except Exception:
         return []
 
 
@@ -783,7 +782,7 @@ def create_points(color=0, obj=None):
     for o in obj:
         try:
             S.append(o.toSurface())
-        except:
+        except Exception:
             pass
     if len(S)==0:
         warning('there are no objects on the screen')
