@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -28,7 +28,6 @@ web. It is currently highly biased to downloading 3D models from archive3d.net,
 unzipping the files, and displaying the .3ds models included.
 
 """
-from __future__ import absolute_import, division, print_function
 
 import pyformex as pf
 from pyformex import utils
@@ -36,24 +35,13 @@ from pyformex import Path
 from pyformex.gui.draw import busyCursor
 
 
-if pf.PY2:
-    def download(url, tgt):
-        """Download a file with a known url to tgt.
+def download(url, tgt):
+    """Download a file with a known url to tgt.
 
-        """
-        import urllib
-        urllib.urlretrieve(url, tgt)
-        fn = Path(tgt).resolve()
-        print("File downloaded to %s" % fn)
-
-if pf.PY3:
-    def download(url, tgt):
-        """Download a file with a known url to tgt.
-
-        """
-        import requests
-        with open(tgt, 'wb') as f:
-            f.write(requests.get(url).content)
+    """
+    import requests
+    with open(tgt, 'wb') as f:
+        f.write(requests.get(url).content)
 
 
 def find3ds(fn):
