@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -26,20 +26,19 @@
 
 Functions for managing a project in pyFormex.
 """
-from __future__ import absolute_import, division, print_function
 
 import sys
 import gzip
+import pickle
 
 import pyformex as pf
 from pyformex import Path
-from pyformex import pickle
 from pyformex import utils
 
 from pyformex.track import TrackedDict
 
 _signature_ = pf.fullVersion()
-
+default_protocol = pickle.DEFAULT_PROTOCOL
 
 module_relocations = {
     'plugins.mesh': 'pyformex.mesh',
@@ -53,8 +52,6 @@ module_relocations = {
 class_relocations = {
     'coords.Coords': 'pyformex.coords.Coords',
     'coords.BoundVectors': 'pyformex.plugins.alt.BoundVectors',
-    'coords.CoordinateSystem': 'pyformex.coordsys.CoordinateSystem',
-    'coordsys.CoordinateSystem': 'pyformex.coordsys.CoordinateSystem',
     'elements.Element': 'pyformex.elements.ElementType',
     'elements.Line2': 'pyformex.elements.Line2',
     'elements.Tri3': 'pyformex.elements.Tri3',
@@ -66,55 +63,42 @@ class_relocations = {
 
 def find_class(module, name):
     """Find a class whose name or module has changed"""
-    pf.debug("I want to import %s from %s" % (name, module), pf.DEBUG.PROJECT)
-    clas = '%s.%s' % (module, name)
-    pf.debug("Object is %s" % clas, pf.DEBUG.PROJECT)
+    pf.debug(f"I want to import {name} from {module}", pf.DEBUG.PROJECT)
+    clas = f"{module}.{name}"
+    pf.debug(f"Object is {clas}", pf.DEBUG.PROJECT)
     if clas in class_relocations:
         module = class_relocations[clas]
         lastdot = module.rfind('.')
         module, name = module[:lastdot], module[lastdot+1:]
-        pf.debug("  I will try %s from module %s instead" % (name, module), pf.DEBUG.PROJECT)
+        pf.debug(f"  I will try {name} from module {module} instead",
+                 pf.DEBUG.PROJECT)
     elif module in module_relocations:
         module = module_relocations[module]
-        pf.debug("  I will try module %s instead" % module, pf.DEBUG.PROJECT)
+        pf.debug(f"  I will try module {module} instead", pf.DEBUG.PROJECT)
     __import__(module)
     mod = sys.modules[module]
     clas = getattr(mod, name)
-    pf.debug("Success: Got %s" % clas.__class__.__name__, pf.DEBUG.PROJECT)
+    pf.debug(f"Success: Got {clas.__class__.__name__}", pf.DEBUG.PROJECT)
     return clas
 
 
-if pf.PY3:
-    default_protocol = pickle.DEFAULT_PROTOCOL
-    class Unpickler(pickle.Unpickler):
-        """Customized Unpickler class"""
+class Unpickler(pickle.Unpickler):
+    """Customized Unpickler class"""
 
-        def __init__(self, f, try_resolve=True):
-            """Initialize the Unpickler"""
-            pickle.Unpickler.__init__(self, f, encoding='latin1')
-            self.try_resolve = try_resolve
-            if not try_resolve:
-                pf.debug("NOT TRYING TO RESOLVE RELOCATIONS: YOU MAY GET INTO TROUBLE", pf.DEBUG.PROJECT)
-
-        def find_class(self, module, name):
-            pf.debug("FIND MODULE %s NAME %s" % (module, name), pf.DEBUG.PROJECT)
-            clas = pickle.Unpickler.find_class(self, module, name)
-            if not clas:
-                clas = find_class(module, name)
-            return clas
-
-
-if pf.PY2 and not pf.sphinx:
-    default_protocol = pickle.HIGHEST_PROTOCOL
-    def Unpickler(f, try_resolve=True):
-        """Create an Unpickler object"""
-        unpickler = pickle.Unpickler(f)
-        if try_resolve:
-            unpickler.find_global = find_class
-        else:
-            pf.debug("NOT TRYING TO RESOLVE RELOCATIONS: YOU MAY GET INTO TROUBLE", pf.DEBUG.PROJECT)
-        return unpickler
+    def __init__(self, f, try_resolve=True):
+        """Initialize the Unpickler"""
+        pickle.Unpickler.__init__(self, f, encoding='latin1')
+        self.try_resolve = try_resolve
+        if not try_resolve:
+            pf.debug("NOT TRYING TO RESOLVE RELOCATIONS: "
+                     "YOU MAY GET INTO TROUBLE", pf.DEBUG.PROJECT)
 
+    def find_class(self, module, name):
+        pf.debug(f"FIND MODULE {module} NAME {name}", pf.DEBUG.PROJECT)
+        clas = pickle.Unpickler.find_class(self, module, name)
+        if not clas:
+            clas = find_class(module, name)
+        return clas
 
 
 class Project(TrackedDict):
@@ -220,7 +204,7 @@ class Project(TrackedDict):
       >>> P.update(d)
       >>> print(P) # doctest: +ELLIPSIS
       Project name: None
-        access: wr    mode: b     gzip:5
+        access: wr    mode: b     gzip: 5
         signature: pyFormex ...
         contents: ['a', 'b', 'c', 'd', 'e']
       <BLANKLINE>
@@ -243,7 +227,9 @@ class Project(TrackedDict):
     latest_format = 3
 
 
-    def __init__(self, filename=None, access='wr', convert=True, signature=_signature_, compression=5, binary=True, data={}, protocol=default_protocol, **kargs):
+    def __init__(self, filename=None, access='wr', convert=True,
+                 signature=_signature_, compression=5, binary=True,
+                 data={}, protocol=default_protocol, **kargs):
         """Create a new project."""
         if 'create' in kargs:
             utils.warn("warn_project_create")
@@ -255,13 +241,12 @@ class Project(TrackedDict):
         self.signature = str(signature)
         self.gzip = compression if compression in range(1, 10) else 0
         self.mode = 'b' if binary or compression > 0 else ''
-        #print("DEBUG PROJECT: access %s gzip %s mode %s" % (self.access,self.gzip, self.mode))
         if protocol is None:
             protocol = default_protocol
         self.protocol = min(protocol, pickle.HIGHEST_PROTOCOL) \
             if self.mode == 'b' else 0
 
-        TrackedDict.__init__(self)
+        super().__init__()
         if self.filename and self.filename.exists() and 'r' in self.access:
             # read existing contents
             self.load(try_resolve=convert)
@@ -271,18 +256,16 @@ class Project(TrackedDict):
         if self.filename and self.access=='w':
             # destroy existing contents
             self.filename.truncate()
-        pf.debug("INITIAL hits = %s" % self.hits, pf.DEBUG.PROJECT)
+        pf.debug(f"Initial hits = {self.hits}", pf.DEBUG.PROJECT)
 
 
     def __str__(self):
-        s = """Project name: %s
-  access: %s    mode: %s     gzip:%s
-  signature: %s
-  contents: %s
-""" % (self.filename, self.access, self.mode, self.gzip, self.signature,
-        self.contents())
-        return s
-
+        return f"""\
+Project name: {self.filename}
+  access: {self.access}    mode: {self.mode}     gzip: {self.gzip}
+  signature: {self.signature}
+  contents: {self.contents()}
+"""
 
     def contents(self):
         return sorted(self.keys())
@@ -292,7 +275,8 @@ class Project(TrackedDict):
         """Construct the data to be saved in the header."""
         store_attr = ['signature', 'gzip', 'mode', 'autofile', '_autoscript_']
         store_vals = [getattr(self, k, None) for k in store_attr]
-        return dict([(k, v) for k, v in zip(store_attr, store_vals) if v is not None])
+        return dict([(k, v) for k, v in zip(store_attr, store_vals)
+                     if v is not None])
 
 
     def save(self, filename=None, quiet=False):
@@ -303,22 +287,24 @@ class Project(TrackedDict):
             raise ValueError(
                 "No filename specified for the Project: can not save it")
         if 'w' not in self.access:
-            pf.debug("Not saving because Project file opened readonly", pf.DEBUG.PROJECT)
+            pf.debug("Not saving because Project file opened readonly",
+                     pf.DEBUG.PROJECT)
             return
 
         if not quiet:
-            print("Project variables changed: %s" % self.hits)
-            print("Saving project %s with protocol %s, mode %s and compression %s" % (self.filename, self.protocol, self.mode, self.gzip))
+            print(f"Project variables changed: {self.hits}")
+            print(
+                f"Saving project {self.filename} with protocol {self.protocol}, "
+                f"mode {self.mode} and compression {self.gzip}")
 
         with self.filename.open('w'+self.mode) as f:
             # write header
-            header = "%s\n" % self.header_data()
-            if pf.PY3:
-                header = header.encode('utf-8')
+            header = f"{self.header_data()}\n".encode('utf-8')
             f.write(header)
             f.flush()
             if self.gzip:
-                pyf = gzip.GzipFile(mode='w'+self.mode, compresslevel=self.gzip, fileobj=f)
+                pyf = gzip.GzipFile(mode='w'+self.mode,
+                                    compresslevel=self.gzip, fileobj=f)
                 pickle.dump(self, pyf, self.protocol)
                 pyf.close()
             else:
@@ -331,31 +317,31 @@ class Project(TrackedDict):
 
         f is the file opened for reading.
         Tries to read the header from different legacy formats,
-        and if succesfull, adjusts the project attributes according
+        and if successful, adjusts the project attributes according
         to the values in the header.
-        Returns the open file if succesfull.
+        Returns the open file if successful.
         """
         self.format = -1
         fpos = f.tell()
         s = f.readline()
-        pf.debug("Project Header: %s" % s, pf.DEBUG.PROJECT)
+        pf.debug(f"Project Header: {s}", pf.DEBUG.PROJECT)
         # Try subsequent formats
         try:
             # newest format has header in text format
             header = eval(s)
             self.__dict__.update(header)
             self.format = 3
-        except:
+        except Exception:
 
             # try OLD new format: the first pickle contains attributes
             try:
-                p = pickle_load(f)
+                p = pickle.load(f)
                 self.__dict__.update(p)
                 self.format = 2
-            except:
+            except Exception:
                 s = s.strip()
                 if not quiet:
-                    print("Header = '%s'" % s)
+                    print(f"Header = '{s}'")
                 if s=='gzip' or s=='' or 'pyFormex' in s:
                     # transitional format
                     self.gzip = 5
@@ -382,12 +368,12 @@ class Project(TrackedDict):
             raise ValueError(
                 "No filename specified for the Project: can not load")
         if not quiet:
-            print("Reading project file: %s" % self.filename)
+            print(f"Reading project file: {self.filename}")
         with self.filename.open('rb') as f:
             f = self.readHeader(f, quiet)
             if self.format < Project.latest_format:
                 if not quiet:
-                    print("Format looks like %s" % self.format)
+                    print(f"Format looks like {self.format}")
                 utils.warn('warn_old_project')
             pos = f.tell()
             if self.gzip > 0:
@@ -407,7 +393,7 @@ class Project(TrackedDict):
     def convert(self, filename=None):
         """Convert an old format project file.
 
-        The project file is read, and if successfull, is immediately
+        The project file is read, and if successful, is immediately
         saved. By default, this will overwrite the original file.
         If a filename is specified, the converted data are saved to
         that file.
@@ -415,25 +401,25 @@ class Project(TrackedDict):
         be read back immediately.
         """
         self.load(try_resolve=True)
-        print("GOT KEYS %s" % list(self.keys()))
+        print(f"GOT KEYS {list(self.keys())}")
         if filename is not None:
             self.filename = Path(filename)
         self.access = 'w'
-        print("Will now save to %s" % self.filename)
+        print(f"Will now save to {self.filename}")
         self.save()
 
 
-    def uncompress(self, verbose=True):
+    def uncompress(self, verbose=True):  # noqa: C901
         """Uncompress a compressed project file.
 
-        The project file is read, and if successfull, is written
+        The project file is read, and if successful, is written
         back in uncompressed format. This allows to make conversions
         of the data inside.
         """
         if self.filename is None:
             return
         if verbose:
-            print("Uncompressing project file: %s" % self.filename)
+            print(f"Uncompressing project file: {self.filename}")
         with self.filename.open('rb') as f:
             f = self.readHeader(f)
             if verbose:
@@ -441,7 +427,7 @@ class Project(TrackedDict):
             if self.gzip:
                 try:
                     pyf = gzip.GzipFile(self.filename, 'r', self.gzip, f)
-                except:
+                except Exception:
                     self.gzip = 0
 
             if self.gzip:
@@ -449,7 +435,7 @@ class Project(TrackedDict):
                 fu = open(fn, 'w'+self.mode)
                 h = self.header_data()
                 h['gzip'] = 0
-                fu.write("%s\n" % h)
+                fu.write(f"{h}\n")
                 while True:
                     x = pyf.read()
                     if x:
@@ -458,7 +444,7 @@ class Project(TrackedDict):
                         break
                 fu.close()
                 if verbose:
-                    print("Uncompressed %s to %s" % (self.filename, fn))
+                    print(f"Uncompressed {self.filename} to {fn}")
 
             else:
                 utils.warn("warn_project_compression")
