@@ -1,11 +1,11 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -23,12 +23,12 @@
 ##
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Thu Jun 21 13:57:46 CEST 2018)
+##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -53,9 +53,12 @@ Any copyright claims made by my employer should therefore be considered void.
 
 Distributed under the GNU General Public License, version 3 or later
 """
-from __future__ import absolute_import, division, print_function
 
-import os, socket, getpass
+import os
+import sys
+import smtplib
+import socket
+import getpass
 
 ################### global data ##################################
 
@@ -65,23 +68,15 @@ mail = os.environ.get('MAIL', "%s@%s" % (user, host))
 
 ################### mail access ##################################
 
-import sys
-import smtplib
 
 if sys.hexversion < 0x03000000:
     # Python 2.x
     from email.Message import Message as EmailMessage
+    userInput = raw_input  # noqa: F821   does not exist in Python3
 else:
     # Python 3.x
     from email.message import EmailMessage
-
-
-def userInput(*args, **kargs):
-    """Input wrapper to deal with different Python versions"""
-    if sys.hexversion < 0x03000000:
-        return raw_input(*args, **kargs)
-    else:
-        return input(*args, **kargs)
+    userInput = input
 
 
 def message(sender='', to='', cc='', subject='', text=''):
