@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -28,15 +28,13 @@ Formex structures representing simple geometric shapes.
 You need to import this module in your scripts to have access to its
 contents.
 """
-from __future__ import absolute_import, division, print_function
 
 import numpy as np
 
-from pyformex import utils, zip, round
-from pyformex.formex import Formex, connect
+from pyformex import utils
 from pyformex import arraytools as at
-
-from pyformex.formex import *
+from pyformex.coords import Coords
+from pyformex.formex import Formex, connect
 
 # A collection of Formex string input patterns to construct some simple
 # geometrical shapes
@@ -59,7 +57,7 @@ def shape(name):
     """Return a Formex with one of the predefined named shapes.
 
     This is a convenience function returning a plex-2 Formex constructed
-    from one of the patterns defined in the simple.Pattern dictionary.
+    from one of the patterns defined in the Pattern dictionary.
     Currently, the following pattern names are defined:
     'line', 'angle', 'square', 'plus', 'cross', 'diamond', 'rtriangle', 'cube',
     'star', 'star3d'.
@@ -68,10 +66,23 @@ def shape(name):
     return Formex(Pattern[name])
 
 
-
 def randomPoints(n, bbox=[[0., 0., 0.], [1., 1., 1.]]):
-    """Create n random points in a specified bbox."""
-    bbox = array(bbox)
+    """Create n random points in a specified bbox.
+
+    Examples
+    --------
+    >>> X = randomPoints(10)
+    >>> X.shape
+    (10, 3)
+    >>> np.asarray(X >= 0.).all(), np.asarray(X <= 1.).all()
+    (True, True)
+    >>> X = randomPoints(15, bbox=[[1.,1.,1.],[2.,2.,2.]])
+    >>> X.shape
+    (15, 3)
+    >>> np.asarray(X >= 1.).all(), np.asarray(X <= 2.).all()
+    (True, True)
+    """
+    bbox = at.checkArray(bbox,(2,3),'f')
     return Coords(at.randomNoise((n, 3))).scale(bbox[1]-bbox[0]).trl(bbox[0])
 
 
@@ -200,10 +211,12 @@ def rectangle(nx=1, ny=1, b=None, h=None, bias=0., diag=None):
     The default b/h values are equal to nx/ny, resulting in a modular grid.
     The rectangle lies in the (x,y) plane, with one corner at [0,0,0].
     By default, the elements are quads. By setting diag='u','d' of 'x',
-    diagonals are added in /, resp. \ and both directions, to form triangles.
+    diagonals are added in /, resp. \\ and both directions, to form triangles.
     """
     if diag == 'x':
-        base = Formex([[[0.0, 0.0, 0.0], [1.0, -1.0, 0.0], [1.0, 1.0, 0.0]]]).rosette(4, 90.).translate([-1.0, -1.0, 0.0]).scale(0.5)
+        base = Formex(
+            [[[0.0, 0.0, 0.0], [1.0, -1.0, 0.0], [1.0, 1.0, 0.0]]]
+        ).rosette(4, 90.).translate([-1.0, -1.0, 0.0]).scale(0.5)
     else:
         base = Formex({'u': '3:012934', 'd': '3:016823'}.get(diag, '4:0123'))
     if b is None:
@@ -230,7 +243,8 @@ def Cube():
     return TriSurface(faces)
 
 
-def circle(a1=2., a2=0., a3=360., r=None, n=None, c=None, eltype='line2'):
+def circle(a1=2., a2=0., a3=360., r=None, n=None, c=None, eltype='line2',
+           angle_spec=at.DEG):
     """A polygonal approximation of a circle or arc.
 
     All points generated by this function lie on a circle with unit radius at
@@ -261,19 +275,65 @@ def circle(a1=2., a2=0., a3=360., r=None, n=None, c=None, eltype='line2'):
     - `r`: the radius of the circle
     - `n`: the normal on the plane of the circle
     - `c`: the center of the circle
+
+    Examples
+    --------
+    >>> circle(90., 90.).coords
+    Coords([[[ 1.,  0.,  0.],
+             [ 0.,  1.,  0.]],
+    <BLANKLINE>
+            [[ 0.,  1.,  0.],
+             [-1.,  0.,  0.]],
+    <BLANKLINE>
+            [[-1.,  0.,  0.],
+             [-0., -1.,  0.]],
+    <BLANKLINE>
+            [[-0., -1.,  0.],
+             [ 1., -0.,  0.]]])
+    >>> circle(90., 45.).coords
+    Coords([[[ 1.  ,  0.  ,  0.  ],
+             [ 0.  ,  1.  ,  0.  ]],
+    <BLANKLINE>
+            [[ 0.71,  0.71,  0.  ],
+             [-0.71,  0.71,  0.  ]],
+    <BLANKLINE>
+            [[ 0.  ,  1.  ,  0.  ],
+             [-1.  ,  0.  ,  0.  ]],
+    <BLANKLINE>
+            [[-0.71,  0.71,  0.  ],
+             [-0.71, -0.71,  0.  ]],
+    <BLANKLINE>
+            [[-1.  ,  0.  ,  0.  ],
+             [-0.  , -1.  ,  0.  ]],
+    <BLANKLINE>
+            [[-0.71, -0.71,  0.  ],
+             [ 0.71, -0.71,  0.  ]],
+    <BLANKLINE>
+            [[-0.  , -1.  ,  0.  ],
+             [ 1.  , -0.  ,  0.  ]],
+    <BLANKLINE>
+            [[ 0.71, -0.71,  0.  ],
+             [ 0.71,  0.71,  0.  ]]])
     """
-    if a2 == 0.0:
-        a2 = a1
-    ns = round(a3/a2)
-    a1 *= pi/180.
+    a1 = a1 * angle_spec
+    a2 = a1 if a2 == 0.0 else a2 * angle_spec
+    a3 = a3 * angle_spec
+    ns = int(round(a3/a2))
     if eltype=='line2':
-        F = Formex([[[1., 0., 0.], [cos(a1), sin(a1), 0.]]]).rosette(ns, a2, axis=2, around=[0., 0., 0.])
+        F = Formex(
+            [[[1., 0., 0.],
+              [np.cos(a1), np.sin(a1), 0.]]]
+        ).rosette(ns, a2, axis=2, around=[0., 0., 0.], angle_spec=at.RAD)
     elif eltype=='line3':
-        F = Formex([[[1., 0., 0.], [cos(a1/2.), sin(a1/2.), 0.], [cos(a1), sin(a1), 0.]]], eltype=eltype).rosette(ns, a2, axis=2, around=[0., 0., 0.])
+        F = Formex(
+            [[[1., 0., 0.],
+              [np.cos(a1/2.), np.sin(a1/2.), 0.],
+              [np.cos(a1), np.sin(a1), 0.]]], eltype=eltype
+        ).rosette(ns, a2, axis=2, around=[0., 0., 0.], angle_spec=at.RAD)
     if r is not None:
         F = F.scale(r)
     if n is not None:
-        F = F.rotate(rotMatrix2([0., 0., 1.], n))
+        F = F.rotate(at.rotMatrix2([0., 0., 1.], n))
     if c is not None:
         F = F.trl(c)
     return F
@@ -308,7 +368,7 @@ def triangle():
     The first point is the origin, the second points is on the axis 0.
     The return value is a plex-3 Formex.
     """
-    return Formex([[[0., 0., 0.], [1., 0., 0.], [0.5, 0.5 * sqrt(3.), 0.]]])
+    return Formex([[[0., 0., 0.], [1., 0., 0.], [0.5, 0.5 * np.sqrt(3.), 0.]]])
 
 
 def quadraticCurve(x=None, n=8):
@@ -320,13 +380,12 @@ def quadraticCurve(x=None, n=8):
     the points x. Each of the intervals [x0,x1] and [x1,x2] will be divided
     in n segments.
     """
-    #if x.shape != (3,3):
-    #    raise ValueError("Expected a (3,3) shaped array."
+    x = at.checkArray(x, (3, 3), kind='f')
     # Interpolation functions in normalized coordinates (-1..1)
     h = [lambda x: x*(x-1)/2, lambda x: (1+x)*(1-x), lambda x: x*(1+x)/2]
-    t = arange(-n, n+1) / float(n)
-    H = column_stack([hi(t) for hi in h])
-    return dot(H, x)
+    t = np.arange(-n, n+1) / float(n)
+    H = np.column_stack([hi(t) for hi in h])
+    return np.dot(H, x)
 
 
 def sphere(ndiv=6, base='icosa', equiv='max'):
@@ -440,7 +499,8 @@ def sector(r, t, nr, nt, h=0., diag=None):
     """
     r = float(r)
     t = float(t)
-    p = Formex(regularGrid([0., 0., 0.], [r, 0., 0.], [nr, 0, 0], swapaxes=True).reshape(-1, 3))
+    p = Formex(regularGrid([0., 0., 0.], [r, 0., 0.], [nr, 0, 0],
+                           swapaxes=True).reshape(-1, 3))
     if h != 0.:
         p = p.shear(2, 0, h / r)
     q = p.rotate(t / nt)
