@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.7  (Mon Jun 17 12:20:39 CEST 2019)
+##  This file is part of pyFormex 2.0  (Mon Sep 14 12:29:05 CEST 2020)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2019 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2020 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -68,10 +68,9 @@ Not sorting the entries in the Varray provides a further gain.
 The Varray class defined below therefore does not sort the rows
 by default, but provides methods to sort them when needed.
 """
-from __future__ import absolute_import, division, print_function
 
 import numpy as np
-import pyformex as pf
+
 from pyformex import arraytools as at
 
 
@@ -162,7 +161,7 @@ class Varray(object):
     >>> Vb = Varray(np.array([[-1,-1,0],[-1,1,2],[0,2,4],[-1,0,2]]))
     >>> print(str(Vb) == str(Va))
     True
-    >>> Vc = Varray([0,1,2,0,2,4,0,2],at.cumsum([0,1,2,3,2]))
+    >>> Vc = Varray([0,1,2,0,2,4,0,2], at.cumsum0([1,2,3,2]))
     >>> print(str(Vc) == str(Va))
     True
     >>> Vd = Varray([1,0, 2,1,2, 3,0,2,4, 2,0,2])
@@ -264,16 +263,16 @@ class Varray(object):
         try:
             data = at.checkArray(data, kind='i', ndim=2)
             data = [row[row >= 0] for row in data]
-        except:
+        except Exception:
             pass
 
         # If data is a list of lists, concatenate and create index
         try:
             # construct row length array
             rowlen = [len(row) for row in data]
-            ind = at.cumsum([0] + rowlen)
+            ind = at.cumsum0(rowlen)
             data = np.concatenate(data).astype(at.Int)
-        except:
+        except Exception:
             pass
 
         # data should now be 1D array
@@ -289,7 +288,7 @@ class Varray(object):
                     rowlen.append(data[i])
                     i += data[i] + 1
                 # create indices and remove row lengths from data
-                ind = at.cumsum([0] + rowlen)
+                ind = at.cumsum0(rowlen)
                 data = np.delete(data, ind[:-1] + np.arange(len(rowlen)))
 
             ind = at.checkArray(ind, kind='i', ndim=1)
@@ -298,7 +297,7 @@ class Varray(object):
                 raise ValueError
             if ind[-1] != len(data):
                 ind = np.concatenate([ind, [len(data)]])
-        except:
+        except Exception:
             raise ValueError("Invalid input data for Varray")
 
         # Store the data
@@ -321,8 +320,14 @@ class Varray(object):
         self._row = 0
 
 
+    def copy(self):
+        """Return a deep copy of the Varray"""
+        return Varray(self.data.copy(), self.ind.copy())
+
+
     # Attributes computed ad hoc, because cheap(er)
 
+
     @property
     def lengths(self):
         """Return the length of all rows of the Varray"""
@@ -347,7 +352,6 @@ class Varray(object):
         return (self.nrows, self.width)
 
 
-    ## Do we need this? Yes, if we do not store lengths
     def length(self, i):
         """Return the length of row i"""
         return self.ind[i + 1] - self.ind[i]
@@ -486,10 +490,6 @@ class Varray(object):
         self._row += 1
         return row
 
-    if pf.PY2:
-        # In Python2 the next method is used instead of __next__
-        next = __next__
-
 
     def index(self, sel):
         """Convert a selector to an index.
@@ -520,7 +520,7 @@ class Varray(object):
         try:
             sel = at.checkArray(sel, shape=(self.size,), kind='b')
             sel = np.where(sel)[0]
-        except:
+        except ValueError:
             sel = at.checkArray(sel, kind='i')
         return sel
 
@@ -586,7 +586,7 @@ class Varray(object):
 
         Parameters
         ----------
-        ind: int or int :term:
+        ind: int or int :term:`array_like`
             Index in the flat data of the element(s) to remove.
 
         Returns
@@ -610,8 +610,6 @@ class Varray(object):
         return Varray(data, ind)
 
 
-
-
     def sort(self):
         """Sort the Varray inplace.
 
@@ -620,8 +618,21 @@ class Varray(object):
 
         See also :meth:`sorted` for sorting the rows without
         changing the original.
+
+        Examples
+        --------
+        >>> va = Varray([[0],[2,1],[4,0,2],[0,2]])
+        >>> va.sort()
+        >>> print(va)
+        Varray (4,3)
+          [0]
+          [1 2]
+          [0 2 4]
+          [0 2]
+        <BLANKLINE>
         """
-        (row.sort() for row in self)
+        for row in self:
+            row.sort()
 
 
     def toArray(self):
@@ -669,7 +680,7 @@ class Varray(object):
         return [r.tolist() for r in self]
 
 
-    def inverse(self, expand=False):
+    def inverse(self, sort=True, expand=False):
         """Return the inverse of a Varray.
 
         The inverse of a Varray is again a Varray. Values k on a row i will
@@ -680,8 +691,24 @@ class Varray(object):
         equal if they have the same number of rows and all rows contain the
         same numbers, independent of their order.
 
-        Example:
+        Parameters
+        ----------
+        sort: bool
+            If True (default), the values on each row of the returned index
+            are sorted.
+            The default (False) will leave the values in the order obtained
+            by the algorithm, which depends on Python/numpy sorting, and
+            usually turns out to be sorted as well.
 
+        Returns
+        -------
+        :class:`Varray`
+        The inverse index, as a Varray (default).
+        Each row ``i`` of the inverse contains the numbers of the rows of the
+        input in which a value ``i`` appeared. The rows are sorted by default.
+
+        Examples
+        --------
         >>> a = Varray([[0,1],[2,0],[1,2],[4]])
         >>> b = a.inverse()
         >>> c = b.inverse()
@@ -703,8 +730,39 @@ class Varray(object):
           [1 2]
           [4]
         <BLANKLINE>
+        >>> a = Varray([[-1,0,1],[0,2,-1],[2,1,1],[3,-2,0]])
+        >>> print(a.inverse())
+        Varray (4,3)
+          [0 1 3]
+          [0 2 2]
+          [1 2]
+          [3]
+        <BLANKLINE>
         """
-        return inverseIndex(self, expand=expand)
+        nrows, ncols = self.shape
+        if nrows <= 0:
+            # allow inverse of empty Varray
+            va = Varray()
+        else:
+            # Create a row index for each value of the data
+            row = np.arange(nrows).repeat(self.lengths)
+            s = self.data.argsort()
+            t = self.data[s]
+            u = row[s]
+            # Now search for the start of every row number
+            v = t.searchsorted(np.arange(t.max() + 1))
+            if v[0] > 0:
+                # There were negative numbers: remove them
+                u = u[v[0]:]
+                v -= v[0]
+            va = Varray(u, v)
+            if sort:
+                # TODO: this could be avoided by using a stable
+                # sort algorithm above
+                va.sort()
+        if expand:
+            va = va.toArray()
+        return va
 
 
     def __repr__(self):
@@ -720,53 +778,4 @@ class Varray(object):
         return s
 
 
-def inverseIndex(ind, sort=False, expand=False):
-    """Create the inverse of a 2D index array.
-
-    Parameters:
-
-    - `ind`: a Varray or a 2D index array. A 2D index array is a 2D integer
-      array where only nonnegative values are significant and negative
-      values are silently ignored.
-      While in most cases all values in a row are unique, this is not a
-      requirement. Degenerate elements may have the same node number
-      appearing multiple times in the same row.
-    - `sort`: bool. If True, rows are sorted.
-    - `expand`: bool. If True, an :class:`numpy.ndarray` is returned.
-
-    Returns the inverse index, as a Varray (default) or as an ndarray (if
-    expand is True). If sort is True, rows are sorted.
-
-    Example:
-
-      >>> a = inverseIndex([[0,1],[0,2],[1,2],[0,3]])
-      >>> print(a)
-      Varray (4,3)
-        [0 1 3]
-        [0 2]
-        [1 2]
-        [3]
-      <BLANKLINE>
-    """
-    if isinstance(ind, Varray):
-        ind = ind.toArray()
-    ind = at.checkArray(ind, ndim=2, kind='i')
-    b = np.resize(np.arange(ind.shape[0]), ind.shape[::-1])
-    c = at.stack([ind, b.transpose()]).reshape(2, -1)
-    s = c[0].argsort()
-    t = c[0][s]
-    u = c[1][s]
-    v = t.searchsorted(np.arange(t.max() + 1))
-    if v[0] > 0:
-        # There were negative numbers: remove them
-        u = u[v[0]:]
-        v -= v[0]
-    va = Varray(u, v)
-    if sort:
-        va.sort()
-    if expand:
-        return va.toArray()
-    return va
-
-
 # End
